      SUBROUTINE ATOVCF(KERR,KIDSAT,KNSAT)
C
C**** *ATOVCF* - INITIALISE SATELLITE-DEPENDENT DATA FOR TOVS.
C
C     PURPOSE.
C     --------
C          TO INITIALISE SATELLITE-DEPENDENT DATA AND COEFFICIENTS
C          FOR ATOVS RT ROUTINES FOR ALL SATELLITES.
C
C**   INTERFACE.
C     ----------
C          *CALL* *ATOVCF(KERR,KIDSAT,KNSAT)*
C               *KERR*  -  ERROR FLAG, RETURNS *KERR.NE.*0 IF ERROR.
C               *KIDSAT* - INPUT ARRAY OF SATELLITES TO BE PROCESSED
C                          TIROS-N=5, NOAA-6=6, NOAA-7=7, ETC
C               *KNSAT* -  NUMBER OF SATELLITES TO BE PROCESSED
C          PUTS OUTPUT IN *COMMON*S * /PRFREF/,/TAUCFN/,/TOVCHN/,*
C          * /MSUFRQ/ *.
C
C     METHOD.
C     -------
C          SEE REFERENCES.
C
C     EXTERNALS.
C     ----------
C          NONE.
C
C     REFERENCE.
C     ----------
C          NOT YET AVAILABLE.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        06/07/90.
C
C     MODIFICATIONS.
C     --------------
C          NONE.
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'taucfn.h'
       include 'tovchn.h'
       include 'msufrq.h'
       include 'prfref.h'
C
      REAL ZHBUF(506),ZMBUF(732),ZAMSUP(5)
      INTEGER KIDSAT(*)
C     DATA ZSSUWV/670.0,669.6,669.4/
      DATA ZPEEDL/2.998E10/,ZPCON1/1.1911E-5/,ZPCON2/1.4388/
C          SPEED OF LIGHT IN CM/S  AND
C          PLANCK FUNCTION CONSTANTS IN MW/M**2/SR/CM**-1 AND K/CM**-1
      DATA ICH/40/,ICOFM/14/,ICOFW/14/,ICOFO/4/,ILEV/40/
      DATA IHIR/19/,IMSU/20/
C          IHIR IS 19 BECAUSE FILES HAVE RECORDS ONLY FOR CHANS 1-19
      DATA IUMIX,IUH2O,IUHIR,IUMSU/15,16,13,14/
C
C     -----------------------------------------------------------------
C*         1.   OPEN AND READ MIXED GAS TRANS COEFFS AND REF PROFILE.
C               ---- --- ---- ----- --- ----- ------ --- --- -------
 100  CONTINUE
      IF (ICH.NE.JPCH) THEN
           KERR=3
           RETURN
      ENDIF
      IF (ILEV.NE.JPLEV) THEN
           KERR=4
           RETURN
      ENDIF
      IF (ICOFM.NE.JPCOFM) THEN
           KERR=5
           RETURN
      ENDIF
C
      IF (JPMACH.EQ.1) THEN
           OPEN (IUMIX,ACCESS='DIRECT',RECL=560*8,status='old',
     &     file='/dmlite3/wd20kt/atovs/taucofma_new')
      ELSE
           OPEN (IUMIX,STATUS='OLD',ACCESS='DIRECT',RECL=560,      ! NOS/VE
     *     FILE='.STE.ATOVCF.TAUCOFM')
      ENDIF
      DO 115 JSAT=1,KNSAT
      ISAT=KIDSAT(JSAT)-14                    ! FOR ATOVS: NOAA-15+
      IF (ISAT.LT.1.OR.ISAT.GT.JPSAT) THEN
           KERR=9
           RETURN
      ENDIF
      IRC=(ISAT-1)*(ICH+1)
      DO 110 JK=1,ICH
         IRC=IRC+1
         READ (UNIT=IUMIX,REC=IRC)
     *           ((CFM(JI,JJ,JK,JSAT),JI=1,ICOFM),JJ=1,ILEV)
 110  CONTINUE
      IRC=IRC+1
      READ (UNIT=IUMIX,REC=IRC) (TREF(J),J=1,ILEV),(WREF(J),J=1,ILEV)
C          NOTE: RELIES ON REF PROFILE SAME FOR ALL SATELLITES
 115  CONTINUE
C
C     -----------------------------------------------------------------
C*         2.   OPEN AND READ WATER VAPOUR TRANSMITTANCE COEFFS.
C               ---- --- ---- ----- ------ ------------- ------
 200  CONTINUE
      IF (ICOFW.NE.JPCOFW) THEN
           KERR=6
           RETURN
      ENDIF
      IF (JPMACH.EQ.1) THEN
           OPEN (IUH2O,ACCESS='DIRECT',RECL=560*8,status='old',
     &           file='/dmlite3/wd20kt/atovs/taucofwa_new')
      ELSE
           OPEN (IUH2O,STATUS='OLD',ACCESS='DIRECT',RECL=560*8,      ! NOS/VE
     *     FILE='.STE.ATOVCF.TAUCOFW')
      ENDIF
      DO 215 JSAT=1,KNSAT
      ISAT=KIDSAT(JSAT)-14          ! FOR ATOVS: NOAA-15+
      IRC=(ISAT-1)*(ICH+1)
      DO 210 JK=1,ICH
         IRC=IRC+1
         READ (UNIT=IUH2O,REC=IRC)
     *           ((CFW(JI,JJ,JK,JSAT),JI=1,ICOFW),JJ=1,ILEV)
 210  CONTINUE
 215  CONTINUE
C
C     -----------------------------------------------------------------
C*         3.   OPEN, READ AND CONVERT HIRS OZONE COEFFICIENTS.
C               ----- ---- --- ------- ---- ----- ------------
C               FROM ITTP HIRS COEFF FILE
 300  CONTINUE
      IF (JPMACH.EQ.1) THEN
           OPEN (IUHIR,ACCESS='DIRECT',RECL=506*8,status='old',
     &		file='/dmlite3/wd20kt/atovs/hirtau_new')
      ELSE
           OPEN (IUHIR,STATUS='OLD',ACCESS='DIRECT',RECL=506*8,     ! NOS/VE
     *     FILE='.STE.TRANH.HIRTAU_10_11_12')
C    *     FILE='.STE.TVDAEX.HIRTAU_10_11')
      ENDIF
      IF (IHIR.NE.JPHIR-1) THEN
           KERR=7
           RETURN
      ENDIF
C          CONVERT ITPP OZONE COEFFS FOR USE BY NEW TRANS ROUTINE
      DO 350 JSAT=1,KNSAT
      DO 320 J=1,IHIR
c        ISAT=KIDSAT(JSAT)-8        ! MAKES NOAA-15 LOOK LIKE NOAA-11

	isat = kidsat(jsat)-14
         IREC=(ISAT-1)*(IHIR+1)+J
         READ (IUHIR,REC=IREC) (ZHBUF(JJ),JJ=1,506)
         DO 310 JL=1,ILEV
            IOFF=(JL-1)*2
            ZA=MAX(1.0E-10,ZHBUF(341+IOFF))
            CFO(1,JL,J,JSAT)=ALOG(ZA)
            ZA=MAX(1.0E-10,ZHBUF(342+IOFF))
            CFO(2,JL,J,JSAT)=ALOG(ZA)
            CFO(3,JL,J,JSAT)=ZHBUF(421+IOFF)
            CFO(4,JL,J,JSAT)=ZHBUF(422+IOFF)
 310     CONTINUE
 320  CONTINUE
      DO 340 J=(IHIR+1),ICH
      DO 330 JL=1,ILEV
         CFO(1,JL,J,JSAT)=0.
         CFO(2,JL,J,JSAT)=0.
         CFO(3,JL,J,JSAT)=1.
         CFO(4,JL,J,JSAT)=1.
 330  CONTINUE
 340  CONTINUE
 350  CONTINUE
C
C     -----------------------------------------------------------------
C*         4.   READ IN OTHER HIRS CHANNEL DATA.
C               ---- -- ----- ---- ------- ----
 400  CONTINUE
      DO 430 JSAT=1,KNSAT
      ISAT=KIDSAT(JSAT)-8      ! MAKES NOAA-15 LOOK LIKE NOAA-11
	isat = kidsat(jsat)-14
      IREC=ISAT*(IHIR+1)
      READ (IUHIR,REC=IREC) (ZHBUF(J),J=1,506)
C
C*         4.1  STORE HIRS PLANCK FUNCTION COEFFICIENTS.
C
      DO 410 JCH=1,IHIR
           WVNUM(JCH,JSAT)=ZHBUF(JCH)
           BCON1(JCH,JSAT)=ZHBUF(JCH+20)
           BCON2(JCH,JSAT)=ZHBUF(JCH+40)
           TC1(JCH,JSAT)=ZHBUF(60+2*JCH-1)
           TC2(JCH,JSAT)=ZHBUF(60+2*JCH)
 410  CONTINUE
C
C*         4.2  STORE HIRS GAMMAS
C
      DO 420 JCH=1,IHIR
           GAMMA(JCH,JSAT)=ZHBUF(100+JCH)
 420  CONTINUE
 430  CONTINUE
C
C     -----------------------------------------------------------------
C*         5.   OPEN AND READ IN MSU CHANNEL DATA.
C               ---- --- ---- -- --- ------- ----
 500  CONTINUE
C     OPEN (IUMSU,ACCESS='DIRECT',RECL=732,status='old',
C     &      file='/users/kleespie/optran/data/msutau.dat')                ! UNICOS
C     OPEN (IUMSU,STATUS='OLD',ACCESS='DIRECT',RECL=732*8,   ! NOS/VE
C    *     FILE='.STE.TRANH.MSUTAU_10_11_12')
C    *     FILE='.STE.TVDAEX.MSUTAU_10_11')
      DO 540 JSAT=1,KNSAT
C     ISAT=KIDSAT(JSAT)-4
C     IREC=ISAT
C     READ (IUMSU,REC=IREC) ZMBUF
C
C*         5.1  STORE MSU FREQUENCIES IN GHZ
C
      IF (IMSU.NE.JPMSU) THEN
           KERR=8
           RETURN
      ENDIF
      DO 510 JCH=1,IMSU
           ICHAN=JCH
           CALL AMSPAR(ICHAN,ZAMSUP)
           FRQMSU(JCH,JSAT)=ZAMSUP(1)
           FMSU2(JCH,JSAT)=FRQMSU(JCH,JSAT)**2
 510  CONTINUE
C
C*         5.2  STORE MSU GAMMAS
C
      DO 520 JCH=1,IMSU
           GAMMA(JPHIR+JCH,JSAT)=1.
 520  CONTINUE
C
C*         5.3  CALCULATE MSU PLANCK FUNCTION COEFFS
C
      DO 530 JCH=1,IMSU
           WVNUM(JCH+JPHIR,JSAT)=FRQMSU(JCH,JSAT)*1.0E9/ZPEEDL
           BCON1(JCH+JPHIR,JSAT)=ZPCON1*WVNUM(JCH+JPHIR,JSAT)**3
           BCON2(JCH+JPHIR,JSAT)=ZPCON2*WVNUM(JCH+JPHIR,JSAT)
           TC1(JCH+JPHIR,JSAT)=0.
           TC2(JCH+JPHIR,JSAT)=1.
 530  CONTINUE
 540  CONTINUE
C
C     -----------------------------------------------------------------
C*         6.   SET UP SSU CHANNEL DATA.
C               --- -- --- ------- ----
C600  CONTINUE
C     IF (ISSU.NE.JPSSU) THEN
C          KERR=10
C          RETURN
C     ENDIF
C
C     DO 640 JSAT=1,KNSAT
C
C*         6.1  STORE SSU GAMMAS
C
C     IOFF=JPHIR+JPMSU
C     DO 610 JCH=1,ISSU
C          GAMMA(IOFF+JCH,JSAT)=1.
C610  CONTINUE
C
C*         6.2  CALCULATE SSU PLANCK FUNCTION COEFFS
C
C     DO 620 JCH=1,ISSU
C          WVNUM(JCH+IOFF,JSAT)=ZSSUWV(JCH)
C          BCON1(JCH+IOFF,JSAT)=ZPCON1*WVNUM(JCH+IOFF,JSAT)**3
C          BCON2(JCH+IOFF,JSAT)=ZPCON2*WVNUM(JCH+IOFF,JSAT)
C          TC1(JCH+IOFF,JSAT)=0.
C          TC2(JCH+IOFF,JSAT)=1.
C620  CONTINUE
C640  CONTINUE
C
C     -----------------------------------------------------------------
C*         7.   CLOSE ALL INPUT FILES.
C               ----- --- ----- -----
 700  CONTINUE
      CLOSE(IUMIX)
      CLOSE(IUH2O)
      CLOSE(IUHIR)
C     CLOSE(IUMSU)
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE BRIGV(PTB,PRAD,KCHAN,KNCHPF,KSAT)
C
C**** *BRIGV* -  RADIANCE TO BRIGHTNESS TEMPERATURE IN MANY CHANNELS.
C
C     PURPOSE.
C     --------
C          TO CONVERT AN ARRAY OF RADIANCES IN MANY CHANNELS
C          TO BRIGHTNESS TEMPERATURES.
C
C**   INTERFACE.
C     ----------
C          *CALL* *BRIGV(PTB,PRAD,KCHAN,KNCHPF,KSAT)*
C               *PTB*   -  OUTPUT ARRAY OF BRIGHTNESS TEMPERATURES
C               *PRAD*  -  INPUT ARRAY OF RADIANCES
C               *KCHAN* -  INPUT ARRAY OF CHANNEL INDICES FOR EACH RAD
C               *KNCHPF* - INPUT NUMBER OF RADIANCES (CHANS * PROFS).
C               *KSAT*   - SATELLITE INDEX.
C
C     METHOD.
C     -------
C          SEE REFERENCES.
C
C     EXTERNALS.
C     ----------
C          NONE.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        6/12/90.
C
C     MODIFICATIONS.
C     --------------
C          8/12/92.  FOR VERSION 2.  ADD SAT INDEX.
C
       IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'tovchn.h'
C
      REAL PRAD(*),PTB(*)
      INTEGER KCHAN(*)
C
C     -----------------------------------------------------------------
C*         1.   CALCULATE BRIGHTNESS TEMPERATURES.
C               --------- ---------- ------------
 100  CONTINUE
      DO 110 J=1,KNCHPF
           ICHAN=KCHAN(J)
           ZTEFF=BCON2(ICHAN,KSAT)/ALOG(1.+BCON1(ICHAN,KSAT)/PRAD(J))
           PTB(J)=(ZTEFF-TC1(ICHAN,KSAT))/TC2(ICHAN,KSAT)
 110  CONTINUE
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE EMISS(KCHAN,KPROF,KNCHPF,PEMS,KSAT)
C
C**** *EMISS* -  SET UP SURFACE EMISSIVITY FOR *RT* CALCULATION.
C
C     PURPOSE.
C     --------
C          TO SET UP SURFACE EMISSIVITIES FOR ALL CHANNELS AND ALL
C          PROFILES.
C
C**   INTERFACE.
C     ----------
C          *CALL* *EMISS(KCHAN,KPROF,KNCHPF,PEMS,KSAT)*
C               *KCHAN* -  INPUT ARRAY OF CHANNEL INDICES FOR EACH RAD
C               *KPROF* -  INPUT ARRAY OF PROFILE INDICES FOR EACH RAD
C               *KNCHPF* - INPUT NUMBER OF RADIANCES (CHANS * PROFS).
C               *PEMS*   - OUTPUT SURFACE EMISSIVITIES (CHANS * PROFS).
C               *KSAT*   - SATELLITE INDEX.
C          ALSO TAKES INPUT FROM *COMMON*S * /EMISIR/, /PRFVAR/, /SURF/ *.
C
C
c      IMPLICIT NONE
       IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'emisir.h'
       include 'msufrq.h'
       include 'prfvar.h'
       include 'surf.h'
C
      REAL PEMS(*),HZMICRO(21:24)
      INTEGER KCHAN(*),KPROF(*)
      DATA HZMICRO/50.3e9,53.74e9,54.96e9,57.95e9/
C
C     -----------------------------------------------------------------
C*         1.   SET UP SURFACE EMISSIVITIES.
C               --- -- ------- ------------
 100  CONTINUE
      
      DO 110 J=1,KNCHPF
           ICHAN=KCHAN(J)
           IPROF=KPROF(J)
           ISTYPE=NSTYP(IPROF)
           IF (ICHAN.GT.JPHIR.AND.ICHAN.LE.(JPHIR+JPMSU)) THEN
c            if(kzem21.eq.0)then
c             CALL SEAEMISS(SURFW,TS,HZMICRO(ICHAN),SEMISS)
c             emissv = semiss
c            else
             semiss = 0.65
c            endif
             PEMS(J)=SEMISS
           ELSE
             PEMS(J)=EMSIR0(ICHAN,ISTYPE,KSAT)
           ENDIF
 110  CONTINUE
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      subroutine seaemiss(wind,sfct,hz,ems)
       ANGLE = 0.0
       radus = 6370.
       THETx=ASIN(SIN(ANGLE)*(RADUS+870.)/RADUS)
c       wind=  sqrt(u*u+v*v)
       theta = thetx*180./3.141592654	
c       hz90 =91.655*1e9
       call refl(wind,thetx,'V',sfct,36.5,hz,ref,emv)
c       call refl(wind,thetx,'V',sfct,36.5,hz90,ref,emv)
c       call refl(wind,thetx,'H',sfct,36.5,hz90,ref,emh)
       ems = emv
       return
       end
      SUBROUTINE REFL (WIND,ANGLE,POLAR,T,S,F,REF,EMI)
C
C THIS FUNCTION CALCULATES THE EMISSIVITY OF A FLAT SURFACE
C REF: MICROWAVE REMOTE SENSING ACTIVE AND PASSIVE
C BY ULABY, MOORE AND FUNG.
C PAG. 230
C VARIABLES: ANGLE = DIRECTION ANGLE IN RADIANS
C            DEGRE = DIRECTION ANGLE IN DEGREES
C            POLAR = POLARIZATION
C            T     = TEMPERATURE
C            S     = SEA WATER SALINITY
C            F     = FREQUENCY
C            WIND  = WIND SPEED
C            FOAM  = FOAM FRACTION
C            G,TR  = EMPERICAL FUNCTIONS FOR WIND INDUCED 
C                    CHANGES IN REFLECTION COEFFICIENT
C NOTE THAT MU AND EPS ARE COMPLEX QUANTITIES
C-------------------------------------------------------------------
      REAL ANGLE,WIND,LAMBDA,LAMBDAS,TC
      CHARACTER POLAR
      COMPLEX MU, EPS, AID1,AID2,AID3,CANG,REFWAT
      MU = CMPLX (1.0,0.0)

C* COMPLEX DIELECTRIC PROPERTIES OF SALINE WATER
      EPS=CMPLX (EPSP(T,S,F),-EPSPP(T,S,F))

C* COMPLEX REFRACTIVE INDEX OF SALINE WATER (NOT USED)
      REFWAT = CSQRT(EPS)
     
      CANG=CMPLX(ANGLE,0.)
      PI = 4.0*ATAN(1.0)
      DEGRE = ANGLE/PI*180.0
      AID1=CSQRT(MU*EPS-CSIN(CANG)**2)
      IF (POLAR.EQ.'H') THEN
                AID2 = MU*CCOS(CANG)-AID1
                AID3 = MU*CCOS(CANG)+AID1
C* EMPERICAL FUNCTIONS FOR WIND INDUCED REFLECTION CHANGES
                G = 1.0 - 1.748E-3*DEGRE-7.336E-5*DEGRE**2+
     &              1.044E-7*DEGRE**3
                TR = WIND*(1.15E-1+3.8E-5*DEGRE**2)*SQRT(F*1.0E-9)
      ELSE
                AID2 = EPS*CCOS(CANG)-AID1
                AID3 = EPS*CCOS(CANG)+AID1 
C* EMPERICAL FUNCTIONS FOR WIND INDUCED REFLECTION CHANGES
                G = 1.0 - 9.946E-4*DEGRE+3.218E-5*DEGRE**2
     &              -1.187E-6*DEGRE**3+7.E-20*DEGRE**10
                TR = WIND*(1.17E-1-2.09E-3*EXP(7.32E-2*DEGRE))
     &              *SQRT(F*1.0E-9)
      ENDIF
      REF = ( CABS(AID2/AID3) )**2
C* THE REFLECTION OF A SPECULAR CALM SEA WITH 
C* WIND INDUCED CHANGES IN THE SURFACE REFLECTION
C* SOURCE: FRANCIS ET AL. 1983 IN 
C*         SATELLITE MICROWAVE REMOTE SENSING
C*         ED BY ALLAN
C*         AND OBSERVATIONS BY HOLLINGER (1971) AND STROGRYN (1971)
C
C* FOAM FRACTION
C      B0 =  1.707E-2+8.560E-4*(F*1.0E-9)+1.120E-5*(F*1.0E-9)**2
C      B1 = -1.501E-2+1.821E-3*(F*1.0E-9)-4.634E-5*(F*1.0E-9)**2
C      B2 =  2.442E-4-2.282E-6*(F*1.0E-9)+4.194E-7*(F*1.0E-9)**2
C      FOAM = B0+B1*WIND+B2*WIND**2
      IF(WIND.LT.7.0) THEN
         FOAM=0.0
      ELSE
         FOAM=0.006*(1.0-EXP(-F*1.0E-9/7.5))*(WIND-7.0)
      ENDIF 
C CORRECTION FOR WIND INDUCED FOAM FREE SEA SURFACE
      IF(FOAM.LT.0.) FOAM=0. 
      IF(FOAM.GT.1.) FOAM=1.  
      RCLEAR = REF - TR/T
C* REFLECTION COEFFICIENT FOR FOAM COVERED SEA
      RFOAM = 1.0-(208.0+1.29E-9*F)/T*G 
C* MOW LINEAR INTERPOLATION BETWEEN FOAM FREE AND FOAM COVERED
      GAMMA = (1.0-FOAM)*RCLEAR+FOAM*RFOAM
      EMI = 1.0 - GAMMA
      IF(EMI.GT.1.0) EMI=1.0       
      IF(EMI.LT.0.0) EMI=0.0       
      RETURN
      END

      REAL FUNCTION EPSP (T1,S,F)
C
C THIS FUNCTION CALCULATES THE REAL PART OF THE DIELECTRIC CONSTANT
C FOR SALINE WATER
C
C SOURCE : MICROWAVE REMOTE SENSING PAG 2022
C UNITS:
C TEMPERATURE (T) IS IN DEGREES CELSIUS
C SALINITY (S) PARTS PER THOUSAND
C FREQUENCY (F) HZ

      T=T1-273.0
      T2=(T-25.0)
      ESWI = 4.9
    
      ESWO = 87.134-1.949E-1*T-1.276E-2*T*T+2.491E-4*T**3
      A = 1.0+1.613E-5*T*S-3.656E-3*S+3.210E-5*S*S-4.232E-7*S**3
      ESW = ESWO*A

      TSWO = 1.1109E-10-3.824E-12*T+6.938E-14*T**2-5.096E-16*T**3
      B = 1.0+2.282E-5*T*S-7.638E-4*S-7.760E-6*S**2+1.105E-8*S**3
      TSW = TSWO*B

      EPSP = ESWI +(ESW-ESWI)/(1.0+(F*TSW)**2)
     
      RETURN
      END
      REAL FUNCTION EPSPP (T1,S,F) 
C
C-------------------------------------------------------------------
C
C THIS FUNCTION CALCULATES THE IMAGINAIR PART OF THE DIELECTRIC CONSTANT
C FOR SALINE WATER
C
C SOURCE : MICROWAVE REMOTE SENSING PAG 2022
C NOTE THAT THE TEMPERATURE (T) IS IN DEGREES CELSIUS
C SALINITY (S) PARTS PER THOUSAND

      T=T1-273.0
      T2=T-25.0
      ESWI = 4.9
      EO = 8.854E-12
      PI = 4.0 * ATAN(1.0)
      ESWO = 87.134-1.949E-1*T-1.276E-2*T*T+2.491E-4*T**3
      A = 1.0+1.613E-5*T*S-3.656E-3*S+3.210E-5*S*S-4.232E-7*S**3
      ESW = ESWO*A
      TSWO = 1.1109E-10-3.824E-12*T+6.938E-14*T**2-5.096E-16*T**3
      B = 1.0+2.282E-5*T*S-7.638E-4*S-7.760E-6*S**2+1.105E-8*S**3
      TSW = TSWO*B
      SSWO = S*(0.18252-1.4619E-3*S+2.093E-5*S**2-1.282E-7*S**3)
      D = 25.0-T
      FI = D*(2.033E-2+1.266E-4*D+2.464E-6*D**2-
     &       S*(1.849E-5-2.551E-7*D+2.551E-8*D*D))
      SSW = SSWO*EXP(-FI)
      EPSPP = TSW*F*(ESW-ESWI)/(1.0+(TSW*F)**2)
      EPSPP = EPSPP + SSW/(2.0*PI*EO*F)
      RETURN
      END

	Subroutine Get_Predictors_All(
     &		Ispecies,
     &		P,
     &		Absorber,
     &		T,
     &          Q,
     &		Nlev
     &				     )
*	
*	Name: Subroutine Get_Predictors_All
*
*	Version 4: 25 October 95
*
*	Purpose:
*	Gets all predictors out of set of 14
*	
*	Input:
*	Ispecies	Species number, 1=wet,2=dry,3=ozo
*	P(Nlev)  	Atmospheric pressure levels
*	Absorber(Nlev)	Atmospheric absorber profile on slant path
*	T(Nlev) 	Atmospheric temperature profile
*	Q(Nlev)         Atmospheric mixing ratio
*	Nlev		Number of atmospheric levels
*
*	From Common:
*
*
*	Output:
*
*	X - various predictors
*
*	Note in the following description 'x' is multiplication,
*					  '^' is exponention
*					  '*' is a "star'd" quantity
*	X(1)	T	
*	X(2)	P	
*	X(3)	T^2
*	X(4)	P^2
*	X(5)    TxP
*	X(6)	T^2xP
*	X(7)	TxP^2
*	X(8)	T^2xP^2
*	X(9)	T*
*	X(10)	P*
*	X(11)	T**
*	X(12)	P**
*	X(13)	T***
*	X(14)	P***	
*	X(15)   q
*
*	Author:	Thomas J. Kleespies
*		Physics Branch
*		Satellite Research Laboratory
*		Office of Research and Applications
*		NOAA/NESDIS
*               301-763-8136
*               301-763-8108 FAX
*
*	Mailing Address:
*		810 NSC E/RA-14
*		NOAA/NESDIS
*		Washington, D.C. 20233
*
*	Email:
*		Kleespies@NZMS.WWB.NOAA.GOV
*
*

	Implicit None

	Include 'constants.inc'
	Include 'cparam.h'
	Include 'opcom.inc'

*	Input
	Integer Ispecies	! Species number, 1=wet,2=dry,3=ozo
	Integer Nlev		! number of atmospheric levels
	Real P(MaxLevel)
	Real T(MaxLevel)
	Real Q(MaxLevel)
	Real Absorber(MaxLevel)
	Real WW(0:nw)
	
*	Output
*	declared in common

*	Local

	Real delA
        Real fact,tint,pint

	Integer i,j,k

	Integer M1

*	Zero arrays

	Do i = 1 , Nlev
	 Do j = 1 , 15
	   X(i,j,Ispecies) = 0.0
	 EndDo
	EndDo	 
*	First compute star'd terms for the specified atmosphere
*	i.e. on pressure levels
        If(Absorber(1) .gt. 0.0) Then
         xx1(1,Ispecies) = T(1) / 2. ! if we treat T(0) = 0, Absorber(0) = 0
         xx2(1,Ispecies) = P(1) / 2. ! if we treat P(0) = 0, Absorber(0) = 0
         xx3(1,Ispecies) = T(1) / 2. ! if we treat T(0) = 0, Absorber(0) = 0
         xx4(1,Ispecies) = P(1) / 2. ! if we treat P(0) = 0, Absorber(0) = 0
         xx5(1,Ispecies) = T(1) / 2. ! if we treat T(0) = 0, Absorber(0) = 0
         xx6(1,Ispecies) = P(1) / 2. ! if we treat P(0) = 0, Absorber(0) = 0
        Else
         xx1(1,Ispecies) = 0.0
         xx2(1,Ispecies) = 0.0
         xx3(1,Ispecies) = 0.0
         xx4(1,Ispecies) = 0.0
         xx5(1,Ispecies) = 0.0
         xx6(1,Ispecies) = 0.0
        EndIf
        s1(1,Ispecies) = 0.0
        s2(1,Ispecies) = 0.0
        s3(1,Ispecies) = 0.0
        s4(1,Ispecies) = 0.0
        s5(1,Ispecies) = 0.0
        s6(1,Ispecies) = 0.0

	Do k = 2 , Nlev
	 delA = Absorber(k) - Absorber(k-1)
         s1(k,Ispecies) = s1(k-1,Ispecies) + (T(k)+T(k-1))*delA ! T*
         s2(k,Ispecies) = s2(k-1,Ispecies) + (P(k)+P(k-1))*delA ! P*
         s3(k,Ispecies) = s3(k-1,Ispecies) + (Absorber(k)*T(k) +
     &              Absorber(k-1)*T(k-1))*delA !T**
         s4(k,Ispecies) = s4(k-1,Ispecies) + (Absorber(k)*P(k) +
     &              Absorber(k-1)*P(k-1))*delA !P**
         s5(k,Ispecies) = s5(k-1,Ispecies) +
     &             (Absorber(k)*Absorber(k)*T(k) +
     &              Absorber(k-1)*Absorber(k-1)*T(k-1))*delA !T***
         s6(k,Ispecies) = s6(k-1,Ispecies) +
     &             (Absorber(k)*Absorber(k)*P(k) +
     &              Absorber(k-1)*Absorber(k-1)*P(k-1))*delA !P***

	EndDo
	Do k = 2 , Nlev
	 If(Absorber(k) .eq. 0.0) Then 
           xx1(k,Ispecies) = 0.0
           xx2(k,Ispecies) = 0.0
           xx3(k,Ispecies) = 0.0
           xx4(k,Ispecies) = 0.0
           xx5(k,Ispecies) = 0.0
           xx6(k,Ispecies) = 0.0
	 Else
           xx1(k,Ispecies) = s1(k,Ispecies)/(2.0*Absorber(k))
           xx2(k,Ispecies) = s2(k,Ispecies)/(2.0*Absorber(k))
           xx3(k,Ispecies) = s3(k,Ispecies)/(Absorber(k)*Absorber(k))
           xx4(k,Ispecies) = s4(k,Ispecies)/(Absorber(k)*Absorber(k))
           xx5(k,Ispecies) = 1.5*s5(k,Ispecies)/
     &                       (Absorber(k)*Absorber(k)*Absorber(k))
           xx6(k,Ispecies) = 1.5*s6(k,Ispecies)/
     &                       (Absorber(k)*Absorber(k)*Absorber(k))
	 EndIf

	EndDo
*	Compute all the predictors on atmospheric levels

	Do 200 k = 1 , Nlev		

          tint= T(k)	! T
          pint= P(k)	! P
          x(k,1,Ispecies)= tint        	! T
          x(k,2,Ispecies)= pint        	! P
	  x(k,3,Ispecies)=  tint*tint 	! T**2
	  x(k,4,Ispecies)=  pint*pint 	! P**2
	  x(k,5,Ispecies)=  tint*pint 	! T*P
	  x(k,6,Ispecies)=  tint*tint*pint 	! T**2 P
	  x(k,7,Ispecies)=  tint*pint*pint 	! T P**2
	  x(k,8,Ispecies)=  tint*tint*pint*pint    ! T**2 P**2
          x(k,9,Ispecies)=  xx1(k,Ispecies)
          x(k,10,Ispecies)= xx2(k,Ispecies)
          x(k,11,Ispecies)= xx3(k,Ispecies)
          x(k,12,Ispecies)= xx4(k,Ispecies)
          x(k,13,Ispecies)= xx5(k,Ispecies)
          x(k,14,Ispecies)= xx6(k,Ispecies)
          x(k,15,Ispecies)= q(k)

  200   Continue	! MaxWlevels loop

	Return
	End
	Subroutine Make_Wlevels(Nprofiles,MaxAbsorber,MinAbsorber,W)
*	
*	Name: Subroutine Make_Wlevels
*
*	Version 4: 25 October 1995
*
*	Purpose:
*	Makes the absorber space of Nw levels,
*	identified as W(0:Nw).  The most important value for
*	defining the parameter 'alpha' is W(200), which must be
*	at least the maximum possible absorber amount. The code 
*	is structured to produce different standard profiles for each channel.
*	
*	Input:
*	Nprofiles	number of profiles to use
*			this is the dimension of MaxAbsorber
*			and the second dimension of W.
*	MaxAbsorber(Nprofiles)	! absorber amount at W(200)
*	MinAbsorber	! absorber amount at W(1), W(0) == 0.0
*
*	Output:
*	W(0:Nw,Nprofiles) ! standard absorber profiles
*
*	Author:	Thomas J. Kleespies
*		Physics Branch
*		Satellite Research Laboratory
*		Office of Research and Applications
*		NOAA/NESDIS
*		301-763-8136
*		301-763-8108 FAX
*
*	Mailing Address:
*		810 NSC E/RA-14
*		NOAA/NESDIS
*		Washington, D.C. 20233
*
*	Email:
*		Kleespies@NZMS.WWB.NOAA.GOV
*
*

	Implicit None

	Include 'constants.inc'

	Integer Nprofiles	! number of profiles to use
				! this is the dimension of MaxAbsorber
				! and the second dimension of W.
	Real MaxAbsorber(Nprofiles)	! absorber amount at W(200)
	Real MinAbsorber	! absorber amount at W(1), W(0) == 0.0

	Real W(0:Nw,Nprofiles) ! standard absorber profiles

	Real alpha    ! exponential parameter

	Integer k     ! utility variables

	Real Tolerance 
	Data Tolerance /1.0e-10/ ! iteration-to-iteration convergence criterion

	Integer MaxIter 
	Data MaxIter  /500/ ! arbitrary value to test non-convergence

	Real x1,x2,fx,fp ! Newton's method variables
			   ! fx is the function
			   ! fp is the function primed (as in it's derivative)
			   ! x1 and x2 are previous and new approximations

	Integer Ichan,Iter ! local variables

	Do Ichan = 1 , NProfiles  ! profile loop

	 W(0,Ichan) = 0		  ! top of atmosphere always has zero absorber
	 W(1,Ichan) = MinAbsorber
	 W(Nw,Ichan) = MaxAbsorber(Ichan)
	
*	solve for alpha by Newton's method

* these are somewhat arbitrary initial guesses
* the lower one is important for the wet atmospheres, and the
* upper one is important for the dry atmospheres.

	 x2 = 0.3	
	 x1 = 3000.
	 iter = 0
	 Do While (abs(x2-x1) .ge. tolerance)

	  iter = iter + 1
	  If(Iter .gt. MaxIter) Then
	   Write(6,*) 'Make_Levels failed to converge '
	   stop
	  EndIf

	  x1 = x2
! 	the function
	  fx = (exp(Nw*x1)-1.) - (W(Nw,Ichan)/W(1,Ichan))*(exp(x1)-1.)
! 	function primed 
	  fp = Nw*exp(Nw*x1) - (W(Nw,Ichan)/W(1,Ichan))* exp(x1)   
	  x2 = x1 - fx/fp

	 EndDo

	 alpha = x2

*	Now that we have alpha, construct the profile 

	 Do k = 2 , Nw
	  W(k,Ichan) = W(1,Ichan) * (exp(k*alpha)-1.)/(exp(alpha)-1.)
	 EndDo

	EndDo ! profile loop
	return
	end

	Subroutine OPtrans(
     &		Nprof,
     &		Nlev,
     &		P,
     &		T,
     &		Q,
     &          Ppw,
     &		Pw,
     &		O3,
     &		Angle,
     &		Nchannels,
     &		Channels,
     &		Ptrans
     &                     )

*	Version 4.0  25 Oct 96
*	
*	Name:	Subroutine Optrans
*
*
*	Purpose: Computes the transmittance using the optical path
*		 regression algorithm.
*	
*	Input:  
*		I*4 Nprof         number of profiles
*		I*4 Nlev          number of levels in each profile
*		R*4 P(Maxlevel,*)   Pressure levels
*		R*4 T(Maxlevel,*)   Temperature (K)
*		R*4 Pw(Maxlevel,*)  Precipitable water (cm) 
*		R*4 O3(Maxlevel,*)  Integrated Ozone Profile
*               R   Q(Maxlevel,*)   mixing ratio profile
*		R*4 Angle(*)      Zenith Angle to use (Degrees)
*		I*4 Nchannels     Number of channels to use
*		I*4 Channels(*) Array of channels for which to 
*		    compute transmittance.
*
*		from for042 wet coefficients
*		from for043 dry coefficients
*		from for044 ozo coefficients
*		From for061 wet control file
*		From for062 dry control file
*		From for063 ozo control file
*
*
*	Output: R*4 Ptrans(Jpchpf,*) Transmittances at Nlev levels
*
*	Author:	Thomas J. Kleespies
*		Physics Branch
*		Satellite Research Laboratory
*		Office of Research and Applications
*		NOAA/NESDIS
*		301-763-8136
*		301-763-8108 FAX
*
*	Mailing Address:
*		810 NSC E/RA-14
*		NOAA/NESDIS
*		Washington, D.C. 20233
*
*	Email:
*		Kleespies@NZMS.WWB.NOAA.GOV
*
*

	Implicit None

	Include 'constants.inc'
	Include 'cparam.h'
	Include 'opcom.inc'

*	Input

        real xl1,xl2,xl3    ! junk real variable
        integer kli                  ! junk integer variable

	Integer Nprof		! number of profiles
	Integer Nlev	  	! number of levels
	Real P(Maxlevel,*)  	! Pressure (mb)
	Real T(Maxlevel,*)	! temperature (K)
        Real Ppw(Maxlevel,*)
	Real Pw(Maxlevel,*) 	! precipitable water profile (cm)
	Real O3(Maxlevel,*)  	! integrated ozone profile
	Real Q(Maxlevel,*)	! mixing ratio profile
	Real Angle(*)	  	! zenith angle (degrees)
	Integer Nchannels ! number of channels to process
	Integer Channels(*) ! channel list

*	Output
	! estimated transmittance in pressure space
	Real Ptrans(Jpchpf,0:MaxLevel)

*	Local

        ! Optical Depths in pressure space
c        Real OdWet(MaxLevel,Nchan)
c        Real OdDry(MaxLevel,Nchan)
c        Real OdOzo(MaxLevel,Nchan)
c
        integer k,j
c
	Real Bw(Nwet+1, Nw ,Nchan)  ! Vector of wet regression coefficients
	Real Bd(Ndry+1, Nw ,Nchan)  ! Vector of dry regression coefficients
	Real Bo(NOzo+1, Nw ,Nchan)  ! Vector of dry regression coefficients
	Save Bw,Bd,Bo

* 	Absorber spaces
	Real WW(0:nw)
	Real AA(0:nw)
	Real OO(0:nw)
	Save WW,AA,OO

	Real PwMax 
        Data PwMax /3.502066e+3/ ! max wet absorber at WW(Nw)
c        Data PwMax /3.502066e+23/ ! max wet absorber at WW(Nw)
c        Data PwMax	/13.87981/	! max wet absorber at WW(Nw)
c	Data PwMax	/12.33751/	! max wet absorber at WW(Nw)
	Real PMax  
	Data Pmax  /9.347048e+2/   ! max dry absorber at AA(Nw)
c        Data Pmax  /9.347048e+24/   ! max dry absorber at AA(Nw)
c	Data Pmax	/2000.0/	! max dry absorber at AA(Nw)
	Real OzMax  
        Data OzMax  /2.33976e+3/  ! max ozo absorber at OO(Nw)
c        Data OzMax  /2.33976e+19/  ! max ozo absorber at OO(Nw)
c        Data OzMax  /1.1403912/  ! max ozo absorber at OO(Nw)
c	Data OzMax	/153.4007/	! max ozo absorber at OO(Nw)
	Real PwMin 
        Data PwMin  /8.541981e-5/  ! Min wet absorber at WW(Nw)
c        Data PwMin  /8.541981e+15/  ! Min wet absorber at WW(Nw)
c       Data PwMin	/1.0e-7/	! Min wet absorber at WW(Nw)
c	Data PwMin	/0.0001/	! Min wet absorber at WW(Nw)
	Real PMin  
	Data Pmin  /4.421026e-2/  ! Min dry absorber at AA(Nw)
c        Data Pmin  /4.421026e+20/  ! Min dry absorber at AA(Nw)
c	Data Pmin	/0.01/		! Min dry absorber at AA(Nw)
	Real OzMin  
        Data OzMin  /1.63248e-1/  ! Min ozo absorber at OO(Nw)
c        Data OzMin  /1.63248e+15/  ! Min ozo absorber at OO(Nw)
c        Data OzMin  /2.0e-5/  ! Min ozo absorber at OO(Nw)
c	Data OzMin	/0.0001/	! Min ozo absorber at OO(Nw)

	Real SlantPw(Jplapf,Jppf)  ! wet absorber on a generalized slant path
	Real SlantP (Jplapf,Jppf)  ! dry absorber on a generalized slant path
	Real SlantOz(Jplapf,Jppf)  ! Ozo absorber on a generalized slant path

	Real Dtr 
	Data Dtr	/1.74532952e-2/ ! degrees to radians conversion

	Real Rangle		! angle in radians
	Real Secant		! secant of angle

	Integer Level,Mlevel

	Integer i ! local index
	Integer Ichan 	! channel index for read
	Integer Ipred	! predictor index for read

	Integer Iprofile ! profile index
	Integer Index    ! index for profile+channel

	Integer Pred_Index_Wet(Nwet,Nchan) ! wet predictors
	Integer Pred_Index_Dry(NDry,Nchan) ! dry predictors
	Integer Pred_Index_Ozo(NOzo,Nchan) ! dry predictors
	Save Pred_Index_Wet,Pred_Index_Dry,Pred_Index_Ozo

	Integer IOs ! io return from open

	Integer Ncoef ! number of coefficients

*  This may need a SAVE statement on some systems
	Logical First 
	Data First	/.true./  ! flag to initialize coefficients and such
				  ! first time routine is called.

	If(First) Then ! first time called, initialize variables and parameters

         DTR = Acos(-1.0)/180.0

	 Read(42) Bw	! read wet coefficients
	 Close(42)

	 Read(43) Bd	! read dry coefficients
	 Close(43)

	 Read(44) Bo	! read ozo coefficients
	 Close(44)

*	Read the control files

       Open(unit=61,status='old',file='AIRS_WET_PICKED.DAT')
       Open(unit=62,status='old',file='AIRS_DRY_PICKED.DAT')
       Open(unit=63,status='old',file='AIRS_OZONE_PICKED.DAT')
 3100     format(i7,f8.2,e17.8,e15.8,5i3)
 3101     format(5i3)

         Do Ichan = 1 , Nchan
          Read(61,3100)kli,xl1,xl2,xl3,
     $         (Pred_Index_Wet(Ipred,Ichan), Ipred=1,Nwet)
         EndDo
         Close(61)

         Do Ichan = 1 , Nchan
          Read(62,3100)kli,xl1,xl2,xl3,
     $         (Pred_Index_Dry(Ipred,Ichan), Ipred=1,NDry)
         EndDo
         Close(62)

         Do Ichan = 1 , Nchan
          Read(63,3100)kli,xl1,xl2,xl3,
     $         (Pred_Index_Ozo(Ipred,Ichan), Ipred=1,NOzo)
         EndDo
         Close(63)

*	Construct the absorber amount spaces for wet and dry cases

	 Call Make_Wlevels(1, PwMax, PwMin, WW)
         Call Make_Wlevels(1, Pmax ,  PMin, AA)
         Call Make_Wlevels(1, Ozmax ,OzMin, OO)

         Iprofile = 0
         Do Ichan =1,201 
          write(*,*)ww(iprofile),aa(iprofile),oo(iprofile)
          iprofile = iprofile + 1
         enddo
     
	 First = .False.  ! assure that we don't come here again

	EndIf ! first

*	This is where the actual work starts

*       Compute slant path absorber amounts

	Do Iprofile = 1 , Nprof

	 Mlevel = Nlev+1

	 If(Mlevel .gt. MaxLevel) Then
	  Write(6,*) 'Too many levels in input profile'
	  Write(6,*) MaxLevel,' is max permitted without recompile'
	  Return
	 EndIf

	 Rangle = Angle(Iprofile)*DTR
	 Secant = 1.0 / Cos(RAngle)
	 Do level= 1 , Mlevel
          SlantP(level,Iprofile)  = Ppw (level,Iprofile)*Secant
c          SlantP(level,Iprofile)  = P (level,Iprofile)*Secant - 0.005
	  SlantPw(level,Iprofile) = Pw(level,Iprofile)*Secant
	  SlantOz(level,Iprofile) = O3(level,Iprofile)*Secant
	 EndDo

	EndDo

	 Ncoef = Nwet + 1
*	Get Wet Optical Depth profile
         Call Optrans_Species     (
     &		1,
     &          Nprof,
     &		Nlev,
     &		Ncoef,
     &		Nwet,
     &          Bw,
     &          WW,
     &          P,
     &          T,
     &		Q,
     &          SlantPw,
     &          Nchannels,
     &          Channels,
     &		Pred_Index_Wet
     &                          )
*	Get Dry Optical Depth profile
	 Ncoef = Ndry + 1
         Call Optrans_Species     (
     &		2,
     &          Nprof,
     &		Nlev,
     &		Ncoef,
     &		Ndry,
     &          Bd,
     &          AA,
     &          P,
     &          T,
     &		Q,
     &          SlantP,
     &          Nchannels,
     &          Channels,
     &		Pred_Index_Dry
     &                          )
*	Get Ozone Optical Depth profile
	 Ncoef = Nozo + 1
         Call Optrans_Species     (
     &		3,
     &          Nprof,
     &		Nlev,
     &		Ncoef,
     &		NOzo,
     &          Bo,
     &          OO,
     &          P,
     &          T,
     &		Q,
     &          SlantOz,
     &          Nchannels,
     &          Channels,
     &		Pred_Index_Ozo
     &                          )

      write(*,*)'Finish  call three species'
*	Compute total transmittance profile

	Do Iprofile = 1 , Nprof
	 Do i = 1 ,  Nchannels ! now process only requested channels
	  Index = Iprofile + i - 1
	  Ptrans(Index,0) = 1.0
          Ichan = Channels(i) 

	  Do level = 1 , Mlevel
             kli = level
       xl1 = od(kli,i,3)
       xl2 = od(kli,i,2)
       xl3 = od(kli,i,1)
c       write(*,*)'channel = ',i,' species = ', ichan,' level = ',level
c       write(*,2118)' od = ',(od(level,i,ichan),ichan=1,3)
c2118   format(a6,3e16.5)

 	   Ptrans(Index,level) = Ptrans(Index,level-1)
     &		    *exp(-(
     &			   Od(level,I,1)
     &			  +Od(level,I,2)
     &			  +Od(level,I,3)
     &			) )
	  EndDo ! Mlevel
	 EndDo  ! channel
	EndDo   ! Iprofile

        write(*,*)'Finish Call subr OPtrans '
*	That's all folks!

	Return

  310   Continue
	Write(6,*) 'Error on control file open '
	Write(6,*) IOs
	Stop
	end

	Subroutine Optrans_Species	(
     &		Ispecies,
     &          Nprof,
     &		Nlev,
     &		NCoeff,
     &		Npred,
     &		B,
     &		WW,
     &		P,
     &		T,
     &          Q,
     &		Absorber,
     &		NChannels,
     &		Channels,
     &		Pred_Index
     &					)

*
*	Version 4: 25 October 1995
*	
*	Name: OPtrans_Species
*
*
*	Purpose:
*	This is the routine that determines the optical depth profile
*	given the pressure profile, temperature profile, and absorber
*	profile.  This is generalized such that it will work with any
*	species.
*	
*	Input:
*	Integer Ispecies	! species - 1=wet, 2=dry, 3=ozo
*	Integer Nprof           ! number of profiles
*	Integer Nlev		! number of levels in each profile
*	Integer Ncoeff		! number of coefficients
*	Integer Npred		! number of predictors
*	Real B(Ncoeff,Nw,Nchan)	! regression coefficients for this species
*	Real WW(0:Nw)		! Absorber space for this species
*	Real P(Maxlevel,*)	! atmospheric pressure profile
*	Real T(Maxlevel,*)	! atmospheric temperature profile
*	Real Q(MaxLevel,*)      ! atmospheric mixing ratio profile
*	Real Absorber(Maxlevel,*)! slant path absorber profile
*	Integer Nchannels	! Number of channels for each profile
*	Integer Channels(jpchus,*) ! vector of channels to use for @ profile
*       Integer Pred_Index(Npred,Nchan)  ! index set of predictors to use
*				 	   ! for each channel.
*	In Common:
*
*	Output variables
*	Real OD(MaxLevel,Nchan,Ispecies,Iprofile)! Optical depth of specie in pressure space
*
*	Author:	Thomas J. Kleespies
*		Physics Branch
*		Satellite Research Laboratory
*		Office of Research and Applications
*		NOAA/NESDIS
*		301-763-8136
*		301-763-8108 FAX
*
*	Mailing Address:
*		810 NSC E/RA-14
*		NOAA/NESDIS
*		Washington, D.C. 20233
*
*	Email:
*		Kleespies@NZMS.WWB.NOAA.GOV
*
	Implicit None

	Include 'constants.inc'
	Include 'cparam.h'
	Include 'opcom.inc'

*	Input variables
	Integer Ispecies	! species - 1=wet, 2=dry, 3=ozo
	Integer Nprof		! numper of profiles
	Integer Nlev		! number of levels in each profile
	Integer Ncoeff		! number of coefficients
	Integer Npred		! number of predictors
	Real B(Ncoeff,Nw,Nchan)! regression coefficients
	Real WW(0:Nw)		! absorber space
	Real P(Maxlevel,*)	! atmospheric pressure profile
	Real T(Maxlevel,*)	! atmospheric temperature profile
	Real Q(Maxlevel,*)	! atmospheric mixing ratio profile
	Real Absorber(Maxlevel,*)	! atmospheric absorber profile
	Integer Nchannels	! Number of channels for each profile
	Integer Channels(*) ! vector of channels to use for profile sets
        Integer Pred_Index(NPred,Nchan) ! index set of predictors to use
     &                                    ! for each channel.

*	Local variables

	Real Sum		! summation 
        real bx,fact

	Real Average_Absorber(MaxLevel)	! average absorber amount

	Integer i,j,level,kt	! utility variables
	Integer Ichan,Jchan
	Integer K2,K1
	Integer Ipred
	Integer Mlevel

        Integer M		! index for interpolation


	Integer Iprofile
c        write(*,*)'enter subr optrans_species'

	Do Iprofile = 1 , Nprof  !  profile loop

         Mlevel = Nlev + 1

         Do level = 1 , Mlevel

*	Compute DP here for convinence

          If(level .eq.1) Then
	   Dp(Level,Ispecies) = Absorber(level,Iprofile)
	  Else
           Dp(Level,Ispecies) =
     &         (Absorber(level,Iprofile)-Absorber(level-1,Iprofile))
          EndIf

          If(level .eq. 1) Then
           Average_Absorber(level) = Absorber(1,Iprofile)/2.
          Else
           Average_Absorber(level) =
     &      (Absorber(level,Iprofile)+Absorber(level-1,Iprofile))/2.
          EndIf

         EndDo

	If(Find_Levels) Then

*	Find values in W space that bracket the absorber levels
         M=0

         Do level = 1 , Mlevel

*	Find the values in absorber space that bracket the layer
*	average absorber

	  Do i = M , Nw
	   If(Average_Absorber(level) .lt. WW(i)) Then
	    j = i
	    Go to 111
	   EndIf
	  EndDo

	  j = Nw

  111     Continue
          M=max(j-1,0)
          Wlevels(level,Ispecies) = j

         EndDo

	EndIf	! Find_Levels

*	Compute the predictors for this atmosphere
        write(*,*)'from specisc to call get_Predicator_ALl'
        Call Get_Predictors_All(
     &		Ispecies,
     &          P(1,Iprofile),
     &          Absorber(1,Iprofile),
     &          T(1,Iprofile),
     &		Q(1,Iprofile),
     &		Mlevel
     &                            )

	Do  300 Jchan = 1 , Nchannels

	 Do level = 1 , Mlevel      
	  OD(level,Jchan,Ispecies) = 0.0
	 EndDo

	 Ichan = Channels(Jchan)

       If(Pred_Index(0,Ichan).lt.1) go to 300! no absorption for this channel


*	Compute k in P space by interpolating coeff

	 Do 200 level = 1 , Mlevel 

	   K1 = max(1,Wlevels(level,Ispecies)-1)
           K2 = max(1,Wlevels(level,Ispecies))
		
           Fact=0.
           If(WW(K1) .lt. WW(K2) .and.
     &          Average_absorber(level) .gt. WW(0)) Then
            Fact=(WW(k2)-Average_Absorber(level))/(WW(k2)-WW(k1))
	   EndIf
           Sum = B(1,K2,Ichan)+Fact*(B(1,K1,ichan)-B(1,k2,ichan))

           Do Ipred = 2 , NCoeff
            Bx = B(ipred,k2,ichan)+Fact*(B(ipred,k1,ichan)
     *         - B(ipred,k2,ichan))
c            write(*,*)'Ncoeff= ', Ncoeff,' Bx = ', Bx
c       write(*,*)B(ipred,k2,ichan), B(ipred,k1,ichan)
	    If(level.eq. 1) Then
c        write(*,*)'x = ', x(level,Pred_Index(Ipred-1,Ichan),Ispecies) 
             Sum = Sum + Bx
     &                * x(level,Pred_Index(Ipred-1,Ichan),Ispecies)
c             write(*,*)'First part If Sum = ', Sum
	    Else
c             write(*,*)'Second part If Sum = ', Sum
c             write(*,*)x(level  ,Pred_Index(Ipred-1,Ichan),Ispecies)
c             write(*,*)x(level-1,Pred_Index(Ipred-1,Ichan),Ispecies)
             Sum = Sum + Bx
     &           *(x(level  ,Pred_Index(Ipred-1,Ichan),Ispecies)+
     &           x(level-1,Pred_Index(Ipred-1,Ichan),Ispecies))/2.
c             write(*,*)'Second part If Sum = ', Sum
	    EndIf
c            write(*,*)'Line 1446 Sum = ', Sum
           EndDo
           If(K2 .eq. 1 )then     
            sum=sum*(ww(1)-average_absorber(level))/(ww(1)-ww(0))
c           print*,ispecies,i,ww(1),average_absorber(level),ww(0)
           end if

	   Kp(level,Jchan,Ispecies) = max(Sum,0.0)

  200    Continue

c        write(*,*)'Line 1418'

*	Compute optical Depth

         Do level = 1 , Mlevel
	  OD(level,Jchan,Ispecies)=
     &		Dp(Level,Ispecies)*kp(level,Jchan,Ispecies) 
	 EndDo

  300   Continue ! Jchan

	EndDo    ! Profiles
c        write(*,*)'End of subr Optran_species '

	Return
	End
      SUBROUTINE PLNCX(PRAD,KCHAN,PTEMP,KNCHPF,KSAT)
C
C**** *PLNCX* -  ATMOSPHERIC TEMPS TO PLANCK FUNCTIONS IN MANY CHANNELS.
C
C     PURPOSE.
C     --------
C          TO CONVERT AN ARRAY OF ATMOSPHERIC TEMPERATURES
C          TO PLANCK FUNCTIONS IN MANY CHANNELS
C
C**   INTERFACE.
C     ----------
C          *CALL* *PLNCX(PRAD,KCHAN,PTEMP,KNCHPF,KSAT)*
C               *PRAD*  -  OUTPUT ARRAY OF RADIANCES
C               *KCHAN* -  INPUT ARRAY OF CHANNEL INDICES FOR EACH RAD
C               *PTEMP* -  INPUT ARRAY OF ATMOSPHERIC TEMPS (CHANS*PROFS)
C               *KNCHPF* - INPUT NUMBER OF RADIANCES (CHANS * PROFS).
C               *KSAT*   - INPUT SATELLITE INDEX.
C
C     METHOD.
C     -------
C          SEE REFERENCES.
C
C     EXTERNALS.
C     ----------
C          NONE.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        6/12/90.
C
C     MODIFICATIONS.
C     --------------
C          12/8/92.  FOR VERSION 2.  INPUT SATELLITE INDEX AND TEMPS
C                    AS VECTOR OF (CHANS*PROFS).
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'tovchn.h'
C
      REAL PRAD(*),PTEMP(*)
      INTEGER KCHAN(*)
C
C     -----------------------------------------------------------------
C*         1.   CALCULATE PLANCK FUNCTIONS.
C               --------- ------ ---------
 100  CONTINUE
c      write(*,*)'subr PLNCX KNCHPF= ',knchpf
      DO 110 J=1,KNCHPF
           ICHAN=KCHAN(J)
           TC1(ICHAN,KSAT) = 0.
           TC2(ICHAN,KSAT) = 1.
c         write(*,*)BCON1(ICHAN,KSAT),BCON2(ICHAN,KSAT)
           ZTEFF=TC1(ICHAN,KSAT)+TC2(ICHAN,KSAT)*PTEMP(J)
           PRAD(J)=BCON1(ICHAN,KSAT)/(EXP(BCON2(ICHAN,KSAT)/ZTEFF)-1.)
 110  CONTINUE
C
C     -----------------------------------------------------------------
C
      RETURN
      END
	Subroutine Precip_Water_Profile(Q,P,ZA,N,Pw)
C
C************************************************************************
C*									*
C*	Module Name:	Precip_Water_Profile				*
C*									*
C*	Language:	Fortran-77	   Library:			*
C*	Version.Rev:	1.0 30 April 96	Programmer: Kleespies		*
C*									*
C*	Calling Seq:	Call Precip_Water_Profile(Q,P,Za,N,Pw)		*
C*									*
C*	Description:	Computes precipitable water profilefrom a mixing*
C*			ratio profile and a pressure profile, along	*
C*			a slant path.					*
C*									*
C*			This code largely lifted from RADCOM.		*
C*									*
C*	Input Args:	R 	Q(N)	Mixing ratio profile		*
C*			R	P(N)	Pressure profile		*
C*			R	ZA	Zenith Angle			*
C*			R	N	Number of points in profile	*
C*									*
C*	Output Args:	R	Precipitable Water profile		*
C*									*
C*	Common Blks:	None						*
C*									*
C*	Include:	NOne						*
C*									*
C*	Externals:	None						*
C*									*
C*	Data Files:	None						*
C*									*
C*	Restrictions:	Q,P,Pw dimensioned in calling routine.		*
C*									*
C*	Error Codes:	None						*
C*									*
C*	Error Messages:	None						*
C*									*
C************************************************************************
C
	Implicit NONE

*	Input
	Real Q(*),P(*),ZA
	Integer N

*	Output
	Real Pw(*)
	Real Path 
	Real CGrav 
	Data CGrav / 5.098581e-4 / ! .5/980.665
	Real Delp

	Real DTR 
	Data DTR /1.7453292519943296E-02/
	Integer i	! local variables

	Path = CGrav / Cos(ZA*DTR)

	Pw(1) = 0.0
	
	Do i = 2 , N
	 Delp = Abs(P(i) - P(i-1))
	 Pw(i) = Pw(i-1) + Path*(Q(i) + Q(i-1))*Delp
	EndDo

	Return
	End
      SUBROUTINE PRFIN(KNPF,KLAPF,KNAV,KNSAV,KNSSV,KNCV,
     *                 PPRES,PANGL,PANGS,PANGA,KCLD,KSURF,KSAT,
     *                 PAV,PSAV,PSSV,PCV,qpw,o3pw,
     *                 KFLCW)
C
C**** *PRFIN* - SETS UP PROFILE VARIABLES FOR *RT* CALCULATIONS.
C
C     PURPOSE.
C     --------
C          TO SET UP PROFILE-DEPENDENT VARIABLES FOR SUBSEQUENT
C          *RT* CALCULATIONS BY OTHER SUBROUTINES OF RTATOV.
C
C**   INTERFACE.
C     ----------
C    *CALL*     *PRFIN(KNPF,KLAPF,KNAV,KNSAV,KNSSV,KNCV,*
C    *                 PPRES,PANGL,PANGS,PANGA,KCLD,KSURF,KSAT,    *
C    *                 PAV,PSAV,PSSV,PCV,      *
C    *                 PSQQ,PXXM,PXXW,PXXO,PXXCW,KFLCW) *
C               *KNPF*  -  INPUT NUMBER OF PROFILE VECTORS
C               *KLAPF* -  INPUT LENGTH OF EACH ATM PROFILE VECTOR
C               *KNAV*  -  INPUT NO. OF ATMOSPHERIC PROFILE VARIABLES
C               *KNSAV* -  INPUT NO. OF SURFACE AIR VARIABLES
C               *KNSSV* -  INPUT NO. OF SURFACE SKIN VARIABLES
C               *KNCV*  -  INPUT NO. OF CLOUD VARIABLES
C               *PPRES* -  INPUT PRESSURE LEVELS OF ATM PROFILE
C               *PANGL* -  INPUT SAT NADIR ANGLE FOR EACH PROFILE
C               *PANGS* -  INPUT SOLAR ZENTIH ANGLE FOR EACH PROFILE
C               *PANGA* -  INPUT AZIMUTH ANGLE BETWEEN SOLAR AND VIEW DIRN.
C               *KCLD*  -  INPUT INDEX OF CLOUD TYPE.
C               *KSURF* -  INPUT SURFACE TYPE INDEX FOR EACH PROFILE.
C               *KSAT*  -  INPUT SATELLITE INDEX.
C               *PAV*   -  INPUT ATM PROFILE VARIABLES
C               *PSAV*  -  INPUT SURFACE AIR VARIABLES
C               *PSSV*  -  INPUT SURFACE SKIN VARIABLES
C               *PCV*   -  INPUT CLOUD VARIABLES
C               *KFLCW*  - OUTPUT FLAG TO SWITCH ON CLOUD WATER CALC.
C          ALSO PUTS OUTPUTS IN *COMMON*S * /GEOPTH/, /SURF/, /PRFVAR/,*
C          * /IRCLD/ *.
C
C     METHOD.
C     -------
C          SEE REFERENCES.
C
C     EXTERNALS.
C     ----------
C          PRSLEV:  FINDS PARAMS LOCATING A GIVEN PRESSURE ON AN ARRAY
C                   OF FIXED PRESSURE LEVELS
C          PRFTAU:  SETS UP PROFILE VARIABLES FOR OPTICAL DEPTH CALCS.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        6/12/90.
C
C     MODIFICATIONS.
C     --------------
C          12/8/92.  FOR VERSION 2.  MOVES OUTPUTS TO ARGUMENTS.
C          23/6/93.  FOR RTATOV
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'geocon.h'
       include 'geopth.h'
       include 'surf.h'
       include 'prfvar.h'
       include 'ircld.h'
C
      integer kp1
      Real qpw(42),o3pw(42)
      REAL PPRES(jplapf,*),PANGL(*),PANGS(*),PANGA(*)
      INTEGER KSURF(*),KCLD(*),klapf(*)
      REAL PAV(JPLAPF,JPNAV,*),PSAV(JPNSAV,*),
     *PSSV(JPNSSV,*),PCV(JPNCV,*)
      DATA DTR/0.0174533/           ! DEGS TO RADS = PI/180
      DATA ZANGMX/89./,ZPTHMX/1.0E6/
      DATA ZTOTOC/476207./   ! = 4.670E6/9.80665 =
C                            ! CONVERTS HPA*(KG/KG) TO DOBSON UNITS
C
C     -----------------------------------------------------------------
C*         1.   SET UP PROFILE-DEPENDENT 'KNOWN' QUANTITIES.
C               --- -- ----------------- ------- ----------
 100  CONTINUE
C
C*         1.1  SATELLITE AND SOLAR GEOMETRY.
C
      DO 110 J=1,KNPF
           ZA=SIN(PANGL(J)*DTR)*RATOE(KSAT)
           XPATH(J)=1./SQRT(1.-ZA*ZA)         ! VIEW ANGLE PATH FACTOR
           SQTPTH(J)=SQRT(XPATH(J))           ! .. AND ITS SQUARE ROOT
           XPATH1(J)=XPATH(J)-1.              ! .. AND PATH FACTOR - 1
C
           IF (PANGS(J).LE.ZANGMX) THEN
                XPATHS(J)=1./COS(PANGS(J)*DTR)     ! SOLAR PATH FACTOR
           ELSE                          ! IF SUN NEAR/BELOW HORIZON,
                XPATHS(J)=ZPTHMX         ! SET TO VERY LARGE VALUE
           ENDIF
           XAZIMS(J)=COS(PANGA(J)*DTR)
 110  CONTINUE
C
C*         1.2  SET UP SURFACE TYPE INFO.
C
      DO 120 J=1,KNPF
           NSTYP(J)=KSURF(J)
 120  CONTINUE
C
C*         1.3  SET UP CLOUD TYPE INFO.
C
      DO 130 J=1,KNPF
           NCTYP(J)=KCLD(J)
 130  CONTINUE
C
C     -----------------------------------------------------------------
C*         2.   UNPACK PROFILE VECTOR.
C               ------ ------- ------
 200  CONTINUE
      DO 230 J=1,KNPF
           Do 205 jl=1,klapf(j)
                prsr(jl,j)=ppres(jl,j)
 205       Continue
           DO 210 JL=1,KLAPF(j)
                TEMP(JL,J)=PAV(JL,1,J)
 210       CONTINUE
           DO 220 JL=1,KLAPF(j)
c                WMIX(JL,J)=PAV(JL,2,J)
                pw(jl,j) = qpw(jl)
                WMIX(JL,J)=PAV(JL,2,J)*1000.   ! scale kg/kg to g/kg
 220       CONTINUE
           DO 223 JL=1,KLAPF(j)
c                OMIX(JL,J)=PAV(JL,3,J)
                toto(jl,j) = o3pw(jl) 
                OMIX(JL,J)=PAV(JL,3,J)*1000.   ! scale to optran units
 223       CONTINUE
           DO 226 JL=1,KLAPF(j)
                CLW(JL,J)=PAV(JL,4,J)          ! KG/KG 
 226       CONTINUE
 230  CONTINUE
      KFLCW=0
      DO 235 J=1,KNPF
           DO 234 JL=1,KLAPF(j)
                IF (CLW(JL,J).GT.0.) KFLCW=1
 234       CONTINUE
 235  CONTINUE
      DO 240 J=1,KNPF
!        put surface air values at end of atmos profile
           jl = klapf(j)+1
           prsr(jl,j) = psav(1,j)
           temp(jl,j) = psav(3,j)
           wmix(jl,j) = psav(4,j)*1000.
c           wmix(jl,j) = psav(4,j)
           pw(jl,j) = qpw(jl)
           omix(jl,j) = psav(5,j)*1000.
c           omix(jl,j) = psav(5,j)
           toto(jl,j) = o3pw(jl)
c           toto(jl,j) = omix(jl,j)
c           wmix(jl,j) = psav(4,j)*1000.
c           omix(jl,j) = psav(5,j)*1000.
           SURFP(J)=PSAV(1,J)
           SURFW(J)=PSAV(2,J)
           TA(J)=PSAV(3,J)
c           OMIXS(J)=PSAV(5,J)
c           WMIXS(J)=PSAV(4,J)
           WMIXS(J)=PSAV(4,J)*1000.
           OMIXS(J)=PSAV(5,J)*1000.
           CLWS(J)=PSAV(6,J)
           TS(J)=PSSV(1,J)
           EMSMW(1,J)=PSSV(2,J)
           EMSMW(2,J)=PSSV(3,J)
           EMSMW(3,J)=PSSV(4,J)
           EMSMW(4,J)=PSSV(5,J)
           EMSIR(J)=PSSV(6,J)
           CLDF(J)=PCV(1,J)
           CLDPT(J)=PCV(2,J)
           CLDPB(J)=PCV(3,J)
           CLDER(J)=PCV(4,J)
 240  CONTINUE
C
C     -----------------------------------------------------------------
C*         3.   SET RELATED PROFILE PARAMETERS.
C               --- ------- ------- ----------
 300  CONTINUE
C
C*         3.1  EXTRAPOLATE UPPER LEVEL HUMIDITY.
C
C     CALL EXTHUM(KNPF)                          ! NO LONGER DONE HERE
C
C*         3.2  SET SURFACE PRESSURE PARAMETERS.
C
      CALL PRSLEV(SURFP,NLVSF,FRCPS,KNPF,KLAPF,PPRES)
C
C*         3.3  SET CLOUD PRESSURE PARAMETERS.
C
      CALL PRSLEV(CLDPT,NLVCT,FRCPT,KNPF,KLAPF,PPRES)
      CALL PRSLEV(CLDPB,NLVCB,FRCPB,KNPF,KLAPF,PPRES)
C
C*         3.4  INTEGRATE OZONE and moisture PROFILE.
C               (DOWN TO LOWEST PRESSURE LEVEL FOR CONSISTENCY)
c      DO 320 J=1,KNPF
c        kp1 = Klapf(j)+1
c       Call Precip_Water_Profile(
c     &		wmix(1,j),prsr(1,j),0.0,kp1,  pw(1,j))
c	Call Precip_Water_Profile(
c     &		omix(1,j),prsr(1,j),0.0,kp1,toto(1,j))
c 320  CONTINUE
C
C     -----------------------------------------------------------------
C*         4.   SET UP PROFILE VARIABLES FOR TRANSMITTANCE CALC.
C               --- -- ------- --------- --- ------------- ----
      write(*,*)'Finish Call Subr PRFIN '
 400  CONTINUE
!        done internally in optrans
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE PRSLEV(PRES,KLEV,PFRAC,KNPF,KLAPF,PPRES)
C
C**** *PRSLEV* - LOCATE GIVEN PRESSURES ON ARRAY OF FIXED LEVELS.
C
C     PURPOSE.
C     --------
C          FINDS THE INDICES AND FRACTIONAL LEVELS LOCATING
C          GIVEN PRESSURES ON AN ARRAY OF FIXED PRESSURE LEVELS.
C
C**   INTERFACE.
C     ----------
C          *CALL* *PRSLEV(PRES,KLEV,PFRAC,KNPF,KLAPF,PPRES)
C               *PRES*  -  INPUT ARRAY OF PRESSURES TO BE LOCATED
C               *KLEV*  -  OUTPUT ARRAY OF LEVEL INDICES (NEAREST
C                          LEVELS .GE. GIVEN PRESSURES)
C               *PFRAC* -  OUTPUT ARRAY OF FRACTIONS BY WHICH GIVEN
C                          PRESSURES ARE BETWEEN LEVEL KLEV AND
C                          ADJACENT LEVEL OF LOWER PRESSURE
C               *KNPF*  -  INPUT NO. OF PRESSURES TO BE PROCESSED.
C               *KLAPF* -  INPUT LENGTH OF ATMOSPHERIC PROFILE VECTOR.
C               *PPRES* -  INPUT ARRAY OF PRESSURE LEVELS.          .
C          EXCEPTION: IF PRESSURE GREATER THAN HIGHEST VALUE IN FIXED
C          LEVELS, SET *KLEV*=LAST LEVEL, AND THEN *PFRAC* IS NEGATIVE.
C
C     METHOD.
C     -------
C          LINEAR INTERPOLATION IN PRESSURE.
C
C     EXTERNALS.
C     ----------
C          NONE.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        6/12/90.
C
C     MODIFICATIONS.
C     --------------
C          15/6/93.  RTATOV.
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
        include 'cparam.h'
      REAL PRES(*),PFRAC(*),PPRES(jplapf,*)
      INTEGER KLEV(*),klapf(*)
      integer jk
C
C     -----------------------------------------------------------------
C*         1.   FIND NEAREST LEVEL AND CALCULATE FRACTIONAL PRESSURE.
C               ---- ------- ----- --- --------- ---------- --------
 100  CONTINUE
      DO 120 J=1,KNPF
           jk = klapf(j)
           DO 110 JL=jk,2,-1
                IF (PRES(J).GT.PPRES(JL,j)) THEN
                     ILEV=MIN((JL+1),jk)
                     KLEV(J)=ILEV
                     PFRAC(J)=(PPRES(ILEV,j)-PRES(J))/(PPRES(ILEV,j)-
     *                         PPRES(ILEV-1,j))
                     GOTO 115
                ENDIF
 110       CONTINUE
 115       CONTINUE
 120  CONTINUE
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE RTATOV(KNPF,KLAPF,KNAV,KNSAV,KNSSV,KNCV,
     *                  PPRES,PANGL,PANGS,PANGA,KCLD,KSURF,
     *                  KSAT,KNCHPF,KCHAN,KPROF,
     *                  PAV,PSAV,PSSV,PCV,ppw,qpw,o3pw,
c     *                  PAV,PSAV,PSSV,PCV,
     *                  PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,
     *                  PTAU,PTAUS)
C
C**** *RTATOV* - FAST *RT* MODEL FOR ATOVS.
C
C     PURPOSE.
C     --------
C          TO COMPUTE MULTI-CHANNEL ATOVS RADIANCES AND BRIGHTNESS
C          TEMPERATURES FOR MANY PROFILES.
C
C**   INTERFACE.
C     ----------
C    *CALL*     *RTATOV(KNPF,KLAPF,KNAV,KNSAV,KNSSV,KNCV,   *
C    *                  PPRES,PANGL,PANGS,PANGA,KCLD,KSURF, *
C    *                  KSAT,KNCHPF,KCHAN,KPROF,            *
C    *                  PAV,PSAV,PSSV,PCV,                  *
C    *                  PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,     *
C    *                  PTAU,PTAUS)                         *
C          INPUT CONSTANTS:
C               *KNPF*  -  NUMBER OF PROFILE VECTORS
C               *KLAPF*  - LENGTH OF EACH PROFILE VECTOR, length knpf
C               *KNAV*   - NUMBER OF ATMOSPHERIC PROFILE VARIABLES
C                    CURRENTLY 4:   TEMPERATURE (K)
C                                   SPECIFIC HUMIDITY (KG/KG)
C                                   OZONE MIXING RATIO (KG/KG)
C                                   LIQUID WATER CONTENT (KG/KG)
C                    [LATER: ICE WATER, PRECIP, AEROSOL, .. ?]
C               *KNSAV*  - INPUT NUMBER OF SURFACE AIR VARIABLES
C                    CURRENTLY 6:   PRESSURE (HPA)
C                                   WIND SPEED (10M-NEUTRAL) (M/S)
C                                   TEMPERATURE (K)
C                                   SPECIFIC HUMIDITY (KG/KG)
C                                   OZONE MIXING RATIO (KG/KG)
C                                   LIQUID WATER CONTENT (KG/KG)
C               *KNSSV*  - INPUT NUMBER OF SURFACE SKIN VARIABLES
C                    CURRENTLY 6:   TEMPERATURE (K)
C                                   4 * MW SURFACE EMISS PARAMS (GRODY MODEL)
C                                   1 * IR SURFACE EMISS PARAM (NOT YET USED)
C               *KNCV*   - INPUT NUMBER OF CLOUD VARIABLES
C                    CURRENTLY 4:   IR FRACIONAL CLOUD COVER
C                                   CLOUD TOP PRESSURE (HPA)
C                                   CLOUD BASE PRESSURE (HPA)
C                                   CLOUD EFF. DROP RADIUS (M) (NOT YET USED)
C               *PANGL* -  SATELLITE NADIR VIEW ANGLES (DEG)
C                          (SIZE=KNPF)
C               *PANGS* -  SOLAR ZENITH ANGLES AT SURFACE (DEG)
C                          (SIZE=KNPF)
C               *PANGA* -  AZIMUTH ANGLE BETWEEN SOLAR AND VIEW DIRECTIONS
C                          (SIZE=KNPF)
C               *KCLD*  -  INDEX OF CLOUD TYPE.
C                          (SIZE=KNPF)
C               *KSURF* -  SURFACE TYPE INDICES
C                          (SIZE=KNPF)
C               *KSAT* -   SATELLITE INDEX
C               *KNCHPF* - NUMBER OF RADIANCES (=CHANS*PROFS USED)
C               *KCHAN* -  ARRAY OF CHANNEL INDICES
C                          (SIZE=KNCHPF)
C                   FOR TOVS: INDEX 1-27 = HIRS 1-20, MSU 1-4, SSU 1-3
C                   FOR ATOVS: INDEX 1-40 = HIRS 1-20, AMSU 1-4
C               *KPROF* -  ARRAY OF PROFILE INDICES
C                          (SIZE=KNCHPF)
C          INPUT VARIABLES:
C               *PPRES* -  PRESSURE LEVELS OF ATM PROF VECTOR (HPA)
C                          (SIZE=jplapf,knpf)
C               *PAV*  -   ARRAYS OF ATMOSPHERIC PROFILE VARIABLES
C                          (SIZE=KLAPF,KNAV,KNPF)
C               *PSAV* -   ARRAYS OF SURFACE AIR VARIABLES
C                          (SIZE=KNSAV,KNPF)
C               *PSSV* -   ARRAYS OF SURFACE SKIN VARIABLES
C                          (SIZE=KNSSV,KNPF)
C               *PCV*  -   ARRAYS OF CLOUD VARIABLES
C                          (SIZE=KNCV,KNPF)
C          OUTPUT VARIABLES:
C               *PRD*   -  ARRAY OF RADIANCES (MW/M**2/SR/CM**-1)
C                          (SIZE=KNCHPF)
C               *PTB*  -   ARRAY OF BRIGHTNESS TEMPERATURES (K)
C                          (SIZE=KNCHPF)
C               *PRDOV* -  OVERCAST RADIANCES AT EACH FIXED PRESS LEVEL
C                          (SIZE=KNCHPF,KLAPF)
C               *PRDO*  -  OVERCAST RADIANCES AT GIVEN CLOUD-TOP PRESSURE
C                          (SIZE=KNCHPF)
C               *PRDCL* -  CLEAR COLUMN RADIANCES
C                          (SIZE=KNCHPF)
C               *PTBCL* -  CLEAR COLUMN BRIGHTNESS TEMPERATURES
C                          (SIZE=KNCHPF)
C               *PTAU*  -  TRANSMITTANCES FROM EACH FIXED PRESSURE LEVEL
C                          (SIZE=KNCHPF,KLAPF)
C               *PTAUS* -  TRANSMITTANCES FROM SURFACE
C                          (SIZE=KNCHPF)
C
C     METHOD.
C     -------
C          SEE REFERENCE.
C
C     EXTERNALS.
C     ----------
C          *PRFIN*: SETS UP PROFILE VARIABLES
C          *OPDEP*: CALCULATES OPTICAL DEPTHS
C          *RTTAU*: CALCULATES TRANSMITTANCES ON *RT* MODEL LEVELS
C          *RTINT*: PERFORMS INTEGRATION OF *RT* EQUATION.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176 (FOR TOVS)
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*       23/06/93.
C
C     MODIFICATIONS.
C     --------------
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
       include 'cparam.h'
       include 'prfvar.h'
C
       include 'constants.inc'
       include 'opcom.inc'

      REAL PPRES(jplapf,*),PANGL(*),PANGS(*),PANGA(*)
      INTEGER KSURF(*),KCHAN(*),KPROF(*),KCLD(*),klapf
      REAL PAV(JPLAPF,KNAV,*),PSAV(JPNSAV,*),PSSV(JPNSSV,*),PCV(JPNCV,*)
      REAL PRD(*),PTB(*),PRDOV(JPCHPF,*),PRDO(*),PRDCL(*),PTBCL(*)
      REAL PTAU(JPCHPF,*),PTAUS(*)
C
      REAL ZB(JPCHPF,JPLAPF),ZBA(JPCHPF),ZBS(JPCHPF)
      REAL ZBDT(JPCHPF,JPLAPF),ZBDTR(JPCHPF,JPLAPF),ZFCLD(JPCHPF)
      REAL ZEMS(JPCHPF)

      Real p(jplapf,jppf),t(jplapf,jppf)
      Real precipw(jplapf,jppf),oz(jplapf,jppf)
      Real angle(jppf)
      Real tau(jpchpf,0:jplapf)
      Real ppw(42),qpw(42),o3(42)

      Integer Nchannel    ! number of channels
C     -----------------------------------------------------------------
C*         1.   SET UP PROFILE VARIABLES.
C               --- -- ------- ---------
 100  CONTINUE
      CALL PRFIN(KNPF,KLAPF,KNAV,KNSAV,KNSSV,KNCV,
     *           PPRES,PANGL,PANGS,PANGA,KCLD,KSURF,KSAT,
     *           PAV,PSAV,PSSV,PCV,qpw,o3pw,
c     *           PAV,PSAV,PSSV,PCV,
     *           IFLCW)
C
C     -----------------------------------------------------------------
C*         2.   CALCULATE OPTICAL DEPTHS.
C               --------- ------- ------
 200  CONTINUE
!                done internally in optran
C
C     -----------------------------------------------------------------
C*         3.   CALCULATE TRANSMITTANCES ON profile LEVELS.
C               --------- -------------- -- ------- ------
 300  CONTINUE
!        note that optran likes the surface air parameters with the profile
!        so prsr,temp,pw,toto are all of length klapf+1.

	Do jk = 1, knpf
	  angle(jk) = pangl(jk)
	  do j = 1 , klapf+1
	   p(j,jk) = prsr(j,jk)
	   t(j,jk) = temp(j,jk)
	   precipw(j,jk) = pw(j,jk)
	   oz(j,jk) = toto(j,jk)
	  EndDo
	Enddo

*************This next line must be active for actual usage******ZZ
	Find_Levels = .True.
        Nchannel = knchpf / knpf
c        write(*,*)'subr rtatov Nchannel = ', Nchannel
c        do j = 1, Nchannel
c          write(3,*)kchan(j)
c        enddo
c        write(*,*)'call sub Optrans from subr Rtatov'
        Call Optrans(knpf,klapf,p,t,wmix,ppw,precipw,oz,
     &		     angle,nchannel,kchan,tau)
c        Call Optrans(knpf,klapf,p,t,wmix,precipw,oz,
c     &		     angle,nchannel,kchan,tau)
	Find_Levels = .False.
        Do jk = 1 , knpf
         Do j = 1 , nchannel
          ptaus(jk+j-1) = tau(jk+j-1,klapf+1)
	  Do jl = 1 , klapf
	   ptau(jk+j-1,jl) = tau(jk+j-1,jl)
	  EndDo
	 EndDo
	EndDo

C
C     -----------------------------------------------------------------
C*         4.   INTEGRATE *RT* EQUATION.
C               --------- ---- --------
 400  CONTINUE
      write(*,*)' begin to call subr RTINT'
      CALL RTINT(KLAPF,KCHAN,KPROF,KSAT,KNCHPF,
     *           PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,PTAU,PTAUS,
     *           ZEMS,ZB,ZBA,ZBS,ZBDT,ZBDTR,ZFCLD)
c      kzem21 = zems(20)
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE RTINT(KLAPF,KCHAN,KPROF,KSAT,KNCHPF,
     *PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,PTAU,PTAUS,
     *PEMS,PB,PBA,PBS,PBDT,PBDTR,PFCLD)
C
C**** *RTINT* - PERFORMS INTEGRATION OF *RT* EQUATION IN RTTOV.
C
C     PURPOSE.
C     --------
C          TO PERFORM INTEGRATION OF RADIATIVE TRANSFER EQUATION
C          IN RTTOV SUITE, CALCULATING RADIANCES AND BRIGHTNESS
C          TEMPERATURES.
C
C**   INTERFACE.
C     ----------
C    *CALL*     *RTINT(KLAPF,KCHAN,KPROF,KSAT,KNCHPF,*
C    *PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,PTAU,PTAUS,     *
C    *PEMS,PB,PBA,PBS,PBDT,PBDTR,PFCLD)              *
C               *KLAPF* -  INPUT LENGTH OF ATMOSPHERIC PROFILE VECTOR
C               *KCHAN* -  INPUT ARRAY OF CHANNEL INDICES FOR EACH RAD
C               *KPROF* -  INPUT ARRAY OF PROFILE INDICES FOR EACH RAD
C               *KSAT* -   INPUT SATELLITE INDEX
C               *KNCHPF* - INPUT NUMBER OF RADIANCES (CHANS * PROFS)
C               *PRD*   -  OUTPUT ARRAY OF RADIANCES
C               *PTB*  -   OUTPUT ARRAY OF BRIGHTNESS TEMPERATURES
C               *PRDOV* -  OUTPUT OVERCAST RADS FOR CLOUD AT EACH STD P LEVEL
C               *PRDO* -   OUTPUT OVERCAST RADS FOR GIVEN CLOUD-TOP PRESSURES
C               *PRDCL* -  OUTPUT CLEAR COLUMN RADIANCES
C               *PTBCL* -  OUTPUT CLEAR COLUMN BRIGHTNESS TEMPERATURES IN K
C               *PTAU*  -  INPUT TRANSMITTANCES FROM EACH LEVEL TO SPACE
C                          (CHANS*PROFS, STD PRESS LEVELS)
C               *PTAUS* -  INPUT TRANSMITTANCES FROM SURFACE TO SPACE
C               *PEMS* -   OUTPUT SURFACE EMISSIVITIES (CHANS*PROFS)
C               *PB*   -   OUTPUT PLANCK FUNCTIONS FOR TEMPERATURES PROFILES
C                          (CHANS*PROFS, STD PRESS LEVELS)
C               *PBA*  -   OUTPUT PLANCK FUNTIONS FOR SURFACE AIR TEMPERATURES
C               *PBS*  -   OUTPUT PLANCK FUNTIONS FOR SURFACE SKIN TEMPERATURES
C               *PBDT* -   OUTPUT: STORES UPWELLING RADIATION FROM ATMOSPHERE
C                          ABOVE EACH LEVEL.
C               *PBDTR* -  OUTPUT: STORES DOWNWELLING RADIATION AT EACH LEVEL
C                          FROM ATMOSPHERE ABOVE
C               *PFCLD* -  OUTPUT EFFECTIVE FRACTIONAL CLOUD COVER (CHANS*PROFS)
C          INPUT ALSO FROM *COMMON*S * /PRFVAR/, /IRCLD/.*
C
C     METHOD.
C     -------
C          SEE REFERENCES.
C
C     EXTERNALS.
C     ----------
C          PLNCX:  CALCUATES PLANCK FUNCTIONS FOR ARRAY OF TEMPERATURES
C          EMISS:  SETS UP EMISSIVITY ARRAY FOR ALL CHANNELS*PROFILES
C          BRIGV:  CONVERTS RADIANCES TO BR. TEMPS FOR AN ARRAY OF
C                  CHANNELS*PROFILES.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        25/06/91.
C
C     MODIFICATIONS.
C     --------------
C          13/8/92.  FOR VERSION 2.  MOVE BIG ARRAYS OUT OF COMMON.
C          16/6/93.  RTATOV.
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'ircld.h'
       include 'prfvar.h'
       include 'surf.h'
C
      REAL PRD(*),PTB(*),PRDOV(JPCHPF,*),PRDO(*),PRDCL(*),PTBCL(*)
      REAL PTAU(JPCHPF,*),PTAUS(*)
      REAL PEMS(*),PB(JPCHPF,*),PBA(*),PBS(*)
      REAL PBDT(JPCHPF,*),PBDTR(JPCHPF,*),PFCLD(*)
      INTEGER KCHAN(*),KPROF(*)
      integer jlev,j
      REAL ZT(JPCHPF)
      DATA ZTAUMN/1.0E-8/
C
C     -----------------------------------------------------------------
C*         1.   SET UP PLANCK FUNCTIONS, ETC.
C               --- -- ------ ---------  ---
 100  CONTINUE
C
C*         1.1  CONVERT ALL TEMPERATURES TO PLANCK FUNCTIONS.
C
      DO 110 JLEV=1,KLAPF
           DO 105 J=1,KNCHPF
                ZT(J)=TEMP(JLEV,KPROF(J))
 105       CONTINUE
           CALL PLNCX(PB(1,JLEV),KCHAN,ZT,KNCHPF,KSAT)
 110  CONTINUE
C               SURFACE AIR AND SKIN TEMPERATURES
      DO 115 J=1,KNCHPF
           ZT(J)=TA(KPROF(J))
 115  CONTINUE
      CALL PLNCX(PBA,KCHAN,ZT,KNCHPF,KSAT)
      DO 117 J=1,KNCHPF
           ZT(J)=TS(KPROF(J))
 117  CONTINUE
      CALL PLNCX(PBS,KCHAN,ZT,KNCHPF,KSAT)
C
C*         1.2  SET UP SURFACE EMISSIVITIES.
C
      CALL EMISS(KCHAN,KPROF,KNCHPF,PEMS,KSAT)
C
C*         1.3  SET UP CLOUD FRACTIONAL COVERAGE
C               CURRENTLY: SAME FOR ALL IR CHANNELS, 0 FOR MW CHANNELS
C
      DO 130 J=1,KNCHPF
           IF (KCHAN(J).LE.JPHIR.OR.KCHAN(J).GT.(JPHIR+JPMSU)) THEN
                PFCLD(J)=CLDF(KPROF(J))
           ELSE
                PFCLD(J)=0.
           ENDIF
 130  CONTINUE
C
C     -----------------------------------------------------------------
C*         2.   ATMOSPHERIC CONTRIBUTION.
C               ----------- ------------
 200  CONTINUE
C               LAYER ABOVE TOP PRESSURE LEVEL
      DO 210 J=1,KNCHPF
           PBDT(J,1)=PB(J,1)*(1.-PTAU(J,1))      ! UPWARD
           PBDTR(J,1)=PBDT(J,1)/PTAU(J,1)        ! DOWNWARD
 210  CONTINUE
C               LAYERS BETWEEN STANDARD PRESSURE LEVELS
      DO 230 JLEV=2,KLAPF
           JLEV1=JLEV-1
           DO 220 J=1,KNCHPF
                ZBDT=0.5*(PB(J,JLEV)+PB(J,JLEV1))*
     *                      (PTAU(J,JLEV1)-PTAU(J,JLEV))
                PBDT(J,JLEV)=PBDT(J,JLEV1)+ZBDT
                IF (PTAU(J,JLEV).GT.ZTAUMN) THEN
                     ZBDTR=PBDTR(J,JLEV1)+
     *                      ZBDT/(PTAU(J,JLEV)*PTAU(J,JLEV1))
                ELSE
                     ZBDTR=PBDTR(J,JLEV1)
                ENDIF
                PBDTR(J,JLEV)=ZBDTR
 220       CONTINUE
 230  CONTINUE
C               NEAR-SURFACE LAYER + ADD UPWARD AND DOWNWARD PARTS
      DO 240 J=1,KNCHPF
           ILEV1=NLVSF(KPROF(J))-1
           IF (FRCPS(KPROF(J)).LT.0.) ILEV1=ILEV1+1
           ZBDT=0.5*(PBA(J)+PB(J,ILEV1))*(PTAU(J,ILEV1)-PTAUS(J))
           IF (PTAUS(J).GT.ZTAUMN) THEN
                ZBDTR=PBDTR(J,ILEV1)+ZBDT/(PTAU(J,ILEV1)*PTAUS(J))
           ELSE
                ZBDTR=PBDTR(J,ILEV1)
           ENDIF
           ZBDT=PBDT(J,ILEV1)+ZBDT
           PRDCL(J)=ZBDT+ZBDTR*(1.-PEMS(J))*PTAUS(J)*PTAUS(J)
 240  CONTINUE
C
C     -----------------------------------------------------------------
C*         3.   SURFACE CONTRIBUTION.
C               ------- ------------
 300  CONTINUE
      DO 310 J=1,KNCHPF
           PRDCL(J)=PRDCL(J)+PEMS(J)*PTAUS(J)*PBS(J)
 310  CONTINUE
C           *** SOLAR REFLECTION BY SURFACE COULD BE ADDED HERE
C
C     -----------------------------------------------------------------
C*         4.   CALCULATE OVERCAST RADIANCES.
C               --------- -------- ---------
 400  CONTINUE
C
C*         4.1  ADD CLOUD EMISSION TO GIVE OVERCAST RADS AT ALL LEVELS.
C               (AND STORE THEM ALL FOR POSSIBLE USE OUTSIDE
C                RTTOV, E.G. IN CLOUD FIRST-GUESS ROUTINE.)
C
       DO 410 JLEV=1,KLAPF
            DO 420 J=1,KNCHPF
                 PRDOV(J,JLEV)=PBDT(J,JLEV)+PB(J,JLEV)*PTAU(J,JLEV)
  420       CONTINUE
  410  CONTINUE
C               *** THIS ASSUMES BLACK (NON-REFLECTIVE) CLOUD.
C                   NON-BLACK CLOUD COULD BE ADDED AT THIS POINT
C                   QUITE EASILY, INCLUDING REFLECTION OF
C                   DOWNWELLING RADIATION STORED IN BDTR.
C
C*         4.2  INTERPOLATE TO GIVEN CLOUD-TOP PRESSURES.
C
       DO 430 J=1,KNCHPF
            IPROF=KPROF(J)
            ICLD=NLVCT(IPROF)
            ZFRAC=FRCPT(IPROF)
            PRDO(J)=PRDOV(J,ICLD)*(1.-ZFRAC)+PRDOV(J,ICLD-1)*ZFRAC
  430  CONTINUE
C
C     -----------------------------------------------------------------
C*         5.   CALCULATE (PARTLY) CLOUDY RADIANCES.
C               --------- -------- ------ ---------
 500  CONTINUE
       DO 510 J=1,KNCHPF
            PRD(J)=PRDCL(J)*(1.-PFCLD(J))+PRDO(J)*PFCLD(J)
  510  CONTINUE
C
C     -----------------------------------------------------------------
C*         6.   CONVERT RADIANCES TO BRIGHTNESS TEMPERATURES.
C               ------- --------- -- ---------- ------------
 600  CONTINUE
       CALL BRIGV(PTB,PRD,KCHAN,KNCHPF,KSAT)       !    CLOUDY
      CALL BRIGV(PTBCL,PRDCL,KCHAN,KNCHPF,KSAT)     !    CLEAR
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE RTTVI(KERR,KIDSAT,KNSAT)
C
C**** *RTTVI* - INITIALISATION ROUTINE FOR RTTOV.
C
C     PURPOSE.
C     --------
C          INITIALISATION FOR TOVS RT ROUTINE, RTTOV.
C          TO BE CALLED BEFORE FIRST CALL TO RTTOV.
C
C**   INTERFACE.
C     ----------
C          *CALL* *RTTVI(KERR,KIDSAT,KNSAT)*
C               *KERR*  -  ERROR FLAG, RETURNS *KERR.NE.*0 IF ERROR.
C               *KIDSAT* - INPUT ARRAY OF SATELLITES TO BE PROCESSED
C                          TIROS-N=5, NOAA-6=6, NOAA-7=7, ETC
C               *KNSAT* -  NUMBER OF SATELLITES TO BE PROCESSED
C          PUTS OUTPUT IN *COMMON*S * /PRFCON/, /EMISIR/, /GEOCON/ *
C
C     METHOD.
C     -------
C          SEE REFERNCES.
C
C     EXTERNALS.
C     ----------
C          AIRSCF  -  INITIALISES SATELLITE-SPECIFIC DATA.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        10/01/91.
C
C     MODIFICATIONS.
C     --------------
C          13/8/92.  FOR VERSION 2. INPUT SAT IDS REQUIRED AND
C                    STORE ONLY DATA FOR THESE.
c          06/7/93.  FOR RTATOV.
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'prfcon.h'
       include 'emisir.h'
       include 'geocon.h'
C
      REAL ZPRES(40)
c      REAL ZHTSAT(12)
      REAL ZHTSAT(1)
      INTEGER KIDSAT(*)
C          PRESSURE LEVELS FOR TRANSMITTANCE CALCULATION.
      DATA ZPRES/.1,.2,.5,1.,1.5,2.,3.,4.,5.,7.,
     *           10.,15.,20.,25.,30.,50.,60.,70.,85.,100.,
     *           115.,135.,150.,200.,250.,300.,350.,400.,430.,475.,
     *           500.,570.,620.,670.,700.,780.,850.,920.,950.,1000./
      DATA ZHTSAT/870./
C          INDICES DEFINING REGION OF WATER VAPOUR EXTRAPOLATION
      DATA ILEVW/20/
      DATA REARTH/6371.03/               ! RADIUS OF EARTH
      DATA IPLEV/41/,INDMAX/12/
c      DATA IPLEV/40/,INDMAX/12/
C
C     -----------------------------------------------------------------
C*         1.   SET UP PROFILE CONSTANTS.
C               --- -- ------- ---------
 100  CONTINUE
      KERR=0
C
C*         1.1  SET UP PRESSURE LEVEL CONSTANTS
      IF (IPLEV.NE.JPLEV) THEN
           KERR=1
           RETURN
      ENDIF
      DO 112 J=1,IPLEV
           XPRES(J)=ZPRES(J)
           XPRES2(J)=XPRES(J)*XPRES(J)
 112  CONTINUE
      DPRES(1)=XPRES(1)
      DO 114 J=2,IPLEV
           DPRES(J)=XPRES(J)-XPRES(J-1)
 114  CONTINUE
C
C*         1.2  SET UP IR EMISSIVITIES
C
      IF (KNSAT.GT.JPNSAT) THEN
           KERR=11
           RETURN
      ENDIF
      DO 126 JSAT=1,KNSAT
           DO 124 J1=1,JPST
                DO 122 J2=1,JPCH
                     EMSIR0(J2,J1,JSAT)=1.  ! TEMPORARY
C                                           ! FOR ALL SURF TYPES AND CHANS
 122            CONTINUE
 124       CONTINUE
 126  CONTINUE
C
C *        1.3  SET UP CONSTANTS FOR TRANSMITTANCE CALC.
C
      NLEVW=ILEVW         ! TOP LEVEL FOR WV TRANSMITTANCE CALC
C
C     -----------------------------------------------------------------
C*         2.   SET UP DATA FOR NEW SATELLITE.
C               --- -- ---- --- --- ---------
 200  CONTINUE
C
C*         2.1  SET UP SATELLITE GEOMETRY CONSTANTS
C
C               (SAT INDEX: TIROS-N=1, NOAA-6=2, ETC)
      DO 210 JSAT=1,KNSAT
           IF (JPISET.EQ.0) THEN
                ISAT=KIDSAT(JSAT)-4           ! FOR TOVS: SAT NO = 5-14
           ELSE IF (JPISET.EQ.1) THEN
                ISAT=KIDSAT(JSAT)-14          ! FOR ATOVS: SAT NO = 15+
           ELSE IF (JPISET.EQ.2) THEN         
                ISAT = 1                      ! FOR AIRS: SAT NO = 1
           ELSE
                KERR=20
                RETURN
           ENDIF
           IF (ISAT.GT.INDMAX) THEN
                KERR=21
                RETURN
           ENDIF
           HTSAT(JSAT)=ZHTSAT(ISAT)          ! SATELLITE HEIGHT
           RATOE(JSAT)=(REARTH+HTSAT(JSAT))/REARTH
 210  CONTINUE
C
C*         2.2  SET UP SATELLITE-SPECIFIC DATA
C
      IF (JPISET.EQ.0) THEN
           CALL TOVSCF(KERR,KIDSAT,KNSAT)     ! TOVS
      ELSE IF (JPISET.EQ.1) THEN
           CALL ATOVCF(KERR,KIDSAT,KNSAT)    ! ATOVS
      ELSE IF (JPISET.EQ.2) THEN
           CALL AIRSCF(KERR,KIDSAT,KNSAT)    ! AIRS
      ELSE
           KERR=22
           RETURN
      ENDIF
C
C     -----------------------------------------------------------------
C
      RETURN
      END
      SUBROUTINE AIRSCF(KERR,KIDSAT,KNSAT)
C
C**** *TOVCF* - INITIALISE SATELLITE-DEPENDENT DATA FOR TOVS.
C
C     PURPOSE.
C     --------
C          TO INITIALISE SATELLITE-DEPENDENT DATA AND COEFFICIENTS
C          FOR TOVS RT ROUTINES FOR ALL SATELLITES.
C
C**   INTERFACE.
C     ----------
C          *CALL* *AIRSCF(KERR,KIDSAT,KNSAT)*
C               *KERR*  -  ERROR FLAG, RETURNS *KERR.NE.*0 IF ERROR.
C               *KIDSAT* - INPUT ARRAY OF SATELLITES TO BE PROCESSED
C                          TIROS-N=5, NOAA-6=6, NOAA-7=7, ETC
C               *KNSAT* -  NUMBER OF SATELLITES TO BE PROCESSED
C          PUTS OUTPUT IN *COMMON*S * /PRFREF/,/TAUCFN/,/TOVCHN/,*
C          * /MSUFRQ/ *.
C
C     METHOD.
C     -------
C          SEE REFERENCES.
C
C     EXTERNALS.
C     ----------
C          NONE.
C
C     REFERENCE.
C     ----------
C          ECMWF TECH MEM 176.
C
C     AUTHOR.
C     -------
C          J.R.EYRE       *ECMWF*        10/12/90.
C
C     MODIFICATIONS.
C     --------------
C          18/09/91  CHANGED COEFF FILES FOR NOAA-12
C          13/08/92. FOR VERSION 2. STORE FOR REQUIRED SATS ONLY
C                    ADD SSU AND CHANGE CHANNEL INDICES TO:
C                    1-20 = HIRS 1-20, 21-24 = MSU 1-4, 25-27 = SSU 1-3
C
      IMPLICIT LOGICAL(L),CHARACTER*8(C)
C
C*    *COMMON*
C          SEE *COMMON* DECK.
       include 'cparam.h'
       include 'taucfn.h'
       include 'tovchn.h'
       include 'msufrq.h'
       include 'prfref.h'
C
	character*100 filename

      REAL ZHBUF(7113)
      INTEGER KIDSAT(*)
      DATA ZPEEDL/2.998E10/,ZPCON1/1.1911E-5/,ZPCON2/1.4388/
C          SPEED OF LIGHT IN CM/S  AND
C          PLANCK FUNCTION CONSTANTS IN MW/M**2/SR/CM**-1 AND K/CM**-1
      DATA IHIR/2371/
C        IHIR IS 2371 BECAUSE FILES HAVE RECORDS ONLY FOR CHANS 1-2371
      DATA IUHIR/13/       ! channel number for input air frequency,
C                          ! two constant in Planck function.
C               ---- -- ----- ---- ------- ----
C*         1.   READ IN OTHER AIRS CHANNEL DATA.
C               ---- -- ----- ---- ------- ----
c 400  CONTINUE
      DO 430 JSAT=1,KNSAT
       Open(unit=13,file='airs_wv_plck.dat',status='old')
        do i = 1, IHIR
           i2 = IHIR*2 + i
           i1 = IHIR*1 + i
           read(13,150)ZHBUF(i),ZHBUF(i1),ZHBUF(i2)
        enddo
c        do i = 1,2371
c           i1 = 2371 + i
c           i2 = 4742 + i
c           write(14,150)ZHBUF(i),ZHBUF(i1),ZHBUF(i2)
c        enddo
150     format(3f15.3)
C
C*         4.1  STORE HIRS PLANCK FUNCTION COEFFICIENTS.
C
      DO 410 JCH=1,IHIR
           WVNUM(JCH,JSAT)=ZHBUF(JCH)
           BCON1(JCH,JSAT)=ZHBUF(JCH+2371)
           BCON2(JCH,JSAT)=ZHBUF(JCH+4742)
           TC1(JCH,JSAT)= 0.0
           TC2(JCH,JSAT)= 1.0
 410  CONTINUE
C
C*         4.2  STORE HIRS GAMMAS
C
      DO 420 JCH=1,IHIR
           GAMMA(JCH,JSAT)= 1.0
 420  CONTINUE
 430  CONTINUE
      CLOSE(IUHIR)
C
C     -----------------------------------------------------------------
C
      RETURN

  999 continue
      write(6,*) 'open error ',ios,' on file'
      write(6,*) filename
      stop

      END
