*	Tests the radiance computation of RTATOV
c        subroutine trad(p,t,q,o3,ptb,ky,idsat,wspeed,tskin,
c     *          ccover,ptop,mis21)
       Implicit None

*	RTATOV Program constants
        Integer Idsat
	Integer KNPF 		! number of profile vectors
	Parameter (Knpf=1)
	Integer KLAPF 		! length of each profile vector
        Parameter (Klapf=42)
	Integer Knav 		! number of atmospheric variables,t,q,o3,clw
	Parameter (Knav=4)
	Integer Knsav 		! number of sfc air varibles
				! P,Wind speed,T,Q,O3,CLW
	Parameter (Knsav=6)
	Integer Knssv 		! number of surface skin variables
				! T, 4mw emiss, 1ir emiss
	Parameter (Knssv=6)
	Integer Kncv 		! number of could variables
				! IR fract cloud, top P, base P, Re
	Parameter (Kncv=4)
	
*	RTATOV Program variables

	Real Ppres(Klapf) 	! pressure profile
	Real Pangl(Knpf)	! angle
	Real Pangs(Knpf)	! solar zenith angle
	Real Panga(Knpf)	! relative solar azimuth angle
	Integer Kcld(Knpf)	! index of cloud type
	Integer Ksurf(Knpf)	! index of surface type
	Integer Ksat		! satellite index
	Integer Knchpf 		! number of channels (*number of profiles
	Parameter (Knchpf=2371)

	Integer Kchan(2371)	! Index of channels
c       Data Kchan
c     &   / 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,17,18,19,
c     &    21,22,23,24 /

	Integer Nchan 
	Data Nchan /2371/
	Integer Kprof(Knchpf)   ! array of profile indices
	Data Kprof
     &	 /Knchpf*1/

*	RTATOV input variables

	Real PAV(Klapf,Knav,Knpf) ! atmospheric profile variables
	Real Psav(Knsav,Knpf) 	  ! surface air variables
	Real Pssv(Knssv,knpf)	  ! surface skin variables
	Real Pcv(Kncv,Knpf)	  ! cloud variables

*	RTATOV output variables

	Real Prd(Knchpf)	! radiances
	Real Ptb(Knchpf)	! brightness temperatures
	Real Prdov(Knchpf,Klapf)! overcaset radiance profile
	Real Prdo(Knchpf)	! overcast radiance at cloud top
	Real Prdcl(Knchpf)	! clear column radiance
	Real Ptbcl(Knchpf)	! clear column brightness temperature
	Real Ptau(Knchpf,Klapf) ! transmittance profile
	Real Ptaus(Knchpf)	! surface to space transmittance

*	Local variables

CC
	Real P(42),T(42),q(42),O3(42) ! atmospheric stuff 
	Real Tau(Klapf)

CC
        Data P
     &  / .1,.2,.5,1.,1.5,2.,3.,4.,5.,7.,10.,15.,20.,25.,30.,    
     &  50.,60.,70.,85.,100.,115.,135.,150.,200.,250.,300.,350.,400.,     
     &  430.,475.,500.,570.,620.,670.,700.,780.,850.,920.,950.,1000.,     
     &  1025.,1050./

	Integer Ichan,Jchan,Iangle,Iatm,Level
	Integer Ierr

        Real Angle(5) 
        Data Angle /0.0, 36.869898, 48.189685, 55.150095, 60.0/
c        Real Angle(1) 
c        Data Angle / 0.0 /

        Integer Ngas,Igas
        Data Ngas / 3 /
        Real wvnum(2371,1)

        DO jchan = 1, Nchan
           kchan(jchan) = jchan
        enddo
         idsat = 1
c        if(ky.eq.1)then
	 Call Rttvi(Ierr,idsat,1) ! tovs
 	 If(Ierr .ne. 0) Then
          write(*,*)'Satellite ID number #', idsat
 	 Write(6,*) 'Rttvi error ',ierr
 	 Stop
 	 Endif
c        endif

!	Specify atmosphere
CC
       open(unit=3,file='airs_wv_plck.dat',status='old')
       do iatm=1,2371
         read(3,1222)wvnum(iatm,1)
1222     format(f15.3)
       enddo
       do Iatm = 1 , 1

        Call Ds32_mf(Iatm,T,q,o3,Iatm)
        write(*,*)'set main program variables'

CC
	 Do level = 1 , klapf
	  Pav(level,1,Knpf) = T(level) 
CC
	  Pav(level,2,Knpf) = q(level) /1000.
c 	  Pav(level,2,Knpf) = q(level) 
CC

        Pav(level,3,Knpf) = O3(level) /1000.
c        Pav(level,3,Knpf) = O3(level)
	  Pav(level,4,Knpf) = 0.0 ! clw sfc cloud liquid water
	  Ppres(level) = P(level)
	 EndDo

!	Specify surface air
CC
	 Psav(1,Knpf) = p(42) 
         Psav(2,Knpf) = 0.0 ! wind speed
CC
	 Psav(3,Knpf) = T(42)
	 Psav(4,Knpf) = q(42) / 1000.
         Psav(5,Knpf) = O3(42) / 1000.

	 Psav(6,Knpf) = 0.0 ! clw

!	Specify skin
CC
         Pssv(1,Knpf) = t(42)
	 Pssv(2,Knpf) = 0.6
	 Pssv(3,Knpf) = 0.6
	 Pssv(4,Knpf) = 120.7
	 Pssv(5,Knpf) = 1.184
	 Pssv(6,Knpf) = 1.0

! 	Specify Cloud
CC
	 Pcv(1,Knpf) = 0.
	 Pcv(2,Knpf) = 0.
	 Pcv(3,Knpf) = 0.
	 Pcv(4,Knpf) = 0.0

!	Do radiative transfer

	 Do Iangle = 1 , 1
C        Do Iangle = 1 , 5 
	  Pangl(Knpf) = Angle(Iangle)
	  Pangs(Knpf) = 0.0
	  Panga(Knpf) = 0.0
	  Kcld(Knpf) = 1
	  Ksurf(Knpf) = 1
	  Ksat = 1
	  Call RTATOV(KNPF,41,KNAV,KNSAV,KNSSV,KNCV,  
     *                PPRES,PANGL,PANGS,PANGA,KCLD,KSURF,     
     *                KSAT,NCHAN,KCHAN,KPROF,     
     *                PAV,PSAV,PSSV,PCV,     
     *                PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,     
     *                PTAU,PTAUS)

	 EndDo
         ENDDO
         do level=1,2371
           write(8,223)level,wvnum(level,1),ptb(level),ptaus(level)
223      format(i5,2f9.2,e14.6)
         enddo
	
	continue
	End
        subroutine ds32_mf(natm,t,w,o,iatm)

c Routine to read in the dependent set profile from a series of data
c  statements.  This is the Meteo-France dependent set of 32 profiles.

c Code received from Guy Rochard (via Pascal Brunel) 13-Oct-1995.

c Originally at 40 standard levels, the data were extrapolated 
c  linearly at the surface from 1000 to 1050mb to provide 42 levels.

c Created   : 13-Oct-1995 (from Meteo-France code)

c Arguments : natm - atmosphere number in set (1-32)
c                      [I*4 PASSED]

c             t    - array containing temperature profile in K.
c                      [R*4 RETURNED]

c             w    - array containing water vapour mixing ratio profile
c                    in g/kg.
c                      [R*4 RETURNED]

c             o    - array containing ozone concentration profile in ppmv.
c                      [R*4 RETURNED]

c             iatm - model atmosphere associated with each profile.
c                      [I*4 RETURNED]

c Comments  : - Best results for transmittance regression model were
c               apparently obtained using ozone ppmv rather than g/kg.

c=======================================================================

        parameter ( na = 32, nl = 42)
        dimension t(*), w(*), o(*)
        dimension temp(nl,na), wvmr(nl,na), ozmr(nl,na), iclas(na)

 
 
c      Atmosphere : 1   reference originale :  6
c      US std 76
       data iclas( 1) / 6/
       data (temp(i, 1),i=1,nl)/
     +  231.70, 245.22, 263.36, 270.63, 264.07, 257.93, 249.51, 243.65,
     +  239.24, 232.64, 228.07, 225.00, 223.13, 221.72, 220.54, 217.28,
     +  216.70, 216.70, 216.70, 216.70, 216.70, 216.70, 216.70, 216.72,
     +  220.85, 228.58, 235.38, 241.45, 244.81, 249.48, 251.95, 258.32,
     +  262.48, 266.40, 268.61, 274.21, 278.74, 282.97, 284.71, 287.50,
     +  288.90, 290.29/
       data (wvmr(i, 1),i=1,nl)/
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.002,
     +   0.002,  0.002,  0.002,  0.002,  0.003,  0.004,  0.005,  0.014,
     +   0.036,  0.089,  0.212,  0.331,  0.427,  0.588,  0.700,  1.060,
     +   1.369,  1.754,  1.971,  2.744,  3.369,  3.979,  4.258,  4.705,
     +   4.929,  5.152/
       data (ozmr(i, 1),i=1,nl)/
     +  0.65318, 1.04800, 2.13550, 3.82390, 5.26770, 6.11310, 7.35960,
     +  7.75000, 7.82120, 7.56130, 6.92010, 6.10260, 5.55510, 5.15300,
     +  4.59910, 2.86790, 2.29260, 1.80630, 1.28990, 0.93973, 0.72277,
     +  0.54848, 0.46009, 0.29116, 0.16277, 0.09861, 0.06369, 0.05193,
     +  0.04718, 0.04097, 0.03966, 0.03614, 0.03384, 0.03342, 0.03319,
     +  0.03249, 0.03070, 0.02878, 0.02805, 0.02689, 0.02631, 0.02573/



c      Atmosphere : 2   reference originale :  1
c      tropical
       data iclas( 2) / 1/
       data (temp(i, 2),i=1,nl)/
     +  231.57, 248.62, 264.40, 269.89, 265.69, 260.98, 254.27, 249.54,
     +  245.98, 240.73, 235.29, 229.33, 225.13, 221.81, 219.20, 209.70,
     +  205.24, 201.55, 197.07, 195.65, 198.37, 204.59, 208.75, 220.96,
     +  230.67, 239.25, 246.59, 253.14, 256.77, 261.82, 264.45, 271.35,
     +  275.88, 280.12, 282.53, 286.64, 290.51, 294.62, 296.32, 299.02,
     +  300.37, 301.72/
       data (wvmr(i, 2),i=1,nl)/
     +   0.003,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.002,  0.002,  0.002,  0.002,  0.002,
     +   0.002,  0.002,  0.002,  0.002,  0.002,  0.003,  0.004,  0.013,
     +   0.051,  0.165,  0.353,  0.613,  0.790,  1.170,  1.405,  2.188,
     +   2.649,  3.969,  4.899,  8.426, 10.752, 12.739, 13.869, 15.673,
     +  16.575, 17.477/
       data (ozmr(i, 2),i=1,nl)/
     +  0.55927, 0.98223, 1.94680, 3.13500, 4.30600, 5.48910, 7.41900,
     +  8.55500, 9.22090, 9.76590, 9.60460, 8.45820, 6.99680, 5.57590,
     +  4.30000, 1.69990, 1.23560, 0.81779, 0.39171, 0.20944, 0.14056,
     +  0.12283, 0.10984, 0.08405, 0.06529, 0.05392, 0.04764, 0.04366,
     +  0.04232, 0.04052, 0.03961, 0.03735, 0.03595, 0.03534, 0.03514,
     +  0.03385, 0.03252, 0.03107, 0.03028, 0.02901, 0.02837, 0.02774/
 


c      Atmosphere : 3   reference originale :  2
c      midlatitude summer
       data iclas( 3) / 2/
       data (temp(i, 3),i=1,nl)/
     +  230.17, 249.31, 268.73, 275.62, 272.63, 267.38, 259.50, 254.07,
     +  249.96, 243.96, 237.90, 231.88, 228.02, 226.02, 224.46, 220.55,
     +  219.13, 217.85, 216.48, 215.70, 215.70, 215.70, 215.70, 220.45,
     +  230.07, 238.24, 245.33, 251.68, 255.15, 259.99, 262.43, 268.56,
     +  272.59, 276.36, 278.51, 283.83, 287.43, 290.47, 291.71, 293.70,
     +  294.70, 295.69/
       data (wvmr(i, 3),i=1,nl)/
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.002,
     +   0.002,  0.002,  0.002,  0.002,  0.002,  0.002,  0.003,  0.015,
     +   0.078,  0.201,  0.338,  0.526,  0.656,  0.882,  1.030,  1.608,
     +   2.271,  3.084,  3.566,  5.496,  7.282,  9.098,  9.955, 11.324,
     +  12.009, 12.693/
       data (ozmr(i, 3),i=1,nl)/
     +  0.61951, 1.07100, 1.77690, 2.91540, 3.98550, 5.06940, 7.01750,
     +  8.18550, 8.74390, 8.74000, 7.87210, 6.65250, 5.84690, 5.12970,
     +  4.37610, 2.46410, 1.97310, 1.47700, 0.91258, 0.66705, 0.57759,
     +  0.48610, 0.44729, 0.24487, 0.16974, 0.12153, 0.10002, 0.08397,
     +  0.07669, 0.06661, 0.06225, 0.05355, 0.04892, 0.04505, 0.04291,
     +  0.03814, 0.03517, 0.03283, 0.03194, 0.03053, 0.02983, 0.02912/
 


c      Atmosphere : 4   reference originale :  3
c      midlatitude winter
       data iclas( 4) / 3/
       data (temp(i, 4),i=1,nl)/
     +  241.64, 251.73, 263.19, 263.81, 255.01, 248.45, 239.48, 233.30,
     +  228.64, 221.93, 218.21, 215.95, 215.35, 215.20, 215.20, 215.20,
     +  215.20, 215.54, 216.16, 216.68, 217.12, 217.63, 217.97, 218.90,
     +  219.61, 225.79, 232.02, 237.54, 240.60, 244.84, 247.07, 252.82,
     +  256.58, 260.11, 261.94, 264.87, 267.22, 269.39, 270.28, 271.70,
     +  272.41, 273.12/
       data (wvmr(i, 4),i=1,nl)/
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.005,
     +   0.016,  0.035,  0.071,  0.142,  0.228,  0.354,  0.427,  0.660,
     +   0.870,  1.166,  1.329,  1.693,  1.973,  2.254,  2.391,  2.609,
     +   2.718,  2.827/
       data (ozmr(i, 4),i=1,nl)/
     +  0.58382, 1.06610, 2.23420, 3.87590, 5.18850, 6.20950, 7.04490,
     +  7.17100, 7.10970, 6.86110, 6.29020, 5.71790, 5.35260, 5.03880,
     +  4.57680, 3.16920, 2.47480, 1.95800, 1.43280, 1.11340, 0.93068,
     +  0.81309, 0.74765, 0.46038, 0.25869, 0.15587, 0.10257, 0.07960,
     +  0.06900, 0.05625, 0.05211, 0.04120, 0.03513, 0.03297, 0.03176,
     +  0.02882, 0.02821, 0.02796, 0.02790, 0.02781, 0.02777, 0.02772/



c      Atmosphere : 5   reference originale :  4
c      polar summer
       data iclas( 5) / 4/
       data (temp(i, 5),i=1,nl)/
     +  227.47, 250.23, 272.70, 277.16, 275.24, 272.35, 265.04, 258.38,
     +  253.33, 246.03, 239.15, 233.82, 230.69, 228.93, 227.34, 225.20,
     +  225.20, 225.20, 225.20, 225.20, 225.20, 225.20, 225.20, 225.20,
     +  225.20, 230.54, 237.97, 244.52, 248.15, 253.21, 255.93, 262.27,
     +  265.77, 269.05, 270.90, 275.59, 279.37, 282.91, 284.39, 286.74,
     +  287.92, 289.09/
       data (wvmr(i, 5),i=1,nl)/
     +   0.002,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.002,  0.002,  0.003,  0.004,
     +   0.018,  0.068,  0.219,  0.439,  0.593,  0.836,  1.050,  1.670,
     +   2.148,  2.691,  2.998,  4.040,  4.889,  5.856,  6.396,  7.259,
     +   7.690,  8.122/
       data (ozmr(i, 5),i=1,nl)/
     +  0.58824, 0.98312, 1.64270, 2.53000, 3.56840, 4.56580, 6.36530,
     +  7.39640, 7.78290, 7.56980, 6.69060, 5.57510, 5.21480, 4.73040,
     +  4.34710, 2.75530, 2.05540, 1.64660, 1.17450, 0.92611, 0.78889,
     +  0.65317, 0.58224, 0.40197, 0.24128, 0.15314, 0.10010, 0.08052,
     +  0.07394, 0.06544, 0.06065, 0.04986, 0.04448, 0.04090, 0.03887,
     +  0.03446, 0.03129, 0.02823, 0.02682, 0.02456, 0.02343, 0.02230/



c      Atmosphere : 6   reference originale :  5
c      polar winter
       data iclas( 6) / 5/
       data (temp(i, 6),i=1,nl)/
     +  249.27, 254.08, 259.26, 248.94, 241.62, 236.66, 229.76, 224.97,
     +  221.69, 218.42, 216.13, 213.65, 211.92, 211.58, 212.27, 214.19,
     +  214.88, 215.46, 216.20, 216.82, 217.20, 217.20, 217.20, 217.20,
     +  217.20, 218.48, 223.08, 229.02, 232.35, 237.00, 239.43, 245.76,
     +  249.32, 252.17, 253.40, 255.98, 258.05, 258.59, 258.12, 257.39,
     +  257.03, 256.66/
       data (wvmr(i, 6),i=1,nl)/
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.006,
     +   0.014,  0.019,  0.047,  0.106,  0.133,  0.199,  0.242,  0.428,
     +   0.567,  0.700,  0.761,  0.890,  0.966,  0.969,  0.937,  0.887,
     +   0.862,  0.837/
       data (ozmr(i, 6),i=1,nl)/
     +  0.75492, 1.20220, 2.39280, 3.75640, 4.96740, 5.64280, 6.17910,
     +  6.22150, 6.15200, 5.88340, 5.42540, 4.91090, 4.76030, 4.63610,
     +  4.52230, 3.70530, 3.01350, 2.39070, 1.76420, 1.38780, 1.12050,
     +  0.82870, 0.66060, 0.36047, 0.28088, 0.17023, 0.09235, 0.06542,
     +  0.05169, 0.04171, 0.03940, 0.03409, 0.03095, 0.02819, 0.02673,
     +  0.02330, 0.02159, 0.01999, 0.01933, 0.01828, 0.01775, 0.01723/
 


c      Atmosphere : 7   reference originale :318
c      Wallops Island USA,30/11/77
       data iclas( 7) / 3/
       data (temp(i, 7),i=1,nl)/
     +  239.07, 249.20, 260.81, 265.69, 261.53, 258.50, 250.10, 244.77,
     +  240.71, 222.15, 217.15, 215.40, 214.15, 213.60, 213.15, 209.15,
     +  207.15, 206.15, 203.00, 203.15, 204.04, 202.34, 204.15, 215.15,
     +  225.15, 235.15, 244.26, 252.15, 254.15, 257.95, 261.15, 267.39,
     +  271.38, 275.07, 277.15, 277.40, 281.15, 284.93, 285.93, 284.15,
     +  283.26, 282.37/
       data (wvmr(i, 7),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.001,  0.001,  0.008,
     +   0.032,  0.107,  0.246,  0.506,  0.695,  0.919,  1.213,  1.838,
     +   2.443,  3.138,  3.843,  3.812,  5.082,  6.456,  7.118,  6.384,
     +   6.017,  5.650/
       data (ozmr(i, 7),i=1,nl)/
     +  0.68547, 1.42560, 2.23960, 3.04190, 3.60650, 3.94880, 4.48000,
     +  4.91870, 5.25190, 5.71430, 5.80000, 6.66670, 6.55000, 5.64000,
     +  5.00000, 2.22000, 1.65000, 1.47140, 0.70588, 0.33000, 0.15652,
     +  0.11111, 0.07333, 0.03500, 0.04400, 0.04333, 0.04000, 0.03750,
     +  0.04884, 0.04842, 0.04600, 0.04561, 0.04516, 0.04328, 0.04429,
     +  0.04359, 0.04235, 0.04239, 0.04105, 0.02400, 0.01548, 0.06950/



c      Atmosphere : 8   reference originale : 12
c      Biscarosse France,07/12/76
       data iclas( 8) / 3/
       data (temp(i, 8),i=1,nl)/
     +  242.29, 252.00, 263.29, 265.72, 261.39, 258.27, 250.64, 244.86,
     +  232.15, 234.15, 233.15, 228.80, 225.15, 222.15, 222.15, 217.15,
     +  217.15, 218.15, 216.70, 218.15, 220.98, 219.95, 221.15, 220.15,
     +  224.93, 227.15, 233.49, 238.98, 241.95, 246.05, 248.15, 252.36,
     +  257.19, 261.64, 264.15, 270.91, 276.27, 281.21, 282.96, 285.15,
     +  286.24, 287.34/
       data (wvmr(i, 8),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.018,  0.019,  0.016,
     +   0.035,  0.045,  0.080,  0.145,  0.185,  0.284,  0.367,  0.495,
     +   0.929,  1.256,  1.605,  2.616,  3.819,  5.033,  5.749,  6.684,
     +   7.151,  7.619/
       data (ozmr(i, 8),i=1,nl)/
     +  0.70571, 1.46700, 2.23680, 3.07610, 4.35820, 5.22530, 6.44240,
     +  7.32620, 8.00000, 8.57140, 7.00000, 5.93330, 6.05000, 5.60000,
     +  5.50000, 2.42000, 1.68330, 1.74290, 0.91765, 0.89000, 0.66957,
     +  0.32593, 0.22667, 0.14500, 0.13600, 0.06667, 0.06000, 0.05500,
     +  0.05116, 0.04842, 0.04800, 0.04386, 0.04032, 0.03881, 0.03857,
     +  0.03590, 0.03529, 0.03370, 0.03158, 0.02500, 0.02171, 0.01842/



c      Atmosphere : 9   reference originale : 97
c      Lindenberg RDA,14/07/76
       data iclas( 9) / 2/
       data (temp(i, 9),i=1,nl)/
     +  239.96, 251.89, 265.25, 268.12, 264.75, 262.31, 256.63, 251.66,
     +  247.75, 242.91, 237.15, 231.68, 229.15, 227.32, 226.15, 223.15,
     +  221.80, 221.15, 221.15, 220.15, 220.30, 220.82, 221.15, 212.15,
     +  221.83, 230.15, 239.14, 245.61, 249.12, 253.95, 257.15, 263.00,
     +  266.74, 270.20, 272.15, 280.04, 286.31, 292.08, 294.42, 298.15,
     +  300.01, 301.88/
       data (wvmr(i, 9),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.020,  0.019,  0.005,
     +   0.022,  0.061,  0.153,  0.275,  0.384,  0.696,  0.887,  1.405,
     +   1.883,  1.505,  2.885,  4.928,  7.169,  9.959, 11.736, 14.774,
     +  16.293, 17.812/
       data (ozmr(i, 9),i=1,nl)/
     +  0.74711, 1.57550, 2.45460, 2.87200, 3.01300, 3.27630, 3.84660,
     +  4.43410, 4.97990, 5.92010, 6.70000, 7.20000, 5.90000, 4.88000,
     +  4.50000, 2.94000, 2.33330, 1.50000, 0.89412, 0.93000, 0.48696,
     +  0.46667, 0.45333, 0.26000, 0.18000, 0.15000, 0.12857, 0.12250,
     +  0.11860, 0.11158, 0.10600, 0.08947, 0.07903, 0.07164, 0.06857,
     +  0.05897, 0.05294, 0.04783, 0.04526, 0.04300, 0.04187, 0.04074/
 


c      Atmosphere :10   reference originale :367
c      Kanton, Iles Phenix,08/09/65
       data iclas(10) / 1/
       data (temp(i,10),i=1,nl)/
     +  243.40, 255.02, 270.12, 271.49, 272.67, 273.48, 266.34, 259.74,
     +  254.57, 243.15, 234.15, 230.15, 227.15, 222.53, 221.15, 211.15,
     +  206.64, 207.15, 202.87, 197.15, 196.77, 202.44, 206.15, 221.15,
     +  232.71, 242.15, 250.30, 257.36, 261.18, 266.44, 269.15, 274.89,
     +  278.57, 281.96, 284.15, 288.42, 290.74, 295.10, 297.42, 301.15,
     +  303.01, 304.88/
       data (wvmr(i,10),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.001,  0.002,  0.019,
     +   0.060,  0.177,  0.417,  0.835,  1.061,  1.453,  1.978,  2.643,
     +   3.150,  3.679,  4.080, 10.370, 11.030, 13.352, 14.878, 17.631,
     +  19.007, 20.384/
       data (ozmr(i,10),i=1,nl)/
     +  0.62838, 1.31770, 2.22210, 3.01420, 3.53910, 3.83350, 4.39880,
     +  5.01220, 5.58410, 6.42860, 7.20000, 8.86670, 7.25000, 5.32000,
     +  4.60000, 1.60000, 0.98333, 0.68571, 0.30588, 0.08000, 0.01739,
     +  0.00741, 0.00667, 0.00500, 0.00800, 0.01000, 0.01429, 0.01500,
     +  0.01628, 0.01895, 0.02000, 0.01579, 0.01290, 0.01194, 0.01857,
     +  0.01923, 0.00824, 0.00652, 0.00737, 0.01000, 0.01131, 0.01263/
 


c      Atmosphere :11   reference originale :290
c      Resolute, Canada, 22/06/77
       data iclas(11) / 4/
       data (temp(i,11),i=1,nl)/
     +  245.55, 258.48, 273.70, 277.76, 274.04, 271.43, 263.61, 257.32,
     +  252.45, 249.15, 243.15, 236.32, 233.15, 231.15, 231.15, 231.15,
     +  231.15, 230.15, 228.15, 227.15, 228.76, 228.47, 228.15, 228.15,
     +  222.47, 226.15, 233.94, 241.15, 244.07, 248.09, 250.15, 257.35,
     +  261.23, 264.38, 266.15, 269.63, 272.15, 271.80, 274.25, 278.15,
     +  280.10, 282.05/
       data (wvmr(i,11),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,
     +   0.003,  0.003,  0.003,  0.004,  0.005,  0.051,  0.044,  0.033,
     +   0.017,  0.035,  0.087,  0.177,  0.241,  0.370,  0.450,  0.976,
     +   1.355,  0.585,  1.285,  2.440,  0.831,  2.805,  3.462,  4.609,
     +   5.183,  5.756/
       data (ozmr(i,11),i=1,nl)/
     +  0.84863, 1.58900, 2.20390, 2.50190, 2.63680, 2.95530, 3.57900,
     +  4.15200, 4.65020, 5.42860, 5.50000, 4.93330, 4.35000, 4.12000,
     +  4.23330, 3.22000, 2.68330, 2.47140, 1.35290, 1.22000, 0.92174,
     +  0.74815, 0.64000, 0.56000, 0.32000, 0.11000, 0.09429, 0.05750,
     +  0.06977, 0.08421, 0.09200, 0.06316, 0.05323, 0.04925, 0.04714,
     +  0.03974, 0.03294, 0.01739, 0.01368, 0.00900, 0.00666, 0.00432/



c      Atmosphere :12   reference originale :241
c      Tateno, Japon, 17/04/75
       data iclas(12) / 2/
       data (temp(i,12),i=1,nl)/
     +  235.29, 247.72, 262.42, 266.79, 262.73, 259.75, 251.40, 245.96,
     +  241.77, 235.88, 231.15, 226.67, 227.15, 222.61, 220.15, 212.15,
     +  212.04, 210.15, 208.15, 212.15, 212.85, 214.05, 212.15, 211.15,
     +  223.79, 234.15, 241.60, 248.05, 251.54, 256.35, 258.15, 263.22,
     +  266.47, 269.46, 271.15, 276.88, 281.43, 285.45, 286.90, 289.15,
     +  290.28, 291.40/
       data (wvmr(i,12),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.008,  0.005,  0.005,
     +   0.028,  0.091,  0.187,  0.324,  0.450,  0.775,  0.919,  1.286,
     +   1.672,  2.129,  2.546,  3.646,  5.061,  6.440,  7.549,  8.843,
     +   9.490, 10.137/
       data (ozmr(i,12),i=1,nl)/
     +  0.67908, 1.44760, 2.34280, 2.92140, 3.24300, 3.56140, 4.22920,
     +  4.95550, 5.65660, 6.86030, 7.80000, 8.46670, 7.25000, 6.16000,
     +  5.66670, 3.44000, 3.18330, 1.92860, 0.58824, 0.43000, 0.58261,
     +  0.55556, 0.41333, 0.08000, 0.06400, 0.06333, 0.06000, 0.05750,
     +  0.05814, 0.05474, 0.05600, 0.05965, 0.06129, 0.06269, 0.06429,
     +  0.06154, 0.06000, 0.05543, 0.04421, 0.01800, 0.00490, 0.00490/



c      Atmosphere :13   reference originale :187
c      Lindenberg RDA, 08/12/77
       data iclas(13) / 3/
       data (temp(i,13),i=1,nl)/
     +  235.50, 245.61, 258.12, 260.61, 256.88, 254.27, 246.90, 241.21,
     +  236.70, 227.43, 210.15, 207.82, 206.15, 206.15, 206.15, 206.15,
     +  208.52, 210.15, 209.10, 208.15, 211.45, 210.15, 208.15, 205.15,
     +  217.93, 228.15, 235.46, 243.02, 247.11, 252.74, 256.15, 264.22,
     +  268.09, 270.69, 272.15, 275.15, 275.15, 275.15, 275.15, 275.15,
     +  275.15, 275.15/
       data (wvmr(i,13),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.004,  0.003,  0.001,
     +   0.011,  0.042,  0.109,  0.240,  0.359,  0.468,  0.733,  1.673,
     +   2.361,  2.618,  3.104,  3.743,  3.569,  3.413,  3.393,  3.416,
     +   3.428,  3.439/
       data (ozmr(i,13),i=1,nl)/
     +  0.74711, 1.51990, 2.23530, 3.05470, 3.60110, 3.84180, 4.07250,
     +  4.20280, 4.28490, 4.40450, 4.60000, 4.80000, 4.55000, 4.20000,
     +  3.93330, 2.52000, 1.86670, 1.51430, 1.27060, 0.99000, 0.81739,
     +  0.37778, 0.24000, 0.10500, 0.07200, 0.06000, 0.09429, 0.09000,
     +  0.08605, 0.08210, 0.07000, 0.05614, 0.06613, 0.06418, 0.06286,
     +  0.03718, 0.03059, 0.02500, 0.02211, 0.02000, 0.01900, 0.01789/



c      Atmosphere :14   reference originale :232
c      Sapporo Japan, 28/08/75
       data iclas(14) / 2/
       data (temp(i,14),i=1,nl)/
     +  241.16, 253.12, 266.07, 272.61, 268.27, 265.17, 256.97, 251.66,
     +  247.65, 244.56, 239.41, 229.53, 227.15, 224.22, 223.15, 219.15,
     +  217.29, 213.15, 209.25, 208.15, 208.15, 211.16, 213.15, 223.15,
     +  233.65, 242.15, 249.39, 256.26, 259.46, 263.88, 266.15, 270.89,
     +  274.28, 277.18, 279.15, 284.49, 287.22, 289.74, 291.51, 295.15,
     +  296.97, 298.79/
       data (wvmr(i,14),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.005,  0.006,  0.024,
     +   0.089,  0.223,  0.405,  0.846,  1.039,  1.397,  1.669,  2.270,
     +   2.990,  3.669,  4.446,  6.216,  7.437,  8.503,  9.877, 12.529,
     +  13.855, 15.181/
       data (ozmr(i,14),i=1,nl)/
     +  0.70085, 1.50000, 2.42530, 3.02030, 3.27840, 3.54460, 4.11180,
     +  4.68590, 5.19070, 5.99550, 6.50880, 6.20000, 6.45000, 5.72000,
     +  5.10000, 2.64000, 1.98330, 1.31430, 0.48235, 0.33000, 0.20870,
     +  0.12593, 0.10667, 0.07500, 0.09200, 0.10333, 0.08571, 0.06500,
     +  0.06279, 0.06105, 0.06200, 0.05439, 0.06936, 0.08507, 0.08429,
     +  0.07436, 0.06353, 0.05543, 0.04842, 0.03600, 0.02979, 0.02358/



c      Atmosphere :15   reference originale :224
c      Cagliari, Sicile, 18/08/76
       data iclas(15) / 2/
       data (temp(i,15),i=1,nl)/
     +  240.91, 252.86, 266.77, 270.59, 266.84, 264.14, 257.09, 251.52,
     +  247.26, 242.18, 235.15, 230.06, 229.15, 224.88, 224.15, 220.15,
     +  218.58, 218.15, 215.65, 217.15, 217.15, 218.34, 219.15, 217.15,
     +  222.33, 231.15, 238.98, 245.67, 249.91, 255.90, 259.15, 266.23,
     +  270.44, 274.86, 277.15, 281.98, 287.25, 292.57, 295.04, 299.15,
     +  301.21, 303.26/
       data (wvmr(i,15),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.014,  0.014,  0.011,
     +   0.023,  0.065,  0.140,  0.255,  0.376,  0.739,  0.979,  1.613,
     +   2.258,  3.140,  3.898,  5.216,  7.449, 10.160, 12.458, 16.161,
     +  18.013, 19.864/
       data (ozmr(i,15),i=1,nl)/
     +  0.69045, 1.47190, 2.42250, 3.00990, 3.28980, 3.58140, 4.21440,
     +  4.88450, 5.50430, 6.54760, 7.30000, 6.86670, 6.25000, 5.00000,
     +  4.43330, 2.40000, 1.61670, 1.18570, 0.87059, 0.71000, 0.49565,
     +  0.38519, 0.26667, 0.17000, 0.10000, 0.09667, 0.07143, 0.04250,
     +  0.04651, 0.05684, 0.05800, 0.05439, 0.06129, 0.05821, 0.05000,
     +  0.04872, 0.05059, 0.05109, 0.04842, 0.04300, 0.04029, 0.03758/
 


c      Atmosphere :16   reference originale :265
c      Goose, Terre Neuve, 07/12/77
       data iclas(16) / 3/
       data (temp(i,16),i=1,nl)/
     +  242.21, 250.87, 260.73, 260.96, 256.37, 253.10, 244.72, 238.59,
     +  233.75, 226.73, 218.15, 218.15, 215.15, 216.15, 217.15, 216.15,
     +  217.15, 220.15, 225.74, 226.15, 223.46, 227.15, 226.15, 223.15,
     +  219.85, 219.15, 226.87, 234.02, 237.15, 238.72, 240.15, 246.44,
     +  250.21, 250.81, 251.15, 251.82, 254.64, 259.48, 261.44, 260.15,
     +  259.51, 258.86/
       data (wvmr(i,16),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.044,  0.035,  0.021,
     +   0.014,  0.013,  0.041,  0.092,  0.128,  0.109,  0.120,  0.287,
     +   0.440,  0.424,  0.468,  0.484,  0.721,  1.036,  1.204,  1.093,
     +   1.038,  0.982/
       data (ozmr(i,16),i=1,nl)/
     +  0.76142, 1.52850, 2.23360, 3.05040, 3.75120, 4.11330, 4.51970,
     +  4.77700, 4.95740, 5.22720, 5.60000, 6.26670, 6.10000, 5.16000,
     +  4.80000, 2.32000, 2.18330, 1.84290, 1.28240, 1.10000, 0.86957,
     +  1.04440, 1.00000, 0.35500, 0.22000, 0.08333, 0.04000, 0.04000,
     +  0.06512, 0.05263, 0.04600, 0.04035, 0.03871, 0.04030, 0.04286,
     +  0.03590, 0.03294, 0.03043, 0.02947, 0.02900, 0.02877, 0.02853/



c      Atmosphere :17   reference originale : 92
c      Lindenberg, RDA, 16/06/76
       data iclas(17) / 2/
       data (temp(i,17),i=1,nl)/
     +  244.48, 255.60, 267.45, 270.10, 266.52, 263.99, 255.78, 248.74,
     +  243.21, 237.66, 238.15, 233.90, 230.15, 226.14, 225.15, 223.15,
     +  222.27, 222.15, 223.15, 223.15, 223.67, 225.64, 226.15, 229.15,
     +  230.15, 217.15, 232.54, 239.51, 243.28, 248.48, 251.15, 258.35,
     +  262.97, 266.77, 268.15, 273.68, 278.06, 282.10, 283.74, 286.15,
     +  287.36, 288.56/
       data (wvmr(i,17),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.036,  0.035,  0.050,
     +   0.062,  0.012,  0.074,  0.145,  0.212,  0.338,  0.429,  0.966,
     +   1.403,  1.162,  2.142,  3.146,  4.108,  5.210,  5.929,  6.982,
     +   7.509,  8.035/
       data (ozmr(i,17),i=1,nl)/
     +  0.74711, 1.57410, 2.43890, 2.83040, 2.93430, 3.18540, 3.73830,
     +  4.31940, 4.87030, 5.82670, 6.60000, 6.13330, 5.55000, 4.56000,
     +  4.93330, 3.16000, 2.31670, 1.55710, 1.61180, 1.09000, 0.77391,
     +  0.75556, 0.59333, 0.41000, 0.34800, 0.16333, 0.06857, 0.06250,
     +  0.05814, 0.05474, 0.05400, 0.05965, 0.06129, 0.06119, 0.05857,
     +  0.05000, 0.04353, 0.03913, 0.03684, 0.03500, 0.03408, 0.03316/



c      Atmosphere :18   reference originale :119
c      Lindenberg, RDA, 27/10/76
       data iclas(18) / 3/
       data (temp(i,18),i=1,nl)/
     +  239.16, 250.28, 263.59, 266.59, 263.03, 260.52, 253.27, 247.31,
     +  242.61, 235.22, 213.15, 213.15, 213.15, 213.46, 214.15, 214.15,
     +  214.15, 214.15, 214.15, 214.15, 214.15, 214.15, 213.15, 211.15,
     +  219.76, 228.15, 237.40, 244.62, 248.55, 254.23, 257.15, 263.77,
     +  268.02, 271.94, 274.15, 278.05, 279.40, 277.23, 276.34, 275.15,
     +  274.56, 273.96/
       data (wvmr(i,18),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.008,  0.006,  0.004,
     +   0.015,  0.043,  0.133,  0.277,  0.405,  0.662,  0.815,  1.591,
     +   2.294,  2.639,  3.539,  4.532,  4.749,  3.907,  3.667,  3.391,
     +   3.253,  3.115/
       data (ozmr(i,18),i=1,nl)/
     +  0.74711, 1.53400, 2.26420, 3.06440, 3.59180, 3.89310, 4.31150,
     +  4.58720, 4.75290, 4.92900, 5.00000, 5.46670, 5.40000, 4.96000,
     +  4.43330, 2.30000, 1.68330, 1.12860, 0.88235, 0.76000, 0.56522,
     +  0.32593, 0.26667, 0.22000, 0.22000, 0.17667, 0.13429, 0.11750,
     +  0.10930, 0.10737, 0.10800, 0.10351, 0.10000, 0.09851, 0.09714,
     +  0.09231, 0.08471, 0.06848, 0.06316, 0.05600, 0.05242, 0.04884/



c      Atmosphere :19   reference originale :264
c      Goose, Terre Neuve, 30/11/77
       data iclas(19) / 3/
       data (temp(i,19),i=1,nl)/
     +  242.17, 247.59, 252.19, 251.04, 245.82, 242.07, 236.63, 232.60,
     +  229.49, 211.15, 214.15, 212.86, 208.15, 209.67, 211.15, 217.15,
     +  217.15, 215.15, 215.52, 217.15, 218.66, 220.15, 221.15, 224.15,
     +  222.69, 220.15, 220.15, 223.80, 225.86, 228.69, 230.15, 235.61,
     +  239.11, 242.33, 244.15, 250.55, 253.86, 255.86, 256.36, 257.15,
     +  257.55, 257.94/
       data (wvmr(i,19),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.018,  0.019,  0.024,
     +   0.020,  0.015,  0.017,  0.027,  0.035,  0.035,  0.039,  0.091,
     +   0.140,  0.180,  0.232,  0.428,  0.675,  0.768,  0.793,  0.854,
     +   0.885,  0.915/
       data (ozmr(i,19),i=1,nl)/
     +  0.76142, 1.53150, 2.22750, 3.05270, 3.62930, 3.90170, 4.17120,
     +  4.32820, 4.43250, 4.57140, 5.00000, 4.80000, 5.10000, 4.72000,
     +  4.46670, 3.30000, 3.15000, 2.67140, 2.14120, 1.60000, 1.73910,
     +  1.05190, 0.54000, 0.45500, 0.26000, 0.13000, 0.06857, 0.05500,
     +  0.04884, 0.04211, 0.04000, 0.03684, 0.03387, 0.03284, 0.03286,
     +  0.02820, 0.02588, 0.02283, 0.02105, 0.01900, 0.01798, 0.01695/



c      Atmosphere :20   reference originale :280
c      Churchill, Canada, 19/10/77
       data iclas(20) / 3/
       data (temp(i,20),i=1,nl)/
     +  245.00, 254.06, 264.63, 266.11, 261.61, 258.40, 250.63, 244.36,
     +  239.46, 216.15, 216.15, 218.11, 216.15, 216.09, 217.15, 217.15,
     +  218.24, 219.15, 217.10, 218.15, 221.22, 222.16, 224.15, 222.15,
     +  222.65, 226.15, 231.13, 235.44, 237.77, 241.82, 245.15, 252.16,
     +  256.66, 260.81, 263.15, 270.49, 276.21, 278.15, 276.16, 273.15,
     +  271.65, 270.14/
       data (wvmr(i,20),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.024,  0.027,  0.018,
     +   0.019,  0.030,  0.071,  0.112,  0.148,  0.146,  0.184,  0.529,
     +   1.003,  1.105,  1.636,  2.776,  3.881,  4.299,  3.663,  2.969,
     +   2.622,  2.275/
       data (ozmr(i,20),i=1,nl)/
     +  0.83301, 1.57600, 2.21400, 3.02610, 3.89160, 4.42650, 5.16940,
     +  5.66460, 5.99920, 6.42860, 6.90000, 6.13330, 5.50000, 5.08000,
     +  4.93330, 2.86000, 2.23330, 1.82860, 0.97647, 0.60000, 0.44348,
     +  0.31111, 0.34000, 0.17500, 0.13200, 0.06667, 0.06000, 0.05500,
     +  0.05349, 0.04842, 0.04600, 0.04035, 0.03710, 0.03433, 0.03429,
     +  0.03205, 0.02941, 0.02500, 0.01790, 0.00900, 0.00455, 0.00100/



c      Atmosphere :21   reference originale : 33
c      Biscarosse, France, 17/05/77
       data iclas(21) / 2/
       data (temp(i,21),i=1,nl)/
     +  246.00, 255.72, 266.31, 268.46, 264.45, 261.59, 254.18, 247.91,
     +  243.10, 242.15, 238.15, 231.52, 226.15, 224.50, 223.15, 223.15,
     +  222.67, 221.15, 222.76, 223.15, 224.15, 224.15, 224.15, 227.15,
     +  226.15, 221.15, 227.01, 234.92, 239.21, 245.11, 248.15, 255.16,
     +  259.66, 263.81, 266.15, 271.67, 276.08, 280.66, 282.82, 286.15,
     +  287.82, 289.48/
       data (wvmr(i,21),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.030,  0.027,  0.039,
     +   0.036,  0.019,  0.034,  0.077,  0.114,  0.197,  0.262,  0.609,
     +   0.922,  1.306,  1.660,  2.475,  3.400,  4.613,  5.538,  7.013,
     +   7.751,  8.488/
       data (ozmr(i,21),i=1,nl)/
     +  0.70571, 1.51710, 2.41260, 2.87820, 3.07120, 3.36220, 3.99420,
     +  4.66890, 5.31490, 6.42860, 7.20000, 7.00000, 6.15000, 5.48000,
     +  4.96670, 3.28000, 2.53330, 2.21430, 2.09410, 1.58000, 1.33040,
     +  1.00740, 0.68667, 0.76500, 0.56400, 0.14333, 0.07143, 0.07000,
     +  0.06744, 0.06526, 0.06600, 0.06316, 0.06129, 0.05821, 0.05857,
     +  0.05641, 0.05412, 0.04239, 0.04000, 0.04000, 0.04000, 0.04000/
 


c      Atmosphere :22   reference originale : 15
c      Biscarosse, France, 05/01/77
       data iclas(22) / 3/
       data (temp(i,22),i=1,nl)/
     +  236.22, 246.36, 257.89, 260.59, 256.46, 253.48, 245.80, 240.50,
     +  236.15, 231.15, 224.15, 219.29, 217.15, 216.30, 215.15, 211.15,
     +  211.83, 212.15, 213.15, 212.15, 212.11, 213.29, 212.15, 213.15,
     +  220.18, 228.15, 235.10, 241.11, 244.36, 248.85, 251.15, 255.83,
     +  258.83, 261.59, 263.15, 266.22, 268.65, 270.89, 271.80, 274.15,
     +  275.33, 276.50/
       data (wvmr(i,22),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.007,  0.005,  0.006,
     +   0.020,  0.052,  0.099,  0.190,  0.249,  0.399,  0.528,  0.859,
     +   1.114,  1.290,  1.526,  1.884,  2.241,  2.448,  2.644,  3.144,
     +   3.394,  3.644/
       data (ozmr(i,22),i=1,nl)/
     +  0.70571, 1.46690, 2.24220, 3.12030, 4.67800, 5.72880, 7.20000,
     +  8.24910, 9.00000, 8.71430, 8.50000, 8.13330, 6.75000, 6.68000,
     +  5.60000, 3.30000, 2.83330, 2.24290, 2.10590, 1.06000, 0.53043,
     +  0.52593, 0.28667, 0.06500, 0.01600, 0.01333, 0.01143, 0.01000,
     +  0.00930, 0.00842, 0.01000, 0.00877, 0.00806, 0.00746, 0.00714,
     +  0.00385, 0.00235, 0.00109, 0.00105, 0.00100, 0.00098, 0.00095/



c      Atmosphere :23   reference originale :328
c      Topeka, USA, 29/05/63
       data iclas(23) / 2/
       data (temp(i,23),i=1,nl)/
     +  237.12, 249.50, 263.98, 267.94, 264.15, 261.40, 254.44, 249.29,
     +  237.15, 232.79, 228.15, 227.51, 226.15, 224.20, 222.15, 217.15,
     +  214.00, 213.15, 213.70, 214.15, 215.42, 214.15, 214.15, 212.15,
     +  223.71, 233.15, 240.81, 247.45, 251.04, 256.39, 259.15, 265.61,
     +  269.76, 273.22, 275.15, 281.32, 286.21, 291.10, 294.19, 298.15,
     +  300.13, 302.11/
       data (wvmr(i,23),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.008,  0.007,  0.005,
     +   0.028,  0.081,  0.169,  0.299,  0.417,  0.752,  0.953,  1.506,
     +   2.121,  2.789,  3.382,  4.954,  6.886,  9.150, 11.786, 15.201,
     +  16.909, 18.616/
       data (ozmr(i,23),i=1,nl)/
     +  0.68974, 1.47390, 2.41250, 2.92840, 5.76950, 8.31640,13.18200,
     + 18.17400,23.20000,18.85700,14.90000,11.46700, 9.40000, 6.32000,
     +  5.03330, 2.66000, 2.01670, 1.08570, 0.70588, 0.48000, 0.26957,
     +  0.19259, 0.12667, 0.07500, 0.06000, 0.05000, 0.05714, 0.06500,
     +  0.06512, 0.05263, 0.04800, 0.05614, 0.06129, 0.04776, 0.04143,
     +  0.05000, 0.05529, 0.05761, 0.05368, 0.04900, 0.04666, 0.04432/



c      Atmosphere :24   reference originale :176
c      Lindenberg, RDA, 26/10/77
       data iclas(24) / 3/
       data (temp(i,24),i=1,nl)/
     +  237.00, 248.30, 261.37, 265.23, 261.57, 259.01, 249.99, 243.52,
     +  238.46, 220.15, 214.15, 209.88, 208.15, 208.15, 210.15, 209.15,
     +  210.48, 211.15, 209.39, 209.15, 209.99, 210.94, 212.15, 215.15,
     +  218.79, 228.15, 237.98, 246.50, 251.11, 256.32, 259.15, 266.22,
     +  268.93, 270.99, 272.15, 276.38, 277.88, 279.29, 279.94, 282.15,
     +  283.26, 284.36/
       data (wvmr(i,24),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.005,  0.005,  0.008,
     +   0.013,  0.043,  0.142,  0.335,  0.521,  0.790,  0.961,  1.924,
     +   2.456,  2.461,  3.060,  4.030,  4.274,  4.511,  4.713,  5.516,
     +   5.918,  6.319/
       data (ozmr(i,24),i=1,nl)/
     +  0.74711, 1.53720, 2.27860, 3.05990, 3.21930, 3.22120, 3.15630,
     +  3.04250, 2.89010, 2.57140, 4.00000, 5.06670, 5.55000, 5.16000,
     +  4.50000, 2.84000, 2.31670, 1.62860, 1.00000, 0.57000, 0.34783,
     +  0.15556, 0.15333, 0.19000, 0.10800, 0.10333, 0.09429, 0.09000,
     +  0.08605, 0.06737, 0.06000, 0.07368, 0.07419, 0.07313, 0.07286,
     +  0.06667, 0.04824, 0.03043, 0.00947, 0.00200, 0.00200, 0.00200/



c      Atmosphere :25   reference originale : 34
c      Biscarosse, France, 25/05/77
       data iclas(25) / 2/
       data (temp(i,25),i=1,nl)/
     +  245.33, 255.81, 267.99, 271.30, 267.32, 264.48, 255.48, 248.52,
     +  245.15, 240.15, 234.15, 230.01, 226.15, 224.57, 222.15, 218.15,
     +  219.15, 217.15, 218.10, 220.15, 221.57, 222.15, 223.15, 225.15,
     +  223.15, 225.15, 232.81, 240.42, 244.55, 250.23, 253.15, 260.11,
     +  264.24, 268.03, 270.15, 274.83, 279.08, 283.00, 284.59, 287.15,
     +  288.43, 289.71/
       data (wvmr(i,25),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.002,  0.003,  0.004,  0.024,  0.024,  0.031,
     +   0.025,  0.032,  0.067,  0.140,  0.200,  0.330,  0.519,  0.918,
     +   1.328,  1.808,  2.248,  3.114,  4.195,  5.404,  6.230,  7.486,
     +   8.114,  8.742/
       data (ozmr(i,25),i=1,nl)/
     +  0.70571, 1.51690, 2.41810, 2.86920, 3.77030, 4.68430, 6.49380,
     +  8.35830,10.20000, 9.00000, 8.60000, 7.60000, 6.15000, 5.40000,
     +  4.40000, 2.32000, 1.58330, 0.82857, 0.98824, 0.91000, 0.64348,
     +  0.63704, 0.58000, 0.57000, 0.36800, 0.14667, 0.06857, 0.06750,
     +  0.06744, 0.06316, 0.06400, 0.05614, 0.06129, 0.06418, 0.06143,
     +  0.05513, 0.05059, 0.04674, 0.04526, 0.03400, 0.02837, 0.02274/



c      Atmosphere :26   reference originale :137
c      Lindenberg, RDA, 03/03/77
       data iclas(26) / 3/
       data (temp(i,26),i=1,nl)/
     +  237.15, 246.06, 257.24, 258.79, 254.75, 251.92, 244.10, 238.00,
     +  233.15, 223.14, 216.15, 211.54, 209.15, 209.15, 209.15, 205.15,
     +  207.04, 209.15, 209.73, 210.15, 210.43, 212.07, 213.15, 209.15,
     +  215.17, 223.15, 230.81, 237.83, 242.02, 247.39, 250.15, 256.58,
     +  260.72, 264.83, 267.15, 271.77, 275.44, 278.81, 280.18, 282.15,
     +  283.14, 284.12/
       data (wvmr(i,26),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,
     +   0.003,  0.004,  0.003,  0.003,  0.004,  0.006,  0.006,  0.003,
     +   0.008,  0.023,  0.063,  0.135,  0.207,  0.282,  0.357,  0.888,
     +   1.295,  1.541,  2.105,  2.890,  3.595,  4.364,  4.791,  5.516,
     +   5.879,  6.241/
       data (ozmr(i,26),i=1,nl)/
     +  0.74711, 1.54100, 2.27280, 2.98590, 3.75610, 4.34320, 5.24400,
     +  5.89330, 6.34120, 6.86820, 6.90000, 5.60000, 5.15000, 5.24000,
     +  5.76670, 2.60000, 2.15000, 1.98570, 2.41180, 1.62000, 1.26960,
     +  0.74074, 0.46667, 0.35500, 0.20400, 0.17000, 0.15714, 0.14000,
     +  0.12558, 0.10947, 0.10400, 0.10000, 0.09677, 0.08209, 0.07429,
     +  0.05641, 0.04471, 0.03478, 0.03158, 0.02700, 0.02471, 0.02242/



c      Atmosphere :27   reference originale :275
c      Edmonton, Canada, 14/12/77
       data iclas(27) / 3/
       data (temp(i,27),i=1,nl)/
     +  241.37, 251.37, 263.32, 264.77, 260.89, 258.16, 250.37, 243.76,
     +  238.50, 230.58, 203.15, 203.96, 205.15, 209.86, 211.15, 215.15,
     +  214.69, 215.15, 216.94, 221.15, 220.49, 220.60, 221.15, 217.15,
     +  210.00, 219.15, 228.21, 236.05, 240.30, 246.14, 249.15, 256.56,
     +  259.43, 263.73, 266.15, 272.19, 278.33, 262.15, 262.15, 262.15,
     +  262.15, 262.15/
       data (wvmr(i,27),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003,  0.003,  0.003,  0.004,  0.019,  0.019,  0.010,
     +   0.003,  0.013,  0.048,  0.115,  0.181,  0.236,  0.300,  0.906,
     +   1.208,  1.548,  1.996,  3.046,  4.475,  1.287,  1.274,  1.284,
     +   1.289,  1.294/
       data (ozmr(i,27),i=1,nl)/
     +  0.76403, 1.52920, 2.23860, 3.06840, 4.18020, 4.84810, 5.68590,
     +  6.25140, 6.66200, 7.27490, 8.10000, 8.06670, 7.55000, 5.56000,
     +  4.13330, 1.66000, 0.98333, 0.31429, 0.14118, 0.13000, 0.03478,
     +  0.07407, 0.44667, 0.55000, 0.11600, 0.07667, 0.08000, 0.08250,
     +  0.08372, 0.08421, 0.08400, 0.07895, 0.07419, 0.07164, 0.07000,
     +  0.05897, 0.02941, 0.00000, 0.00000, 0.00000, 0.00000, 0.00000/



c      Atmosphere :28   reference originale :  2
c      Halley Bay, Antarctic, 11/08/87
       data iclas(28) / 5/
       data (temp(i,28),i=1,nl)/
     +  231.19, 254.37, 293.65, 278.87, 254.15, 243.07, 227.11, 216.33,
     +  209.10, 200.20, 193.43, 188.94, 186.09, 184.74, 184.15, 185.39,
     +  187.57, 188.15, 190.62, 192.52, 194.15, 195.84, 196.94, 201.37,
     +  205.98, 210.67, 214.64, 220.46, 223.84, 228.49, 230.89, 237.02,
     +  240.95, 244.57, 246.62, 245.35, 243.01, 248.62, 249.64, 247.15,
     +  245.91, 244.66/
       data (wvmr(i,28),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,
     +   0.003,  0.003,  0.003,  0.004,  0.005,  0.005,  0.006,  0.009,
     +   0.015,  0.023,  0.039,  0.069,  0.095,  0.144,  0.177,  0.291,
     +   0.394,  0.514,  0.594,  0.475,  0.350,  0.542,  0.575,  0.437,
     +   0.368,  0.299/
       data (ozmr(i,28),i=1,nl)/
     +  0.68309, 1.15260, 1.62780, 1.93150, 2.31120, 2.64560, 3.08950,
     +  3.47340, 3.80430, 4.22810, 4.56720, 4.22290, 3.54330, 3.22830,
     +  3.10000, 2.98780, 2.50910, 1.93340, 1.84750, 1.56920, 1.15650,
     +  0.82635, 0.60940, 0.27885, 0.12934, 0.08465, 0.04687, 0.04053,
     +  0.03958, 0.03827, 0.03760, 0.03588, 0.03478, 0.03376, 0.03319,
     +  0.02852, 0.02466, 0.02618, 0.02684, 0.02800, 0.02858, 0.02916/



c      Atmosphere :29   reference originale :  9
c      Halley Bay, Antarctic, 28/08/87
       data iclas(29) / 5/
       data (temp(i,29),i=1,nl)/
     +  231.19, 254.32, 293.42, 282.20, 261.57, 251.36, 236.58, 226.71,
     +  220.04, 211.62, 204.73, 197.15, 199.15, 197.27, 193.15, 190.21,
     +  192.77, 194.15, 191.50, 191.49, 191.15, 195.97, 194.29, 198.60,
     +  204.74, 213.32, 221.49, 228.57, 231.93, 235.24, 236.95, 243.38,
     +  247.57, 251.44, 253.62, 259.01, 258.21, 255.78, 253.67, 247.15,
     +  243.89, 240.63/
       data (wvmr(i,29),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,
     +   0.003,  0.003,  0.003,  0.001,  0.001,  0.002,  0.001,  0.002,
     +   0.003,  0.016,  0.037,  0.109,  0.145,  0.185,  0.208,  0.342,
     +   0.539,  0.704,  0.931,  1.312,  1.127,  1.010,  0.818,  0.437,
     +   0.247,  0.056/
       data (ozmr(i,29),i=1,nl)/
     +  0.68309, 1.10900, 1.47100, 2.19470, 2.91610, 3.25270, 3.62570,
     +  3.90730, 4.20180, 4.66340, 5.07430, 4.33330, 3.95000, 3.11900,
     +  2.33330, 2.07190, 2.10950, 2.31430, 1.52140, 0.80188, 0.60870,
     +  0.57301, 0.40193, 0.18737, 0.06014, 0.05453, 0.05234, 0.04760,
     +  0.04426, 0.04014, 0.03802, 0.03637, 0.03542, 0.03455, 0.03405,
     +  0.03284, 0.03151, 0.03017, 0.02856, 0.02300, 0.02022, 0.01744/



c      Atmosphere :30   reference originale : 17
c      Halley Bay, Antarctic, 11/09/87
       data iclas(30) / 5/
       data (temp(i,30),i=1,nl)/
     +  231.19, 254.25, 292.63, 283.83, 265.10, 254.64, 239.15, 228.66,
     +  221.62, 212.73, 207.15, 195.15, 191.15, 189.11, 187.74, 185.15,
     +  187.15, 187.77, 187.15, 187.15, 188.15, 189.40, 189.90, 196.25,
     +  206.97, 215.87, 223.70, 230.54, 234.28, 239.43, 241.88, 247.15,
     +  250.53, 253.65, 255.41, 258.99, 261.71, 262.15, 261.36, 258.15,
     +  256.55, 254.94/
       data (wvmr(i,30),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,
     +   0.003,  0.003,  0.003,  0.001,  0.001,  0.001,  0.001,  0.003,
     +   0.010,  0.028,  0.060,  0.112,  0.154,  0.234,  0.281,  0.403,
     +   0.502,  0.609,  0.948,  1.146,  1.310,  1.433,  1.302,  0.953,
     +   0.778,  0.604/
       data (ozmr(i,30),i=1,nl)/
     +  0.68309, 1.11630, 1.48900, 2.27070, 2.97080, 3.19560, 3.30900,
     +  3.26320, 3.21910, 3.15600, 3.00000, 2.80000, 2.10000, 1.61330,
     +  1.40320, 1.22090, 0.96667, 0.89899, 0.74231, 0.58112, 0.39130,
     +  0.33082, 0.22795, 0.07041, 0.04630, 0.04556, 0.04540, 0.04503,
     +  0.04208, 0.03801, 0.03645, 0.03490, 0.03391, 0.03299, 0.03248,
     +  0.02962, 0.02709, 0.02502, 0.02581, 0.03100, 0.03359, 0.03619/



c      Atmosphere :31   reference originale : 25
c      Halley Bay, Antarctic, 15/10/87
       data iclas(31) / 4/
       data (temp(i,31),i=1,nl)/
     +  231.19, 253.44, 285.15, 287.11, 277.23, 267.23, 249.83, 236.15,
     +  231.75, 224.15, 219.15, 212.80, 207.15, 202.11, 199.15, 191.15,
     +  190.15, 190.15, 192.83, 192.82, 194.32, 196.05, 197.19, 200.20,
     +  207.19, 214.64, 221.76, 228.41, 231.41, 235.25, 236.52, 240.96,
     +  243.99, 246.80, 248.38, 252.26, 254.62, 256.80, 257.69, 253.15,
     +  250.88, 248.61/
       data (wvmr(i,31),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,
     +   0.003,  0.003,  0.003,  0.001,  0.001,  0.001,  0.001,  0.001,
     +   0.004,  0.009,  0.058,  0.107,  0.137,  0.185,  0.266,  0.361,
     +   0.443,  0.532,  0.587,  0.742,  0.835,  1.101,  1.147,  0.743,
     +   0.541,  0.339/
       data (ozmr(i,31),i=1,nl)/
     +  0.68309, 1.13630, 1.59810, 2.26740, 3.35710, 4.40120, 6.23940,
     +  7.75000, 7.15380, 5.28570, 4.80000, 3.81700, 3.65000, 2.41000,
     +  1.63330, 0.28000, 0.21667, 0.38571, 0.41079, 0.52220, 0.45218,
     +  0.37187, 0.31909, 0.08545, 0.04163, 0.03628, 0.03448, 0.03448,
     +  0.03185, 0.02778, 0.03135, 0.03126, 0.02976, 0.02838, 0.02760,
     +  0.02561, 0.02281, 0.02023, 0.01918, 0.01800, 0.01741, 0.01682/



c      Atmosphere :32   reference originale : 23
c      Halley Bay, Antarctic, 04/10/87
       data iclas(32) / 4/
       data (temp(i,32),i=1,nl)/
     +  231.19, 253.76, 287.92, 286.65, 274.72, 264.96, 248.54, 236.15,
     +  232.01, 225.77, 219.15, 211.29, 204.81, 200.11, 197.15, 194.15,
     +  193.15, 193.66, 195.14, 196.42, 196.47, 199.65, 201.15, 206.20,
     +  208.15, 212.61, 218.10, 222.85, 225.43, 228.97, 230.80, 233.28,
     +  236.97, 240.37, 242.46, 247.90, 251.96, 252.35, 246.49, 238.80,
     +  234.96, 231.11/
       data (wvmr(i,32),i=1,nl)/
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,
     +   0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.004,  0.003,
     +   0.003,  0.003,  0.003,  0.004,  0.004,  0.005,  0.006,  0.009,
     +   0.017,  0.026,  0.059,  0.091,  0.113,  0.151,  0.175,  0.199,
     +   0.267,  0.345,  0.404,  0.600,  0.789,  0.754,  0.433,  0.198,
     +   0.081,  0.081/
       data (ozmr(i,32),i=1,nl)/
     +  0.68309, 1.13200, 1.55960, 2.28670, 3.45250, 4.45770, 6.07500,
     +  7.25000, 6.60470, 5.63150, 4.60000, 4.24070, 3.40240, 1.99360,
     +  0.83333, 0.30000, 0.28333, 0.14292, 0.23944, 0.20512, 0.33625,
     +  0.40099, 0.38127, 0.28651, 0.14877, 0.07332, 0.06158, 0.05141,
     +  0.04591, 0.03833, 0.03442, 0.02643, 0.02435, 0.02243, 0.02258,
     +  0.02500, 0.02543, 0.02009, 0.02330, 0.03399, 0.03933, 0.04468/


c -- Conversion of O3 ppmv to g/kg
c     o(i) = ozmr(i,natm) * 1.e-06 * 1.e03 * MO3 / Mair


c -- Load arrays

      do i = 1, nl
        t(i) = temp(i,natm)
        w(i) = wvmr(i,natm)
        o(i) = ozmr(i,natm)
      end do


c -- Save atmospheric class

      iatm = iclas(Natm)


      return
      end
