        PROGRAM MAIN
C
CC      bt.f -- (1)reads nature run, sbuv/2 and tovs data, (2)interpolates
CC              pressure, temperature, ozone and moisture profiles as
CC              well as some surface wind speed and skin temperature, 
CC              (3) calls optran program to get simulated btightness 
CC              temperatures, and (4) finally compare the difference
CC              of brightness temperatures between simulated from nature
CC              run and observed from tovs channels
C
C
CC      COMMON BLOCK for NATURE RUN DATA
CC      FOR ANY LEVEL, NATURE RUN WOULD HAVE 640 GRID POINTS IN LATITIDE
CC      AND 320 ONES IN LONGITUDE
C
        COMMON PP(641,320),    ! nature run(nr) log pressure(one level)
     $      TT(641,320,31),    ! nr temperature profile(K, 31 levels)
     $      QQ(641,320,31)     ! nr specific humidity profile(g/kg,31 levels)
        COMMON /PSKN/ WSKIN(641,320),  ! surface(skin) wind speed(m/s)
     $                TSKIN(641,320)   ! skin temperature(K)
        COMMON /CLDCOV/ CC(641,320,31) ! cloud cover profile(0.0 - 1.)
C
CC      COMMON BLOCK FOR SBUV/2 OZONE DATA.
CC      SBUV/2 OZONE PROFILE, 65*65 HORIZONTAL GRID POINTS, 6 VERTICAL ONES
CC      FOR EACH HALF HEMISPHERE.
C
        COMMON /O3NH/ O3N(65,65,6)   ! north hemisphere ozone data
        COMMON /O3SH/ O3S(65,65,6)   ! south hemishpere ozone data
C
CC      TOVS_DAT subroutine variables(see Noaa technical report)    
C
        INTEGER
     $         IDS,        ! satellite ID
     $         NYEAR,      ! year
     $         NMONTH,     ! month
     $         NDAY,       ! day
     $         NHOUR,      ! GMT hour
     $         NMIN,       ! GMT minute
     $         NSEC,       ! GMT second
     $         IEL,        ! land sea indicator 
     $         IC,         ! instrument and/or channel combination
     $         MR,         ! retrieval method
     $         OZONEA,     ! total ozone amount
     $         OZONEQ,     ! total ozone quality
     $         XM          ! mean value
        REAL
     $         YLAT,       ! latitude
     $         YLON,       ! longitude
     $         ZA,         ! isolar zenith angle
     $         TSKN,       ! surface temperature
     $         BP,         ! pressure at the base of sounding.
     $         SC,         ! superswash counter
     $         BC,	   ! box counter 
     $         CBM,        ! minibox counter
     $         SST,        ! sea surface temperature
     $         CCP,        ! cloud cover pressure
     $         CC,         ! cloud cover amount
     $         EBT(24),    ! brightness temp for tovs HIRS/2 and MSU channel  
     $         t8,         ! uncorrected brightness temp. at channel 8
     $         t18,        ! uncorrected brightness temp. at channel 18
     $         t19	   ! uncorrected brightness temp. at channel 19
        INTEGER HEAD_S(5)    ! SBUV/2 data header
C
CC    INTP_NR subroutine variables
C
       REAL
     $  PPR(31),    ! interpolated pressure profile from nr
     $  TPR(31),    ! interpolated temperature profile from nr
     $  QPR(31),    ! interpolated moist profile from nr
     $  CCLD(31),   ! interpolated cloud cover profile from nr
     $  WSFC,       ! interpolated surface wind speed profile from nr
     $  TSFC,       ! interpolated surface skin temperature profile from nr
     $  CCOVER,     ! maximun cloud cover from cloud cover profile
     $  CPBOT,      ! pressure at cloud bottom from cloud cover profile
     $  CPTOP       ! pressure at cloud top from cloud cover profile
C
CC   NH_UPAIR_PRF and SH_UPAIR_PRF subroutine variables
C
        REAL
     $   TUP(10),    ! temperature profile about nr top level(10mb)
     $   QUP(10),    ! moist profile about nr top level(10mb)
     $   TTOPNR      ! temperature at nr top level(10mb)
C
CC     OPTRAN_SET subroutine varibles
C
        REAL 
     $   PPROF(41),  ! composite pressure profile
     $   TPROF(41),  ! composite temperature profile
     $   QPROF(41),  ! composite moist profile
     $   O3PROF(41), ! composite ozone profile 
     $   CPROF(41),  ! composite cloud cover profile
     $   BT(23),     ! returning simulated TOVS brightness temperatures
     $   IIDSAT,     ! tovs satellite identification number
     $   emissv      ! returned channel 21 microwave emmisivity
C
CC   Local variables
C
        REAL
     $   PUP(10),       ! standard pressure level above 10 mb(nr top limit)   
     $   TMPP(640,320), ! array used to read nr profile data
     $   STMP(640),     ! array used to read nr surface data
     $   TO3(65,65),    ! array used to read sbuv/2 data
     $   st(23,2)      ! array used to compute mean and std for tovs channel
C
CC   Local constants
       INTEGER
     $   iday,          ! input an day when tovs and nr result compared
     $   Julian,        ! the julian day of last day of last month for iday
     $   ISATID,        ! tovs satellite ID (noaa11=1, noaa12=2)
     $   Ks             ! tovs record counter

       REAL
     $   YMAX           ! southest or nothest latitude for NR

        DATA PUP/0.1,0.2,0.5,1.,1.5,2.,3.,4.,5.,7./
        LOGICAL EOF

        OPEN(UNIT=7,FILE='bt_in',STATUS='UNKNOWN')
c        OPEN(UNIT=8,FILE='nh_mar_1993.dat',STATUS='OLD')
c        OPEN(UNIT=9,FILE='sh_mar_1993.dat',STATUS='OLD')
        OPEN(UNIT=8,FILE='nh_feb_1993.dat',STATUS='OLD')
        OPEN(UNIT=9,FILE='sh_feb_1993.dat',STATUS='OLD')

C
CC      read input file to decide which day and satellite to be used to
CC      compare nr and tovs results
C
        READ(7,*)IDAY,JULIN, IIDSAT
        write(*,*)' iday = ',iday,' JULIAN = ',julin, IIDSAT
C
CC   Read north hemisphere SBUV/2  ozone data 
C
CC   Read sbuv/2 header
C
536     READ(8,507,END=504)HEAD_S

CC   Read total ozone amount(useless in the program) 
        READ(8,501)TO3

CC   Read ozone profiles(six levels)
        READ(8,505,END=541)O3N
        IO3DAY = HEAD_S(1) - JULIN
c        IO3DAY = HEAD_S(1) - 31
        write(*,*)' iday for NH ',IO3DAY
        IF(IO3DAY.NE.IDAY)GOTO 536
        GOTO 581
541     WRITE(*,*)'NH O3DATA MISSING, SET TO ZERO'
        DO K = 1,6
         DO J = 1,65
           DO I = 1,65
              O3N(I,J,K) = 0.
           ENDDO
         ENDDO
        ENDDO
C
CC    Read south hemisphere ozone data
C
581     READ(9,507,END=504)HEAD_S
        READ(9,501)TO3
        READ(9,505,END=504)O3S
        IO3DAY = HEAD_S(1) - JULIN
c        IO3DAY = HEAD_S(1) - 31
        write(*,*)'iday for SH ',IO3DAY
        IF(IO3DAY.NE.IDAY)GOTO 581
        GOTO 399
504     WRITE(*,*)'SH O3DATA MISSING, SET TO ZERO'
        DO K = 1,6
         DO J = 1,65
           DO I = 1,65
              O3S(I,J,K) = 0.
           ENDDO
         ENDDO
        ENDDO
399     CONTINUE
507     FORMAT(5I5)
501     FORMAT(422(10F8.3/),5F8.3)
505     FORMAT(5(422(10F8.3/),5F8.3/),422(10F8.3/),5F8.3)

C
CC    set some local constants
C
        EOF = .FALSE.
        YMAX = 89.57009   ! assign nr latitude limit
        ISATID = IIDSAT - 10  ! assign tovs satellite ID
        KT = 0         !  counter of total tovs record to be read
        KS = 0        !  counter of tovs records used in statistatic compute
        KS1 = 0
        do i = 1,23
          st(i,1) = 0.
          st(i,2) = 0.
        enddo
        write(*,*)' Satellite ID ', ISATID
         
C
CC   read log pressure data
C
        READ(31, ERR=309, IOSTAT=IOS) TMPP
        DO J = 1,320
           DO I = 1,640
              PP(I,J) = TMPP(I,J)
           ENDDO
           PP(641,J) = TMPP(1,J)
        ENDDO
   
C
CC      begin to read profiles(31 levels)
        DO I = 1,31

C
CC    read nr temperature profile
C
          READ(33, ERR=309, IOSTAT=IOS)TMPP
          DO J =1,320
            DO L=1,640
               TT(L,J,I) = TMPP(L,J)
            ENDDO
            TT(641,J,I) = TMPP(1,J)
          END DO

C
CC   read nr moist profile
C
          READ(34, ERR=309, IOSTAT=IOS)TMPP
          DO J =1,320
            DO L=1,640
               QQ(L,J,I) = TMPP(L,J)
            ENDDO
            QQ(641,J,I) = TMPP(1,J)
          ENDDO

C
CC   read nr cloud cover profile
C
          READ(30, ERR=309, IOSTAT=IOS)TMPP
          DO J = 1, 320
            DO L = 1, 640
               CC(L,J,I) = TMPP(L,J)
            ENDDO
            CC(641,J,I) = TMPP(1,J)
          ENDDO
        ENDDO 

        DO I = 1, 320
C
CC  read nr surface wind speed data at 10m altitude
C
           READ(27, ERR=309, IOSTAT=IOS)STMP
           DO J = 1,640
              WSKIN(J,I) = STMP(J) * STMP(J)
           ENDDO
           READ(28, ERR=309, IOSTAT=IOS)STMP
           DO J = 1,640
              WSKIN(J,I) = WSKIN(J,I) + STMP(J) * STMP(J)
              WSKIN(J,I) = SQRT(WSKIN(J,I))
           ENDDO
           WSKIN(641,I) = WSKIN(1,I)
C
CC  read nr surface skin temeprature
C
           READ(29, ERR=309, IOSTAT=IOS)STMP
           DO J = 1,640
              TSKIN(J,I) = STMP(J)
           ENDDO
           TSKIN(641,I) = TSKIN(1,I)
        ENDDO
C
CC      ENTER THE LOOP
C
        DO WHILE(.TRUE.)
 
CC    read tovs data by calling subroutine TOVS_DAT
           CALL TOVS_DAT(IDS,
     $                NYEAR,
     $                NMONTH, 
     $                NDAY, 
     $                NHOUR,
     $                NMIN, 
     $                NSEC,
     $                YLAT,
     $                YLON,
     $                ZA,
     $                IEL,
     $                TSKN,
     $                BP,
     $                IC,
     $                MR,
     $                XM,
     $                SC, 
     $                BC, 
     $                CBM,
     $                SST,
     $                OZONEA,
     $                OZONEQ,
     $                CCP,
     $                CC,
     $                EBT,
     $                t8,
     $                t18,
     $                t19,
     $                EOF)

c      IF(NDAY.GT.IDAY) GOTO 300
C    identify right satellite
      IF (IDS.EQ.ISATID) THEN

C    convert a variety of tovs time units into hours 
       TIM = (FLOAT(NDAY) - IDAY) * 24. + FLOAT(NHOUR) + 
     $       (FLOAT(NMIN) + FLOAT(NSEC) / 60.) / 60.

C    set temporal range for tovs observation(in this case, choise tovs data
C    from 6 to 18 GMT hour
       IF(TIM.GE.6.0.AND.TIM.LE.18.0)THEN
          yylat = abs(ylat)

C    set latitude range (60S -- 60N) and sea only.
        IF(YYLAT.LE.60..and.iel.eq.0) THEN

C    count tovs data record which satisfys above restrictions
        KS1 = KS1 + 1
       if(ks1.eq.1)then
         write(*,*)'check tovs data ',ids,tim,t8,t18,t19
       endif


C    from geographical location of tovs observation to interpolate
C    p, t, q, cloud cover, wind speed, skin temperature and cloud
C    top, bottom pressure as well as maximum cloud cover.
       CALL INTP_NR(YLAT, YLON, PPR, TPR, QPR,WSFC,TSFC,CCOVER,
     $           CPBOT,CPTOP,CCLD)

       if(ks1.eq.1)then
         write(*,*)'check interpolation ', wsfc,tsfc
         do n = 1,31
          write(*,1073)ppr(n),tpr(n),qpr(n)
1073      format(f8.1,f8.2,e13.4)
         enddo
       endif

C    assign nr top level temperature to TTOPNR to get upper air
C    profile adjusted according to nr top level temp.
           TTOPNR = TPR(1)

C    NH_UPAIR_PRF and NH_UPAIR_PRF subroutines used for winter season ONLY!!!
         IF(YLAT.GE.0.0)THEN

C    if north hemisphere
           CALL NH_UPAIR_PRF(YLAT,TTOPNR,TUP,QUP,KS)
         ELSE

C    If south hemisphere,
           CALL SH_UPAIR_PRF(YLAT,TTOPNR,TUP,QUP)
         ENDIF

       if(ks1.eq.1)then
         write(*,*)'check standard atmos'
         do n = 1,10
          write(*,1073)pup(n),tup(n),qup(n)
         enddo
       endif

C    Call O3_PRF to obtain ozone profile combining sbuv/2 and climatological
C    data(1976 US standard)         
           CALL O3_PRF(YLAT,YLON,PPR,O3PROF)
       if(ks1.eq.1)then
         write(*,*)'check standard atmos'
         do n = 1,41
          write(*,1075)o3prof(n)
1075      format(e13.4)
         enddo
       endif


C    set first ten level profiles from climatological data
             DO I = 1,10
                PPROF(i) = PUP(i)
                TPROF(i) = TUP(i)
                QPROF(i) = QUP(i)
                CPROF(i) = 0.0
             ENDDO

C    set below 31 level profile from nr data
             DO I = 11, 41
                I1 = I - 10
                IF(QPR(I1).LT.0.0)QPR(I1) = 0.0
                PPROF(i) = PPR(i1)
                TPROF(i) = TPR(i1)
                QPROF(i) = QPR(i1)
                CPROF(i) = CCLD(i1)
             ENDDO

C   call OPTRAN_SET to set optran input infirmation 
       write(*,*)'Main KS1 = ',ks1,iidsat
        CALL OPTRAN_SET(PPROF,TPROF,QPROF,O3PROF,BT,KS1,IIDSAT,WSFC,TSFC,
     $            CCOVER,CPTOP,CPBOT,IEL,emissv) 

C   cloud screening
c        tdiff = abs(ebt(8)-sst)
        tdiff = abs(t8-sst)
2100    format(2f8.2)

C   compute mean and standard deviation for 23 channel
        if(tdiff.le.5.)then
         KS = KS + 1
         do ich=1,23
          btdiff = ebt(ich) - bt(ich)
          st(ich,1) = st(ich,1) + btdiff
          st(ich,2) = st(ich,2) + btdiff ** 2
         enddo
         ENDIF
        ENDIF
       ENDIF
       ENDIF

1234   format(i6,2f9.2)
248          IF(EOF) GOTO 300
       KT = KT + 1
298    CONTINUE
       ENDDO
300    CONTINUE
       write(*,*)'end of loop ',' KS ',KS
       DO ICH = 1,23
         ST(ICH,1) = ST(ICH,1) / KS
         ST(ICH,2) = ST(ICH,2) / KS - ST(ICH,1) * ST(ICH,1) 
         ST(ICH,2) = SQRT(ST(ICH,2))
         WRITE(*,1234)ICH,ST(ICH,1),ST(ICH,2)
       enddo
       write(*,*)'end of old part of st'
      
        WRITE(6,*) 'NUMBER OF TOTAL RECORDS IS ', KT
        GOTO 311
 309    WRITE(6,*) 'IO ERROR', IOS
 311    CONTINUE

        STOP
        END

        SUBROUTINE TOVS_DAT( 
C
C************************************************************************
C*
C*      Module Name:    TOVS_DAT                                        *
C*                                                                      *
C*      Language:       Fortran-77                                      *
C*									*
C*      Version.Rev:    1.0 10 April 98 Programmer: po                  *
C*                                                                      *
C*      Calling Seq:    Call Precip_Water_Profile(Q,P,Za,N,Pw)          *
C*                                                                      *
C*      Description:    Read a tovs satellite record                    *
C*									*
C*      Input Args:     None						*
C*									*
C*      Output Args:    I     IDSAT   satellite ID                      *
C*                      I     IYEAR   year                              *
C*                      I     IMONTH  month  				*
C*			I     IDAY    day				*
C*			I     IHOUR   hour				*
C*			I     IMIN    minute				*
C*			I     ISEC    second				*
C*			R     XLAT    latitude				*
C*			R     XLON    longititude			*
C*			R     ZANGLE  solar zenith angle		*
C*			R     IELEV   land and sea indicator		*
C*			R     STEMP   surface temperature		*
C*			R     BPRESS  pressure at bottom of sounding	*
C*			I     ICOMB   instrument or/and channel comb.   *
C*			I     RM      retrival method			*
C*			I     XMEAN   mean value of N*			*
C*			R     SCOUNT  superwash count			*
C*			R     BCOUNT  box count				*
C*			R     CBMINI  minibox count			*
C*			R     SSTEMP  sea surface temperature		*
C*			I     AOZONE  total ozone amount		*
C*			I     QOZONE  total ozone quality		*
C*			R     CCPRES  cloud cover pressure		*
C*			R     CCOVER  cloud cover amount		*
C*			R     EBTEMP  equivalent brightness temperature *
C*                      R     t8      channel 8 uncorrected bt          *
C*                      R     t18     channel 18 uncorrected bt		*
C*			R     t19     channel 19 uncorrected bt         * 
C*                      L     EOF     signal to reach the end of file   *
C*                                                                      *
C************************************************************************
C
     $     IDSAT, 
     &     IYEAR,
     $     IMONTH,
     $     IDAY,
     $     IHOUR, 
     $     IMIN, 
     $     ISEC,
     $     XLAT,
     $     XLON,
     $     ZANGLE,
     $     IELEV,
     $     STEMP,
     $     BPRESS,
     $     ICOMB, 
     $     RM,
     $     XMEAN,
     $     SCOUNT,
     $     BCOUNT,
     $     CBMINI,
     $     SSTEMP,
     $     AOZONE,
     $     QOZONE,
     $     CCPRES,
     $     CCOVER,
     $     EBTEMP,
     $     t8,
     $     t18,
     $     t19,
     $     EOF)
CC      This program read the NESDIS operaitonal satellite tape
        INTEGER NESREC(140), IYEAR, IMONTH, IDAY, IHOUR, IMIN, ISEC,
     $            IELEV, ICOMB, ICHIRS, NMARK, ICHMSU, ICHSSU, NCH,
     $            ICH, INUM, NSERIE, IDSAT, AOZONE, QOZONE,XMEAN,RM
        REAL XLAT, XLON, ZANGLE, STEMP, BPRESS, SCOUNT, BCOUNT,
     $            CBMINI, SSTEMP, CCPRES, CCOVER, EBTEMP(23) 
        LOGICAL EOF
c        CHARACTER*280 NESDIN
C
CC     Local variables
	Integer nesdin(35)   ! unpack routine variable
	Integer I2extI8,Tmp,i
        real pcor(5,3,0:2)   ! coefficients to convert channel 8, 18 ,19
C         correcrted brightness temperature into uncorrected ones.
        data pcor/
     $    9.7364, 1.6207, -1.9637, 0., 0.31597, 7.052, 0.58602,
     $    -0.68382, 0.072734, 0., 4.871, 0.70082, -0.81477, 0.0,
     $    0.098153,
     $    13.531, 1.9471, -2.3146, 0.19174, 0.13624, 7.3404,
     $    0.35009, -0.35813, 0.034253, -0.054317, 4.8341,
     $    0.68990, -0.77987, 0.03482, 0.040656,
     $    6.993, 2.104, -2.475, -0.007727, 0.3647, 6.909,
     $    0.5882, -0.6488, 0.03584, 0.0, 3.282, 0.8889,
     $    -1.017, 0.0007867, 0.1186/

        EOF = .FALSE.

C
CC       Read tovs data by calling UNPACK routine
CC      !!!!  Important !!!!
CC      Tovs data is read by NOAA UNPACK routine and that is the only way.
CC
C
        READ(32, END=310)NESDIN
        CALL UNPACK(NESDIN, 16, NESREC, 140)
C
CC      TO READ SATELLITE IDENTIFICATION
C
        IDSAT = NESREC(1)

C
CC      TO READ THE TIMETABLE OF SATELLITE DATA
C
        IYEAR = NESREC(2) / 256
        IMONTH = MOD(NESREC(2), 256)

        IDAY = NESREC(3) / 256
        IHOUR = MOD(NESREC(3), 256)

        IMIN = NESREC(4) / 256 
        ISEC = MOD( NESREC(4), 256 )

C
CC      TO READ THE LATITUDE (XLAN) AT THE CENTER POINT OF
CC       SATELLITE OBSERVATIONS. ' + 'VALUE FOR THE NORTH HEMISPHERE;
CC       ' - ' VALUE FOR THE SOUTH HEMISPHERE.
C
C
	Tmp = nesrec(5)
	
	Xlat = I2extI8(Tmp)/100. 
CC      TO READ THE LONGITUDE (XLON) AT THE CENTER POINT OF
CC       SATELLITE OBSERVATIONS. RANGE: 180 TO 0, EAST HEMISPHERE;
CC       0 TO -180, WEST HEMISPHERE.
C
	Tmp = nesrec(6)
	
	Xlon = I2extI8(Tmp)/100. 


C
CC      TO READ SOLAR ZENITH ANGLE (ZANGLE). 
CC      DAYTIME: 0 < ANGLE < 90; NIGHT: 90.
C
        ZANGLE = NESREC(7) / 100.

C
CC      TO READ LAND/SEA INDICATOR. LAND, SURFACE ELEVATION (IELEV) 
CC      IN METERS; IF SEA, SET ZERO.
C
        IELEV = NESREC(8)

C
CC      TO READ THE SURFACE TEMPERATURE (STEMP)
C
        STEMP = NESREC(9) / 10.

C
CC      TO READ THE ESTIMATED PRESSURE AT THE BASE OF SOUNDINGS
CC      (BPRESS) (mbs)
C
        BPRESS = NESREC(10) /10.

C
CC      TO OUUTPUT THE INSTRUMENT AND/OR CHANNEL COMBINATION (ICOMB).
C
        ICOMB = NESREC(11)
C
CC      TO READ THE RETRIEVAL METHOD
C
        RM = NESREC(12)

C
CC      TO READ THE MEAN VALUE OF N* (XMEAN). N* RANGES FROM 0 TO 1.
C
        XMEAN = NESREC(15) 

C
CC      TO READ SUPERSWATH COUNT (SCOUNT) , BOX COUNT (BCOUNT), 
CC      AND MINIBIX COUNTER.
C
        SCOUNT = AINT(NESREC(16) / 1000.)
        BCOUNT = AINT(NESREC(16) / 10.) - SCOUNT*100
        CBMINI = FLOAT(NESREC(16))- AINT(NESREC(16) / 10.) * 10

C
CC      TO OUPPUT SEA SURFACE TEMPERATURE (SSTEMP)
C
        SSTEMP = NESREC(17) / 10.

C
CC      TO READ THE TOTAL OZONE AMOUNT (DOBSON INITS)
C
        AOZONE = NESREC(99)

C
CC      TO READ THE TOTAL OZONE QUALITY (percent)
C
        QOZONE = NESREC(100)

C
CC      TO READ THE CLOUD COVER PRESSURE (CCPRES) (mbs)
C
        CCPRES = NESREC(101) / 10.

C
CC      TO READ THE CLOUD COVER AMOUNT (CCOVER) (percent)
C
        CCOVER = NESREC(102)


C   
CC      TO READ EQUIVALENT BLACKBODY TEMPERATURES(EBTEMP) USED
CC      TO OBTAIN HIRS/2 CHANNEL 1-19.
C
        ICH = 0
        NSERIE = 102
        DO ICHIRS = 1, 19
           ICH = ICH + 1
           NMARK= NSERIE + ICHIRS
           EBTEMP(ICH) = NESREC(NMARK) / 64.
        ENDDO

C
CC      TO READ EQUIVALENT BLACKBODY TEMPERATURES(EBTEMP) UESD
CC      TO OBTAIN HIRS/2 CHANNEL 20.
c        ICH = ICH +1
c        INUM = 2
c        TCH20 = NESREC(122) / 16.

C
CC         TO READ EQUIVALENT BLACKBODY TEMPERATURES(EBTEMP) UESD
CC         TO OBTAIN MSU CHANNEL 1-4
C
        NSERIE = 122
        DO ICHMSU = 1, 4
           ICH =ICH + 1
           NMARK = NSERIE + ICHMSU
           EBTEMP(ICH) = NESREC(NMARK) / 64.
        ENDDO
C
CC      Make water vapor attenuation correction for NOAA 10 -- 12
CC      HIRS channels 8, 18 and 19.
C
        ID = IDSAT
        TCOR8  = (EBTEMP(8) - PCOR(1,1,ID) - PCOR(3,1,ID)*EBTEMP(10)
     $          - PCOR(4,1,ID)*EBTEMP(11) - PCOR(5,1,ID)*EBTEMP(21))
     $          /(1. + PCOR(2,1,ID))
        TCOR18 = EBTEMP(18) - PCOR(1,2,ID) - PCOR(2,2,ID)*TCOR8 -
     $           PCOR(3,2,ID)*EBTEMP(10) - PCOR(4,2,ID)*EBTEMP(11)-
     $           PCOR(5,2,ID)*EBTEMP(21)
        TCOR19 = EBTEMP(19) - PCOR(1,3,ID) - PCOR(2,3,ID)*TCOR8 -
     $           PCOR(3,3,ID)*EBTEMP(10) - PCOR(4,3,ID)*EBTEMP(11)-
     $           PCOR(5,3,ID)*EBTEMP(21)
        t8 = ebtemp(8)
        t18 = ebtemp(18)
        t19 = ebtemp(19)
        EBTEMP(8)  = TCOR8
        EBTEMP(18) = TCOR18
        EBTEMP(19) = TCOR19
C
CC         TO READ EQUIVALENT BLACKBODY TEMPERATURES(EBTEMP) USED
CC         TO OBTAIN SSU CHANNEL 1-4
C
c        NSERIE = 126
c        DO ICHSSU = 1, 3   
c           ICH = ICH + 1
c           NMARK = NSERIE + ICHSSU
c           EBTEMP(ICH) = NESREC(NMARK) / 64.
c        ENDDO
	RETURN	

 310    CONTINUE
        EOF = .TRUE.
        RETURN

        END         

	Integer Function I2extI8(In)
*	Sign extends a I*2 signed integer to I*8
	Integer In
	If(Btest(In,15)) Then
	  I2extI8 = OR(In,x'FFFFFFFFFFFF0000')
	Else
	  I2extI8 = In
	EndIf

	Return
	End

        subroutine intp_nr(
C
C************************************************************************
C*									*
C*	Module Name:	intp_nr						*
C*									*
C*	Language:	Fortran-77					*
C*									*
C*	Version:	1.0 10 April 98 Programmer: Po			*
C*									*
C*	Calling Seq:	Call intp_nr(clat,clon,p,t,q,wspeed,tskin,	*
C*			ccover,pmax,pmin,cc)				*
C*									*
C*	Description:	Use four-point distance-weighting method	*
C*			to interpolate nr meteorological profiles 	*
C*			and cloud information in nr grid coordinate	* 
C*			according to tovs latitude and longitude        *
C*									*
C*	Input Args:	R	clat    tovs latitude			*
C*			R	clon    tovs longitude			*
C*									*
C*      nr = nature run
C*	Output Args:	R	P(31)	nr pressure profile		* 
C*			R	t(31)	nr temp. profile		*
C*			R	q(31)	nr moist profile		*
C*			R	wspeed  nr 10m wind speed		*
C*			R	tskin	nr skin temp.			*
C*			R	ccover  nr maximum cloud cover		*
C*			R	pmax	nr cloud base pressure		*
C*			R	pmin	nr cloud top pressure		*
C*			R	cc	nr cloud cover profile		*
     $      clat,
     $      clon,
     $      p,
     $      t,
     $      q,
     $      wspeed,
     $      tskin,
     $      ccover,
     $      pmax,
     $      pmin,
     $      cc)
C
CC    common block
C
        common dat(641,320),tdat(641,320,31),qdat(641,320,31)
        common /cldcov/ ccov(641,320,31)
        common /pskn/ wskn(641,320),tskn(641,320)
C
CC    input
C
      Real clat,clon
C
CC    output
C
      Real p(31), t(31), q(31),cc(31)
      Real wspeed, tskin, ccover, pmax, pmin 
C
CC    Local 
C
      Real presuf(32,2,4)  !nr pressures profile around tovs point 
      Real tlow(4)
      Real lnsp
      Real tq(31,2,4)      ! nr T and q profiles around tovs point

      Integer ystart
      Integer istep(18)    ! number of nr longitude at each 10 degree
      data (istep(i), i=1,18)/1,18,35,53,71,89,107,124,142,
     *            160,178,196,213,231,249,267,285,302/

      Real para(32,2)      ! nr coeff. to get pressure profile from log P
      DATA para / 0.0, 2000., 4000., 6000.,
     $ 8000.0, 9976.136719,11820.539063, 13431.394531,
     $ 14736.355469, 15689.207031, 16266.609375, 16465.003906,
     $ 16297.621094, 15791.597656, 14985.269531, 13925.519531,
     $ 12665.292969, 11261.230469, 9771.40625, 8253.210938,
     $ 6761.339844, 5345.914063, 4050.717773, 2911.569336,
     $ 1954.805176, 1195.889893, 638.148926, 271.626465,
     $ 72.063583, 0.0, 0.0, 0.0,
     $ 0.0, 0.0, 0.0, 0.0,
     $ 0.0, 0.0003908582, 0.0029197007, 0.0091941319,
     $ 0.0203191563, 0.0369748585, 0.0594876409, 0.0878949761,
     $ 0.1220036149, 0.161441505, 0.2057032585, 0.2541885972,
     $ 0.3062353730, 0.3611450195, 0.418202281, 0.4766881466,
     $ 0.5358865857, 0.59508425, 0.6535645723, 0.7105944157,
     $ 0.7654052377, 0.8171669841, 0.8649558425, 0.907715857,
     $ 0.9442132115, 0.972985208, 0.9922814965, 1.0 /

      Real grblat(320)     ! nr 320 grid point in longitude 
      DATA grblat /
     $  89.570090,  89.013176,  88.452974,  87.892028,  87.330801,
     $  86.769438,  86.207998,  85.646511,  85.084993,  84.523454,
     $  83.961900,  83.400334,  82.838759,  82.277177,  81.715590,
     $  81.153998,  80.592403,  80.030805,  79.469204,  78.907601,
     $  78.345996,  77.784389,  77.222782,  76.661172,  76.099562,
     $  75.537951,  74.976339,  74.414727,  73.853113,  73.291499,
     $  72.729885,  72.168270,  71.606655,  71.045039,  70.483423,
     $  69.921806,  69.360189,  68.798572,  68.236955,  67.675337,
     $  67.113719,  66.552101,  65.990483,  65.428865,  64.867246,
     $  64.305627,  63.744008,  63.182389,  62.620770,  62.059151,
     $  61.497532,  60.935912,  60.374292,  59.812673,  59.251053,
     $  58.689433,  58.127813,  57.566193,  57.004573,  56.442953,
     $  55.881332,  55.319712,  54.758092,  54.196471,  53.634851,
     $  53.073230,  52.511610,  51.949989,  51.388368,  50.826748,
     $  50.265127,  49.703506,  49.141885,  48.580264,  48.018643,
     $  47.457022,  46.895401,  46.333780,  45.772159,  45.210538,
     $  44.648917,  44.087296,  43.525675,  42.964054,  42.402432,
     $  41.840811,  41.279190,  40.717569,  40.155947,  39.594326,
     $  39.032705,  38.471083,  37.909462,  37.347841,  36.786219,
     $  36.224598,  35.662976,  35.101355,  34.539734,  33.978112,
     $  33.416491,  32.854869,  32.293248,  31.731626,  31.170005,
     $  30.608383,  30.046762,  29.485140,  28.923518,  28.361897,
     $  27.800275,  27.238654,  26.677032,  26.115410,  25.553789,
     $  24.992167,  24.430546,  23.868924,  23.307302,  22.745681,
     $  22.184059,  21.622437,  21.060816,  20.499194,  19.937572,
     $  19.375951,  18.814329,  18.252707,  17.691085,  17.129464,
     $  16.567842,  16.006220,  15.444599,  14.882977,  14.321355,
     $  13.759733,  13.198112,  12.636490,  12.074868,  11.513246,
     $  10.951625,  10.390003,   9.828381,   9.266759,   8.705138,
     $   8.143516,   7.581894,   7.020272,   6.458650,   5.897029,
     $   5.335407,   4.773785,   4.212163,   3.650542,   3.088920,
     $   2.527298,   1.965676,   1.404054,   0.842433,   0.280811,
     $  -0.280811,  -0.842433,  -1.404054,  -1.965676,  -2.527298,
     $  -3.088920,  -3.650542,  -4.212163,  -4.773785,  -5.335407,
     $  -5.897029,  -6.458650,  -7.020272,  -7.581894,  -8.143516,
     $  -8.705138,  -9.266759,  -9.828381, -10.390003, -10.951625,
     $ -11.513246, -12.074868, -12.636490, -13.198112, -13.759733,
     $ -14.321355, -14.882977, -15.444599, -16.006220, -16.567842,
     $ -17.129464, -17.691085, -18.252707, -18.814329, -19.375951,
     $ -19.937572, -20.499194, -21.060816, -21.622437, -22.184059,
     $ -22.745681, -23.307302, -23.868924, -24.430546, -24.992167,
     $ -25.553789, -26.115410, -26.677032, -27.238654, -27.800275,
     $ -28.361897, -28.923518, -29.485140, -30.046762, -30.608383,
     $ -31.170005, -31.731626, -32.293248, -32.854869, -33.416491,
     $ -33.978112, -34.539734, -35.101355, -35.662976, -36.224598,
     $ -36.786219, -37.347841, -37.909462, -38.471083, -39.032705,
     $ -39.594326, -40.155947, -40.717569, -41.279190, -41.840811,
     $ -42.402432, -42.964054, -43.525675, -44.087296, -44.648917,
     $ -45.210538, -45.772159, -46.333780, -46.895401, -47.457022,
     $ -48.018643, -48.580264, -49.141885, -49.703506, -50.265127,
     $ -50.826748, -51.388368, -51.949989, -52.511610, -53.073230,
     $ -53.634851, -54.196471, -54.758092, -55.319712, -55.881332,
     $ -56.442953, -57.004573, -57.566193, -58.127813, -58.689433,
     $ -59.251053, -59.812673, -60.374292, -60.935912, -61.497532,
     $ -62.059151, -62.620770, -63.182389, -63.744008, -64.305627,
     $ -64.867246, -65.428865, -65.990483, -66.552101, -67.113719,
     $ -67.675337, -68.236955, -68.798572, -69.360189, -69.921806,
     $ -70.483423, -71.045039, -71.606655, -72.168270, -72.729885,
     $ -73.291499, -73.853113, -74.414727, -74.976339, -75.537951,
     $ -76.099562, -76.661172, -77.222782, -77.784389, -78.345996,
     $ -78.907601, -79.469204, -80.030805, -80.592403, -81.153998,
     $ -81.715590, -82.277177, -82.838759, -83.400334, -83.961900,
     $ -84.523454, -85.084993, -85.646511, -86.207998, -86.769438,
     $ -87.330801, -87.892028, -88.452974, -89.013176, -89.570090 /
         
c       do i=1,32
c         write(18,*) para(i,1),para(i,2)
c       enddo
c       write(19,102) (grblat(i), i=1,320)
c102    format(64(5f12.6/))
c             write(*,*)(istep(i), i=1,18)
             pi = 3.1415926
c             cearth = 6371./360.
             cearth = 1.
C
CC    the range for clat:  -90S  < clat < 90N  from nr definition   
CC    the range for clon:  -180W < clon < 180E 
C
c             write(*,*)clat,clon

C     Find the closest nr longitude at the west of tovs point from nr grid
             if(clon.lt.0.0)then
               clon1 = clon + 360.
             else 
               clon1 = clon
             endif
c             write(*,*)' clon1 ', clon1
             xnum = aint(clon1/0.5625)

C    nx is the number of this closest nr longitude grid.
             nx = int(xnum+1)
C
C    computer the logitudes of two closest grids near tovs observation
C    xlonb is at the west and xlone at the east
             xlonb = 360.*xnum/640.
             xlone = 360.*(xnum+1.)/640.
c             write(*,*)xlonb,xlone,xnum,'nx= ',nx

C    computer angle distances between these two grid and tovs obs. 
C    in longitude direction.
             xrad = clat*pi/180.
             xadcb = clon1 - xlonb
             xadce = xlone - clon1 

c             write(*,*)' acb=', xadcb, ' ace=', xadce
C    xdiscb is the distance in longitude dir.(x-dir) between 
C    the west grid and tovs obs., 
             xdiscb = cos(xrad)*(clon1-xlonb)*cearth  

C    xdisce between the east nr grid and tovs observation
             xdisce = cos(xrad)*(xlone-clon1)*cearth 
c             write(*,*)cos(xrad),'cb=',xdiscb,'ce=',xdisce

C
CC   Find the number of the closest nr latitude in grid array.
C
                 clat2 = clat - 90.
                 clat1 = abs(clat2)
                 ynum = aint(clat1/10.) + 1.
                 nyst = int(ynum)
                 ystart = istep(nyst)
                 k = ystart 
                 do 10 while(clat.le.grblat(k))
                   k = k + 1
10               continue
                 ny = k - 1  ! ny is that number

C    Find two latitudes in nr grid array closest to tovs obs.
C    ylatb is at the north and ylate at the south of tovs obs. 
                 ylatb = grblat(ny)
                 ylate = grblat(ny+1)

C    compute the angle distances in latitude between the above grids and  
C    tovs obs.
                 yacb = ylatb-clat
                 yace = clat-ylate
c        write(*,*)'ny ',ny,' yacb= ', yacb, ' yace= ', yace

C    compute the distances in km between the above grids and
C    tovs obs.
                 ydiscb = (ylatb-clat)*cearth
                 ydisce = (clat-ylate)*cearth
c                 write(*,*)ylatb,ylate,ny
c             write(*,*) 'ydiscb= ',ydiscb,'ydisce=', ydisce

CC   compute four distances between tovs obs. and each grid point 
CC   which shapes a rectangle surrounding tovs obs.
C    disbb: a distance between tovs obs. and its northwest nr grid point   
               disbb1 = xdiscb**2 + ydiscb**2
               disbb  = sqrt(disbb1)

C   disbe: a distance between tovs obs. and its northeast nr grid point
               disbe1 = xdiscb**2 + ydisce**2
               disbe  = sqrt(disbe1)

C   diseb: a distance between tovs obs. and its southwest nr grid point
               diseb1 = xdisce**2 + ydiscb**2
               diseb  = sqrt(diseb1)

C   disee: a distance between tovs obs. and its southeast nr grid point
               disee1 = xdisce**2 + ydisce**2
               disee  = sqrt(disee1)

C  compute total weighting
             dwsum=1./disbb +1./disbe +1./diseb +1./disee
c         write(*,*)'disbb ', disbb,' disbe ', disbe
c         write(*,*)'diseb ', diseb,' disee ', disee
c         write(*,*)'dwsum ', dwsum

C
CC     compute pressure profile(see nr reference)
C
             k=1
             nx1=nx+1
             ny1=ny+1
            do m=nx, nx1
             do n=ny,ny1
               lnsp=dat(m,n)
               presuf(32,2,k)=exp(lnsp)
               pres= presuf(32,2,k)
              do i=1,31 
               presuf(i,2,k)= para(i,1)+ para(i,2)*pres 
             enddo
             do i=1,31
             presuf(i,1,k)=(presuf(i,2,k)+presuf(i+1,2,k))/200.
             enddo
             k=k+1
             enddo
            enddo
            do i=1,31

C    compute four-point weighted pressure profile p(i)
              wbb = presuf(i,1,1) / disbb
              web = presuf(i,1,2) / diseb
              wbe = presuf(i,1,3) / disbe
              wee = presuf(i,1,4) / disee
              p(i) = (wbb+web+wbe+wee)/dwsum
            enddo
                 
C   compute four-point weighted surface wind speed
              wbbw = wskn(nx,ny) / disbb
              webw = wskn(nx1,ny) / diseb
              wbew = wskn(nx,ny1) / disbe
              weew = wskn(nx1,ny1) / disee
       wspeed = (wbbw+webw+wbew+weew) / dwsum 

C   compute four-point weighted surface skin temperature
              wbbt = tskn(nx,ny) / disbb
              webt = tskn(nx1,ny) / diseb
              wbet = tskn(nx,ny1) / disbe
              weet = tskn(nx1,ny1) / disee
       tskin = (wbbt+webt+wbet+weet) / dwsum

       ccover = 0.
       pmax = 0.
       pmin = p(31)
       tlow(1) = tdat(nx,ny,31)
       tlow(2) = tdat(nx1,ny,31)
       tlow(3) = tdat(nx,ny1,31)
       tlow(4) = tdat(nx1,ny1,31)

       do i=1,31
          tq(i,1,1)=tdat(nx,ny,i)
          tq(i,1,2)=tdat(nx1,ny,i)
          tq(i,1,3)=tdat(nx,ny1,i)
          tq(i,1,4)=tdat(nx1,ny1,i)
          wbb = tq(i,1,1) / disbb
          web = tq(i,1,2) / diseb
          wbe = tq(i,1,3) / disbe
          wee = tq(i,1,4) / disee

C    compute four-point weighted temperature profile t(i)
          t(i) = (wbb+web+wbe+wee)/dwsum 

          tq(i,2,1)=qdat(nx,ny,i)*1000.
          tq(i,2,2)=qdat(nx1,ny,i)*1000.
          tq(i,2,3)=qdat(nx,ny1,i)*1000.
          tq(i,2,4)=qdat(nx1,ny1,i)*1000.
          wbb = tq(i,2,1) / disbb
          web = tq(i,2,2) / diseb
          wbe = tq(i,2,3) / disbe
          wee = tq(i,2,4) / disee

C    compute four-point weighted moist profile q(i)
          q(i) = (wbb+web+wbe+wee)/dwsum

          wbb = ccov(nx,ny,i) / disbb
          web = ccov(nx1,ny,i) / diseb
          wbe = ccov(nx,ny1,i) / disbe
          wee = ccov(nx1,ny1,i) / disee

C    compute four-point weighted cloud cover profile cc(i)
          cc(i) = (wbb+web+wbe+wee)/dwsum
C
C    decide the maximim cloud cover from cloud cover profile
          if(cc(i).gt.ccover)ccover = cc(i)
          if(cc(i).gt.0.0)then

C    decide cloud bottom and top pressure
            if(p(i).gt.pmax)pmax=p(i)
            if(p(i).lt.pmin)pmin=p(i)
          endif
        
c       write(*,*)'wbb=',wbb,' web=',web,' wbe=',wbe,' wee=',wee
c       write(*,3901)tq(i,2,1),tq(i,2,2)
c       write(*,3902)disbb,diseb
c       write(*,3903)q(i)
c       write(*,3902)disbe,disee
c       write(*,3904)tq(i,2,3),tq(i,2,4)
       enddo
c3901   format(/f15.6,40x, f15.6)
c3902   format(18x, f12.4,20x, f12.4)
c3903   format(30x, f15.6)
c3904   format(f15.6,40x, f15.6/)
c150          format(i3,f9.2,f9.2,f10.6)
c             do k=1,4
c                 write(2,151) k
c               do i=1,31
c                 write(2,150)i,presuf(i,1,k),tq(i,1,k),tq(i,2,k)
c               enddo
c             enddo
c151          format(//i6//)
300        continue
3000         continue
             end

*	Tests the radiance computation of RTATOV
c        subroutine trad(p,t,q,o3,ptb,ky,idsat,wspeed,tskin,
c     *          ccover,ptop,mis21)
        subroutine OPTRAN_SET(p,t,q,o3,ptbcl,ky,idsat,wspeed,tskin,
     *          ccover,ptop,pbot,iel,emissv)
       Implicit None

*	RTATOV Program constants

	Integer KNPF 		! number of profile vectors
	Parameter (Knpf=1)
	Integer KLAPF 		! length of each profile vector
        Parameter (Klapf=50)
	Integer Knav 		! number of atmospheric variables,t,q,o3,clw
	Parameter (Knav=4)
	Integer Knsav 		! number of sfc air varibles
				! P,Wind speed,T,Q,O3,CLW
	Parameter (Knsav=6)
	Integer Knssv 		! number of surface skin variables
				! T, 4mw emiss, 1ir emiss
	Parameter (Knssv=6)
	Integer Kncv 		! number of could variables
				! IR fract cloud, top P, base P, Re
	Parameter (Kncv=4)
	
*	RTATOV Program variables

	Real Ppres(Klapf) 	! pressure profile
	Real Pangl(Knpf)	! angle
	Real Pangs(Knpf)	! solar zenith angle
	Real Panga(Knpf)	! relative solar azimuth angle
	Integer Kcld(Knpf)	! index of cloud type
	Integer Ksurf(Knpf)	! index of surface type
	Integer Ksat		! satellite index
	Integer Knchpf 		! number of channels (*number of profiles
	Parameter (Knchpf=23)

	Integer Kchan(23)	! Index of channels
	Data Kchan
     &   / 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15,16,17,18,19,
     &    21,22,23,24 /

	Integer Nchan 
	Data Nchan /23/
	Integer Kprof(Knchpf)   ! array of profile indices
        Integer idsat           ! satellite ID number
        INteger ccover          ! maximun cloud cover in a cloud cover profile
        Integer i,ky,iel,emissv
        Real ptop,pbot,wspeed,tskin
	Data Kprof
     &	 /Knchpf*1/

*	RTATOV input variables

	Real PAV(Klapf,Knav,Knpf) ! atmospheric profile variables
	Real Psav(Knsav,Knpf) 	  ! surface air variables
	Real Pssv(Knssv,knpf)	  ! surface skin variables
	Real Pcv(Kncv,Knpf)	  ! cloud variables

*	RTATOV output variables

	Real Prd(Knchpf)	! radiances
	Real Ptb(Knchpf)	! brightness temperatures
	Real Prdov(Knchpf,Klapf)! overcaset radiance profile
	Real Prdo(Knchpf)	! overcast radiance at cloud top
	Real Prdcl(Knchpf)	! clear column radiance
	Real Ptbcl(Knchpf)	! clear column brightness temperature
	Real Ptau(Knchpf,Klapf) ! transmittance profile
	Real Ptaus(Knchpf)	! surface to space transmittance

*	Local variables

CC
	Real P(41),T(41),q(41),O3(41) ! atmospheric stuff 
	Real Tau(Klapf)

CC
c        Data P
c     &  / .1,.2,.5,1.,1.5,2.,3.,4.,5.,7.,10.,15.,20.,25.,30.,    
c     &  50.,60.,70.,85.,100.,115.,135.,150.,200.,250.,300.,350.,400.,     
c     &  430.,475.,500.,570.,620.,670.,700.,780.,850.,920.,950.,1000.,     
c     &  1025.,1050./

	Integer Ichan,Jchan,Iangle,Iatm,Level
	Integer Ierr

c        Real Angle(5) 
C        Data Angle /0.0, 36.869898, 48.189685, 55.150095, 60.0/
        Real Angle(1) 
	Data Angle / 0.0 /

        idsat = 11
        if(ky.eq.1)then
         write(*,*)'call Rttvi idsat = ',idsat,ky
	 Call Rttvi(Ierr,idsat,1) ! tovs
	 If(Ierr .ne. 0) Then
          write(*,*)'Satellite ID number #', idsat
	  Write(6,*) 'Rttvi error ',ierr
	  Stop
	 Endif
        endif

         do i=1,41
c            o3(i)=o3(i)/1000.
            o3(i)=o3(i)*29./48.
         enddo

!	Specify atmosphere
CC
C       do Iatm = 1 , 1
C        Call Ds32_mf(Iatm,T,q,o3,Iatm)

CC
	 Do level = 1 , 40
	  Pav(level,1,Knpf) = T(level) 
CC
	  Pav(level,2,Knpf) = q(level)/1000.
c          Pav(level,2,Knpf) = q(level)/1000.
CC

          Pav(level,3,Knpf) = O3(level)/1000.
	  Pav(level,4,Knpf) = 0.0 ! clw sfc cloud liquid water
	  Ppres(level) = P(level)
	 EndDo

!	Specify surface air
CC
	 Psav(1,Knpf) = p(41) 
c         Psav(2,Knpf) = 0.0 ! wind speed
         Psav(2,Knpf) = wspeed ! wind speed
CC
	 Psav(3,Knpf) = T(41)
	 Psav(4,Knpf) = q(41)/1000.
         Psav(5,Knpf) = O3(41)/1000.

	 Psav(6,Knpf) = 0.0 ! clw

!	Specify skin
CC
c         Pssv(1,Knpf) = t(41)
         Pssv(1,Knpf) = tskin
	 Pssv(2,Knpf) = 0.6
	 Pssv(3,Knpf) = 0.6
	 Pssv(4,Knpf) = 120.7
	 Pssv(5,Knpf) = 1.184
	 Pssv(6,Knpf) = 1.0

! 	Specify Cloud
CC
	 Pcv(1,Knpf) = ccover
	 Pcv(2,Knpf) = ptop
	 Pcv(3,Knpf) = pbot
	 Pcv(4,Knpf) = 0.0

!	Do radiative transfer

	 Do Iangle = 1 , 1
C        Do Iangle = 1 , 5 
	  Pangl(Knpf) = Angle(Iangle)
	  Pangs(Knpf) = 0.0
	  Panga(Knpf) = 0.0
	  Kcld(Knpf) = 1
	  Ksurf(Knpf) = 1
	  Ksat = 1
	  Call RTATOV(KNPF,40,KNAV,KNSAV,KNSSV,KNCV,  
     *                PPRES,PANGL,PANGS,PANGA,KCLD,KSURF,     
     *                KSAT,NCHAN,KCHAN,KPROF,     
     *                PAV,PSAV,PSSV,PCV,     
     *                PRD,PTB,PRDOV,PRDO,PRDCL,PTBCL,     
     *                PTAU,PTAUS,iel,emissv)

	 EndDo
	
	continue
	End

        Subroutine NH_UPAIR_PRF(
C
C************************************************************************
C*									*
C*	Module Name:	NH_UPAIR_PRF					*
C*									*
C*	Language:	Fortran-77					*
C*									*
C*	Version Rev:	1.0 10 April 98 Programmer:po			*
C*									*
C* 	Call Seq:	Call NH_UPAIR_PRF(ylat,ttopnr,tup,qup)		*
C*									*
C*	Description:	interpolate upper atmosphere profile(10mb - 0.1 *
C*                      mb) for north hemisphere winter according to	*
C*			latitude of tovs obs.				*
C*									*
C*  	Input Args:	R	xlat    tovs obs.'s latitude		*
C*			R	tnr     nr top level temp.		*
C*									*
C*	Output Args:	R  	tu(10) upper temp. profile		*
C*			R	qu(10) upper moist profile		*
C*									*
C************************************************************************
C
     $  xlat,
     $  tnr,
     $  tu,
     $  qu)

C        dimension tu(10),qu(10),tqt(10,2),tqmw(10,2),tqaw(10,2),
C     $            tqt1(10,2),tqmw1(10,2),tqaw1(10,2)

C    Input
       Real xlat, tnr

C    Output
       Real tu(10), qu(10)

C    Local 
       Real tqt(10,2),tqmw(10,2),tqaw(10,2)

       Real tqt1(10,2)  
C      the first ten element: temp. diffence profile above 10 mb(temp at 10mb
C        - temp. above 10 mb)
C      the last ten element: moist profile.
c      Atmosphere : 2   reference originale :  1
c      tropical 
       data tqt1/          
     +   -3.72,  13.33,  29.11,  34.60,  30.40,  25.69,  18.98,  14.25, 
     +   10.69,   5.44, 
     +   0.003,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003/  

       Real tqmw1(10,2)
C      the first ten element: temp. diffence profile above 10 mb(temp at 10mb
C        - temp. above 10 mb)
C      the last ten element: moist profile.
c      Atmosphere : 4   reference originale :  3
c      midlatitude winter
       data tqmw1/    
     +   23.43,  33.52,  44.98,  45.60,  36.80,  30.24,  21.27,  15.09, 
     +   10.43,   3.72, 
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003/  

       Real tqaw1(10,2)
C      the first ten element: temp. diffence profile above 10 mb(temp at 10mb
C        - temp. above 10 mb)
C      the last ten element: moist profile.
c      Atmosphere : 6   reference originale :  5
c      polar winter
       data tqaw1/
     +   33.14,  37.95,  43.13,  32.81,  25.49,  20.53,  13.63,   8.84, 
     +    5.56,   2.29, 
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003/  

        do j=1,10

C    take temp. adjustment from nr 10mb temp.
           tqt(j,1)=tqt1(j,1)+tnr
           tqmw(j,1)=tqmw1(j,1)+tnr
           tqaw(j,1)=tqaw1(j,1)+tnr

C    assign moist profile
           tqt(j,2)=tqt1(j,2)   
           tqmw(j,2)=tqmw1(j,2)   
           tqaw(j,2)=tqaw1(j,2)   
        enddo

C
CC     Interpolate temperature and moist profile according tovs obs.
CC     latiutde.
CC     ALGORITHM:
CC           xlat < 25:  assign tropical
CC      25 < xlat < 35:  interpolater from midlatiutde winter and tropical
CC      35 < xlat < 55:  assign midlatiutde winter
CC      55 < xlat < 65:  interpolater from midlatiutde winter and arctic winter
CC      65 < xlat     :  assign arctic winter
        if(xlat.lt.35.)then
         if(xlat.le.25.)then
          do i=1,10
            tu(i)=tqt(i,1)
            qu(i)=tqt(i,2)
          enddo
         else 
          do i=1,10
            tu(i)=tqt(i,1)+(xlat-25.)*(tqmw(i,1)-tqt(i,1))/10.   
            qu(i)=tqt(i,2)+(xlat-25.)*(tqmw(i,2)-tqt(i,2))/10.
          enddo
         endif
        else 
         if(xlat.ge.35..and.xlat.le.55.)then
          do i=1,10  
            tu(i) = tqmw(i,1)
            qu(i) = tqmw(i,2)
          enddo
         else if(xlat.ge.65.)then
          do i=1,10
            tu(i) = tqaw(i,1)
            qu(i) = tqaw(i,2)
          enddo
         else
          do i=1,10
           tu(i)=tqmw(i,1)+(xlat-55.)*(tqaw(i,1)-tqmw(i,1))/10.
           qu(i)=0.003 
          enddo
         endif
        endif
c        if(kk.eq.2)then
c          write(*,*)' Subroutine PUPNH '
c          write(*,*)'TOP temp of nature run ', tnr
c          do i=1,10
c          write(*,*)tu(i)
c          enddo
c        endif
        return
        end

         
        Subroutine SH_UPAIR_PRF(
C
C************************************************************************
C*                                                                      *
C*      Module Name:    SH_UPAIR_PRF                                    *
C*                                                                      *
C*      Language:       Fortran-77                                      *
C*                                                                      *
C*      Version Rev:    1.0 10 April 98 Programmer:po                   *
C*                                                                      *
C*      Call Seq:       Call SH_UPAIR_PRF(ylat,ttopnr,tup,qup)          *
C*                                                                      *
C*      Description:    interpolate upper atmosphere profile(10mb - 0.1 *
C*                      mb) for south hemisphere summer according to    *
C*                      latitude of tovs obs.                           *
C*                                                                      *
C*      Input Args:     R       xlat    tovs obs.'s latitude            *
C*                      R       tnr     nr top level temp.              *
C*                                                                      *
C*      Output Args:    R       tu(10) upper temp. profile              *
C*                      R       qu(10) upper moist profile              *
C*                                                                      *
C************************************************************************
C
     $  xlat,
     $  tnr,
     $  tu,
     $  qu)


C
CC      to obtain upper air profile at altitudes above 10mb(nature run
CC      upper limit) from model atmospheric profile in SOUTH HEMISPERE.
C
C        dimension tu(10),qu(10),tqt(10,2),tqms(10,2),tqas(10,2),
C      $            tqt1(10,2),tqms1(10,2),tqas1(10,2)
C    Input
       Real xlat, tnr

C    Output
       Real tu(10), qu(10)

C    Local
       Real tqt(10,2),tqms(10,2),tqas(10,2)

       Real tqt1(10,2)
C      the first ten element: temp. diffence profile above 10 mb(temp at 10mb
C        - temp. above 10 mb)
C      the last ten element: moist profile.
c      Atmosphere : 2   reference originale :  1
c      tropical 
       data tqt1/
     +   -3.72,  13.33,  29.11,  34.60,  30.40,  25.69,  18.98,  14.25, 
     +   10.69,   5.44, 
     +   0.003,  0.004,  0.004,  0.004,  0.004,  0.003,  0.003,  0.003,
     +   0.003,  0.003/  

       Real  tqms1(10,2)
C      the first ten element: temp. diffence profile above 10 mb(temp at 10mb
C        - temp. above 10 mb)
C      the last ten element: moist profile.
c      Atmosphere : 3   reference originale :  2
c      midlatitude summer
       data tqms1/
     +   -7.73,  11.41,  30.83,  37.72,  34.73,  29.48,  21.60,  16.17, 
     +   12.06,   6.06, 
     +   0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003/  

       Real tqas1(10,2)
C      the first ten element: temp. diffence profile above 10 mb(temp at 10mb
C        - temp. above 10 mb)
C      the last ten element: moist profile.
c      Atmosphere : 5   reference originale :  4
c      polar summer
       data tqas1/
     +  -11.68,  11.08,  33.55,  38.01,  36.09,  33.20,  25.89,  19.23, 
     +   14.18,   6.88, 
     +   0.002,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,  0.003,
     +   0.003,  0.003/

        do j=1,10

C    take temp. adjustment from nr temp. at 10mb
           tqt(j,1)=tqt1(j,1)+tnr
           tqms(j,1)=tqms1(j,1)+tnr
           tqas(j,1)=tqas1(j,1)+tnr

C    assign moist profile
           tqt(j,2)=tqt1(j,2)   
           tqms(j,2)=tqms1(j,2)   
           tqas(j,2)=tqas1(j,2)   
        enddo

C
CC     Interpolate temperature and moist profile according tovs obs.
CC     latiutde.
CC     ALGORITHM:
CC           xlat < 25:  assign tropical
CC      25 < xlat < 35:  interpolater from midlatiutde summer and tropical
CC      35 < xlat < 55:  assign midlatiutde summer
CC      55 < xlat < 65:  interpolater from midlatiutde summer and arctic winter
CC      65 < xlat     :  assign arctic summer
        xl = abs(xlat)
        if(xl.lt.35.0)then
         if(xl.le.25.) then
          do i=1,10
            tu(i)=tqt(i,1)
            qu(i)=tqt(i,2)
          enddo
         else
          do i=1,10
            tu(i)=tqt(i,1)-(xlat+25.)*(tqms(i,1)-tqt(i,1))/10.
            qu(i)=tqt(i,2)-(xlat+25.)*(tqms(i,2)-tqt(i,2))/10.
          enddo
         endif
        else
         if(xl.ge.35..and.xl.le.55.)then
          do i=1,10
            tu(i) = tqms(i,1)
            qu(i) = tqms(i,2)
          enddo
         else if(xl.ge.65.) then
          do i=1,10
            tu(i) = tqas(i,1)
            qu(i) = tqas(i,2)
          enddo
         else
          do i=1,10
           tu(i)=tqms(i,1)-(xlat+55.)*(tqas(i,1)-tqms(i,1))/10.
           qu(i)=0.003
          enddo
         endif
        endif
        return
        end

       subroutine O3_PRF(
C
C************************************************************************
C*                                                                      *
C*      Module Name:    O3_PRF	                                        *
C*                                                                      *
C*      Language:       Fortran-77                                      *
C*                                                                      *
C*      Version Rev:    1.0 10 April 98 Programmer:po                   *
C*                                                                      *
C*      Call Seq:       Call O3_PRF(tlat,xlon,pnr1,o3p)          *
C*                                                                      *
C*      Description:    interpolate upper atmosphere profile(10mb - 0.1 *
C*                      mb) for north hemisphere winter according to    *
C*                      latitude of tovs obs.                           *
C*                                                                      *
C*      Input Args:     R       tlat    tovs obs.'s latitude            *
C*                      R       xlon     nr top level temp.             *
C*                      R       pnr1(31) upper moist profile            *
C*                                                                      *
C*      Output Args:    R       o3p(41) upper temp. profile              *
C*                                                                      *
C************************************************************************

     $    tlat,
     $    xlon,
     $    pnr1,
     $    o3p)

C
CC   SBUV/2 o3 common block
CC   ozone unit: ppv
       common /o3nh/ ozn(65,65,6)
       common /o3sh/ ozs(65,65,6)

C     Input
      Real tlat, xlon, pnr1(31)

C     Output
      Real o3p(31) 

C      dimension pnr(41),o3p(41), pref(42), o3ref(42),
C    $           f(65,65),po(6),ozl(6),pnr1(31)

C     Local 
      Real f(65,65)    ! SBUV/2 grid point(65*65)
      Real ozl(6)      ! interpolate SBUV/2 ozone quantity at 6 level
      Real pnr(31)
    
       Real po(6)    !  sbuv 6 layer standard pressure
       data po/0.4,1.0,2.0,5.0,10.0,30.0/

       Real O3ref(42)   ! US 1976 standard ozone profile 
c      Atmosphere : 1   reference originale :  6
c      US std 76
       data o3ref/
     +  1.08113,  1.73462,  3.53462,  6.32921,  8.71895, 10.11823, 
     +  12.18141,
     + 12.82759, 12.94543, 12.51526, 11.45396, 10.10086,  9.19465, 
     +  8.52910,
     +  7.61230, 4.74687, 3.79465, 2.98974,  2.13501,  1.55542, 
     +  1.19631,
     +  0.90783,  0.76153,  0.48192,  0.26941,  0.16322,  0.10542,
     +  0.08595,
     +  0.07809,  0.06781,  0.06564,  0.05982,  0.05601,  0.05532,  
     +  0.05494,
     +  0.05378,  0.05081,  0.04764,  0.04643,  0.04451,  0.04355, 
     +  0.04259/

C     US 1976  standard ozone profile in ppmv
c     +  0.65318, 1.04800, 2.13550, 3.82390, 5.26770, 6.11310, 7.35960,
c     +  7.75000, 7.82120, 7.56130, 6.92010, 6.10260, 5.55510, 5.15300,
c     +  4.59910, 2.86790, 2.29260, 1.80630, 1.28990, 0.93973, 0.72277,
c     +  0.54848, 0.46009, 0.29116, 0.16277, 0.09861, 0.06369, 0.05193,
c     +  0.04718, 0.04097, 0.03966, 0.03614, 0.03384, 0.03342, 0.03319,
c     +  0.03249, 0.03070, 0.02878, 0.02805, 0.02689, 0.02631, 0.02573/

       Real pref(42)     !  US 1976 standard pressure profile
       data Pref
     &  / .1,.2,.5,1.,1.5,2.,3.,4.,5.,7.,10.,15.,20.,25.,30.,
     &  50.,60.,70.,85.,100.,115.,135.,150.,200.,250.,300.,350.,400.,
     &  430.,475.,500.,570.,620.,670.,700.,780.,850.,920.,950.,1000.,
     &  1025.,1050./
  
C     assign first ten layer pressure from 1976 us standard
       do i=1,10
        pnr(i) = pref(i)
       enddo

C     assign last 31 layer from nature run pressure profile
       do i=11,41
        ii=i-10
        pnr(i)=pnr1(ii)
       enddo

C     Call sbuv/2 routine to get 6 layer ozone profile
C     SEE SBUV/2 REFERENCE
       if(xlon.lt.0.0)then
         tlon=360+xlon
       else
         tlon=xlon
       endif
        tlon = 360. - tlon
        irev=0
       if(tlat.ge.0.0)then
         xmesh = 381.0
         orient = 80.0
         do k = 6,1,-1
          irev = irev + 1
          do i=1,65
           do j=1,65
            f(i,j)=ozn(i,j,k)
           enddo
          enddo
            CALL W3FB04(TLAT,TLON,XMESH,ORIENT,XI,XJ)                           
            XIIN=XI+33.                                                         
            XJIN=XJ+33.                                                         
c            IMAX=65                                                            
c            JMAX=65                                                          
c            INTERP=1                                                           
c            CALL W3FT01(XIIN,XJIN,F,D,IMAX,JMAX,0,INTERP)                      
            CALL W3FT01(XIIN,XJIN,F,D,65,65,0,0)                       
            ozl(irev) = D
          enddo
        else
         do k = 6,1,-1
          irev = irev + 1
          do i=1,65
           do j=1,65
            f(i,j)=ozs(i,j,k)
           enddo
          enddo
            XMESH=-381.0                          
            ORIENT=260.0                                               
            CALL W3FB04(TLAT,TLON,XMESH,ORIENT,XI,XJ)                           
            XIIN=XI+33.                                                         
            XJIN=XJ+33.                                                         
            IMAX=65                                                             
            JMAX=65                                                             
            INTERP=1                                                            
            CALL W3FT01(XIIN,XJIN,F,D,IMAX,JMAX,0,INTERP)                       
            ozl(irev) = D
         enddo
        endif

c        do i=1,15
c           o3ref(i)=o3r(i)
c        enddo
c        do i=16,18
c           o3ref(i)=o3r(i)+ozl(6)
c        enddo
c        do i=19,42
c           o3ref(i)=o3r(i)
c        enddo
c        if(kk.lt.12)then
c          write(*,*)kk,' ozone obs. ', ozl(6)
c            do i=1,42
c               write(*,*)'ozone refence profile  ',i,o3ref(i)
c            enddo
c        endif

C     assign first 6 layers ozone quantity according to their P level
        o3p(1) = o3ref(1)
        o3p(2) = o3ref(2)
        o3p(3) = ozl(1)+(ozl(2)-ozl(1))/6.
        o3p(4) = ozl(2)
        o3p(5) = (ozl(2)+ozl(3))*0.5
        o3p(6) = ozl(3)

C     interpolate 7-10 level ozone profile from sbuv/2 data
        do i = 7,10
          do j=3,5
            if(pref(i).le.po(j).and.pref(i).gt.po(j-1))then
            p1=po(j-1)
            p2=po(j)
            oz1=ozl(j-1)
            oz2=ozl(j)
          o3p(i)=ozl(j-1)+(pref(i)-p1)*(oz2-oz1)/(p2-p1)
            goto 921
            endif
          enddo
921      continue
        enddo

C     assign 11 - 14 layers ozone quantity according to their P level
        o3p(11) = ozl(5)
        o3p(12) = ozl(6)
        o3p(13) = o3ref(16)
        o3p(14) = o3ref(18)

C     interpolate 7-10 level ozone profile from 1976 us standard
        do j = 15,41
          do i = 19,42 
          if(pref(i).ge.pnr(j).and.pref(i-1).lt.pnr(j))then
          o3p(j)=o3ref(i-1)+(o3ref(i)-o3ref(i-1))*
     $           (pnr(j)-pref(i-1))/(pref(i)-pref(i-1))
          goto 923
          endif
          enddo
923      continue
        enddo
        return
        end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE W3FB04(ALAT,ALONG,XMESHL,ORIENT,XI,XJ)                         
C$$$  SUBPROGRAM DOCUMENTATION BLOCK                                            
C                                                                               
C SUBPROGRAM:  W3FB04        LATITUDE, LONGITUDE TO GRID COORDINATES            
C   PRGMMR: REJONES          ORG: NMC421      DATE:93-09-30                     
C                                                                               
C ABSTRACT: CONVERTS THE COORDINATES OF A LOCATION ON EARTH FROM THE            
C   NATURAL COORDINATE SYSTEM OF LATITUDE/LONGITUDE TO THE GRID (I,J)           
C   COORDINATE SYSTEM OVERLAID ON A POLAR STEREOGRAPHIC MAP PRO-                
C   JECTION TRUE AT 60 DEGREES N OR S LATITUDE. W3FB04 IS THE REVERSE           
C   OF W3FB05.                                                                  
C                                                                               
C PROGRAM HISTORY LOG:                                                          
C   86-07-17  MCDONELL,J.                                                       
C   88-06-07  R.E.JONES   REPLACE GOTO'S WITH IF-THEN-ELSE                      
C   93-09-14  R.E.JONES   ADD SAVE                                              
C                                                                               
C USAGE:  CALL W3FB04 (ALAT, ALONG, XMESHL, ORIENT, XI, XJ)                     
C                                                                               
C   INPUT VARIABLES:                                                            
C     NAMES  INTERFACE DESCRIPTION OF VARIABLES AND TYPES                       
C     ------ --------- -----------------------------------------------          
C     ALAT   ARG LIST  LATITUDE IN DEGREES (<0 IF SH)                           
C     ALONG  ARG LIST  WEST LONGITUDE IN DEGREES                                
C     XMESHL ARG LIST  MESH LENGTH OF GRID IN KM AT 60 DEG LAT(<0 IF SH)        
C                   (190.5 LFM GRID, 381.0 NH PE GRID,-381.0 SH PE GRID)        
C     ORIENT ARG LIST  ORIENTATION WEST LONGITUDE OF THE GRID                   
C                   (105.0 LFM GRID, 80.0 NH PE GRID, 260.0 SH PE GRID)         
C                                                                               
C   OUTPUT VARIABLES:                                                           
C     NAMES  INTERFACE DESCRIPTION OF VARIABLES AND TYPES                       
C     ------ --------- -----------------------------------------------          
C     XI     ARG LIST  I OF THE POINT RELATIVE TO NORTH OR SOUTH POLE           
C     XJ     ARG LIST  J OF THE POINT RELATIVE TO NORTH OR SOUTH POLE           
C                                                                               
C   SUBPROGRAMS CALLED:                                                         
C     NAMES                                                   LIBRARY           
C     ------------------------------------------------------- --------          
C     COS SIN                                                 SYSLIB            
C                                                                               
C   REMARKS: ALL PARAMETERS IN THE CALLING STATEMENT MUST BE                    
C     REAL. THE RANGE OF ALLOWABLE LATITUDES IS FROM A POLE TO                  
C     30 DEGREES INTO THE OPPOSITE HEMISPHERE.                                  
C     THE GRID USED IN THIS SUBROUTINE HAS ITS ORIGIN (I=0,J=0)                 
C     AT THE POLE IN EITHER HEMISPHERE, SO IF THE USER'S GRID HAS ITS           
C     ORIGIN AT A POINT OTHER THAN THE POLE, A TRANSLATION IS NEEDED            
C     TO GET I AND J. THE GRIDLINES OF I=CONSTANT ARE PARALLEL TO A             
C     LONGITUDE DESIGNATED BY THE USER. THE EARTH'S RADIUS IS TAKEN             
C     TO BE 6371.2 KM.                                                          
C                                                                               
C ATTRIBUTES:                                                                   
C   LANGUAGE: IBM370 VS FORTRAN                                                 
C   MACHINE:  HDS 9080, XL50.                                                   
C                                                                               
C$$$                                                                            
C                                                                               
      SAVE                                                                      
C                                                                               
      DATA  RADPD /.01745329/                                                   
      DATA  EARTHR/6371.2/                                                      
C                                                                               
      RE    = (EARTHR * 1.86603) / XMESHL                                       
      XLAT  = ALAT * RADPD                                                      
C                                                                               
      IF (XMESHL.GE.0.) THEN                                                    
        WLONG = (ALONG + 180.0 - ORIENT) * RADPD                                
        R     = (RE * COS(XLAT)) / (1.0 + SIN(XLAT))                            
        XI    =   R * SIN(WLONG)                                                
        XJ    =   R * COS(WLONG)                                                
C                                                                               
      ELSE                                                                      
C                                                                               
        RE    = -RE                                                             
        XLAT  = -XLAT                                                           
        WLONG = (ALONG - ORIENT) * RADPD                                        
        R     = (RE * COS(XLAT)) / (1.0 + SIN(XLAT))                            
        XI    =   R * SIN(WLONG)                                                
        XJ    =  -R * COS(WLONG)                                                
      ENDIF                                                                     
C                                                                               
      RETURN                                                                    
      END                                                                       
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       SUBROUTINE W3FT01(STI,STJ,FLD,HI,II,JJ,NCYCLK,LIN)                       
C$$$   SUBPROGRAM  DOCUMENTATION  BLOCK                                         
C                                                                               
C SUBPROGRAM: W3FT01         INTERPOLATE VALUES IN A DATA FIELD                 
C   AUTHOR: MCDONELL, J.     ORG: W345       DATE: 84-06-27                     
C                                                                               
C ABSTRACT: FOR A GIVEN GRID COORDINATE IN A DATA ARRAY, ESTIMATES              
C   A DATA VALUE FOR THAT POINT USING EITHER A LINEAR OR QUADRATIC              
C   INTERPOLATION METHOD.                                                       
C                                                                               
C USAGE:  CALL W3FT01 (STI,STJ,FLD,HI,II,JJ,NCYCLK,LIN)                         
C                                                                               
C   INPUT VARIABLES:                                                            
C     NAMES  INTERFACE DESCRIPTION OF VARIABLES AND TYPES                       
C     ------ --------- -----------------------------------------------          
C     STI    ARG LIST  REAL*4 I GRID COORDINATE OF THE POINT FOR WHICH          
C                      AN INTERPOLATED VALUE IS DESIRED                         
C     STJ    ARG LIST  REAL*4 J GRID COORDINATE OF THE POINT FOR WHICH          
C                      AN INTERPOLATED VALUE IS DESIRED                         
C     FLD    ARG LIST  REAL*4 SIZE(II,JJ) DATA FIELD                            
C     II     ARG LIST  INTEGER*4 NUMBER OF COLUMNS IN 'FLD'                     
C     JJ     ARG LIST  INTEGER*4 NUMBER OF ROWS IN 'FLD'                        
C     NCYCLK ARG LIST  INTEGER*4 CODE TO SPECIFY IF GRID IS CYCLIC OR           
C                      NOT:                                                     
C                      = 0  NON-CYCLIC IN II, NON-CYCLIC IN JJ                  
C                      = 1  CYCLIC IN II, NON-CYCLIC IN JJ                      
C                      = 2  CYCLIC IN JJ, NON-CYCLIC IN II                      
C                      = 3  CYCLIC IN II, CYCLIC IN JJ                          
C     LIN    ARG LIST  INTEGER*4 CODE SPECIFYING INTERPOLATION METHOD:          
C                      = 1  LINEAR INTERPOLATION                                
C                      .NE.1  QUADRATIC INTERPOLATION                           
C                                                                               
C   OUTPUT VARIABLES:                                                           
C     NAMES  INTERFACE DESCRIPTION OF VARIABLES AND TYPES                       
C     ------ --------- -----------------------------------------------          
C     HI     ARG LIST  REAL*4 DATA FIELD VALUE AT (STI,STJ) OBTAINED            
C                      BY INTERPOLATION.                                        
C                                                                               
C ATTRIBUTES:                                                                   
C   LANGUAGE: IBM VS FORTRAN                                                    
C   CODE SIZE:  79 LINES   CORE SIZE: 1142 (HEX) BYTES                          
C                                                                               
C$$$                                                                            
C                                                                               
      DIMENSION FLD(II,JJ),ERAS(4),JY(4)                                        
      I=STI                                                                     
      J=STJ                                                                     
      FI=I                                                                      
      FJ=J                                                                      
      XDELI=STI-FI                                                              
      XDELJ=STJ-FJ                                                              
      IP2=I+2                                                                   
      IM1=I-1                                                                   
      IP1=I+1                                                                   
      JY(4)=J+2                                                                 
      JY(1)=J-1                                                                 
      JY(3)=J+1                                                                 
      JY(2)=J                                                                   
      XI2TM=0.                                                                  
      XJ2TM=0.                                                                  
      IF (LIN.EQ.1) GO TO 12                                                    
      XI2TM=XDELI*(XDELI-1.)*.25                                                
      XJ2TM=XDELJ*(XDELJ-1.)*.25                                                
   12 CONTINUE                                                                  
      IF((I.LT.2).OR.(J.LT.2)) GO TO 10                                         
      IF((I.GT.II-3).OR.(J.GT.JJ-3)) GO TO 10                                   
C     QUADRATIC (LINEAR TOO) OK W/O FURTHER ADO SO GO TO 41                     
      GO TO 41                                                                  
   10 CONTINUE                                                                  
      ICYCLK=0                                                                  
      JCYCLK=0                                                                  
      IF (NCYCLK) 11,6,11                                                       
   11 IF (NCYCLK/2 .NE. 0) JCYCLK=1                                             
      IF (NCYCLK.NE.2) ICYCLK=1                                                 
      IF (ICYCLK) 8,5,8                                                         
    8 IF (I.EQ.1) GO TO 16                                                      
      IF (I.EQ.(II-1)) GO TO 17                                                 
      IP2=I+2                                                                   
      IM1=I-1                                                                   
      GO TO 18                                                                  
   16 IP2=3                                                                     
      IM1=II-1                                                                  
      GO TO 18                                                                  
   17 IP2=2                                                                     
      IM1=II-2                                                                  
   18 IP1=I+1                                                                   
    5 IF (JCYCLK) 9,6,9                                                         
    9 IF (J.EQ.1) GO TO 26                                                      
      IF (J.EQ.(JJ-1)) GO TO 27                                                 
      JY(4)=J+2                                                                 
      JY(1)=J-1                                                                 
      GO TO 28                                                                  
   26 JY(4)=3                                                                   
      JY(1)=JJ-1                                                                
      GO TO 28                                                                  
   27 JY(4)=2                                                                   
      JY(1)=JJ-2                                                                
   28 JY(3)=J+1                                                                 
      JY(2)=J                                                                   
    6 IF (LIN.EQ.1) GO TO 22                                                    
      IF (ICYCLK) 21,20,21                                                      
   20 IF ((I.LT.2).OR.(I.GE.(II-1)))  XI2TM=0.                                  
   21 IF (JCYCLK) 22,23,22                                                      
   23 IF ((J.LT.2).OR.(J.GE.(JJ-1)))  XJ2TM=0.                                  
   22 CONTINUE                                                                  
C.....DO NOT ALLOW POINT OFF GRID,CYCLIC OR NOT                                 
      IF (I.LT.1) I=1                                                           
      IF (IP1.LT.1) IP1=1                                                       
      IF (IP2.LT.1) IP2=1                                                       
      IF (IM1.LT.1) IM1=1                                                       
C.....DO NOT ALLOW POINT OFF GRID,CYCLIC OR NOT                                 
      IF (I.GT.II) I=II                                                         
      IF (IP1.GT.II) IP1=II                                                     
      IF (IP2.GT.II) IP2=II                                                     
      IF (IM1.GT.II) IM1=II                                                     
   41 CONTINUE                                                                  
      DO 40 K = 1,4                                                             
      J1 = JY(K)                                                                
C.....DO NOT ALLOW POINT OFF GRID,CYCLIC OR NOT                                 
      IF (J1.LT.1) J1=1                                                         
      IF (J1.GT.JJ) J1=JJ                                                       
      ERAS(K)=(FLD(IP1,J1)-FLD(I,J1))*XDELI+FLD(I,J1)+                          
     1(FLD(IM1,J1)-FLD(I,J1)-FLD(IP1,J1)+FLD(IP2,J1))*XI2TM                     
   40 CONTINUE                                                                  
      HI=ERAS(2)+(ERAS(3)-ERAS(2))*XDELJ+(ERAS(1)-ERAS(2)-ERAS(3)+ERAS(4        
     1))*XJ2TM                                                                  
      RETURN                                                                    
      END                                                                       
